package com.jeeplus.modules.cg.infrastructure.service;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.infrastructure.entity.ConstructionBatch;
import com.jeeplus.modules.cg.infrastructure.mapper.ConstructionBatchMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * @author: 王强  - service
 * @create: 2023-05-08 15:04
 **/
@Service
@Transactional(readOnly = true)
public class ConstructionBatchService extends CrudService<ConstructionBatchMapper, ConstructionBatch> {

    @Autowired
    private ConstructionBatchMapper dao;

    /**
     * 获取所有的施工图纸收集截止时间
     * @return
     */
    public List<ConstructionBatch> getAllDeadLine(){
        return dao.getAllDeadLine();
    }

    /**
     * 根据条件查询所有数据
     * @param param
     * @return
     */
    public int getAllInfo(ConstructionBatch param){
        return dao.getAllInfo(param);
    }

    public Page<ConstructionBatch> findPage(Page<ConstructionBatch> page, ConstructionBatch batch) {
        Page<ConstructionBatch> pageList = super.findPage(page, batch);
        return pageList;
    }

    /**
     * 批量添加数据
     * @param batches
     */
    @Transactional(readOnly = false)
    public void insertList(List<ConstructionBatch> batches){
        dao.insertList(batches);
    }

    public List<ConstructionBatch> exportFindList( ConstructionBatch batch) {
        List<ConstructionBatch> pageList = dao.exportFindList(batch);
        return pageList;
    }

    /**
     * 删除方法
     * @param basicInfo
     */
    @Transactional(readOnly = false)
    public void delete(ConstructionBatch basicInfo) {
        super.delete(basicInfo);
    }

    /**
     * 修改方法
     * @param batch
     */
    @Transactional(readOnly = false)
    public void update(ConstructionBatch batch) {
        super.save(batch);
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param reserveManagement
     * @return
     */
    public Map<String, List<ConstructionBatch>> getExistProjectList(List<ConstructionBatch> reserveManagement){
        Map<String,List<ConstructionBatch>> map = new HashMap();
        List<ConstructionBatch> existReserveManagementList = new ArrayList<>();
        Iterator<ConstructionBatch> iterator = reserveManagement.iterator();
        while (iterator.hasNext()) {
            ConstructionBatch rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            ConstructionBatch reserveManag = dao.queryByProjectCode(rm);

            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }
        }
        map.put("without",reserveManagement);
        map.put("exist",existReserveManagementList);
        return map;
    }

}
