package com.jeeplus.modules.cg.infrastructure.service;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.infrastructure.entity.InfrastructureBasicInfo;
import com.jeeplus.modules.cg.infrastructure.mapper.InfrastructureBasicInfoMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * 基建基础信息 - service
 * @author: 王强
 * @create: 2023-05-08 14:23
 **/
@Service
@Transactional(readOnly = true)
public class InfrastructureBasicInfoService extends CrudService<InfrastructureBasicInfoMapper, InfrastructureBasicInfo> {

    @Autowired
    private InfrastructureBasicInfoMapper dao;

    /**
     * 新增方法
     * @param entity
     */
    @Transactional(readOnly = false)
    public void save(InfrastructureBasicInfo entity) {
        //查询数据表中是否含有同项目储备编号的数据 若有则进行修改 没有则新增
        //根据项目储备编号 查询数据
        if (entity.getIsNewRecord()){
            entity.preInsert();
            mapper.insert(entity);
        }else{
            entity.preUpdate();
            mapper.update(entity);
        }
    }

    /**
     * 根据条件查询所有数据
     * @param param
     * @return
     */
    public int getAllInfo(InfrastructureBasicInfo param){
        return dao.getAllInfo(param);
    }

    public Page<InfrastructureBasicInfo> findPage(Page<InfrastructureBasicInfo> page, InfrastructureBasicInfo basicInfo) {
        Page<InfrastructureBasicInfo> pageList = super.findPage(page, basicInfo);
        return pageList;
    }

    public List<InfrastructureBasicInfo> exportFindList( InfrastructureBasicInfo basicInfo) {
        List<InfrastructureBasicInfo> pageList = dao.exportFindList(basicInfo);
        return pageList;
    }

    /**
     * 修改方法
     * @param basicInfo
     */
    @Transactional(readOnly = false)
    public void update(InfrastructureBasicInfo basicInfo) {
        super.save(basicInfo);
    }

    /**
     * 批量添加数据
     * @param basicInfos
     */
    @Transactional(readOnly = false)
    public void insertList(List<InfrastructureBasicInfo> basicInfos){
        dao.insertList(basicInfos);
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param reserveManagement
     * @return
     */
    public Map<String,List<InfrastructureBasicInfo>> getExistProjectList(List<InfrastructureBasicInfo> reserveManagement){
        Map<String,List<InfrastructureBasicInfo>> map = new HashMap();
        List<InfrastructureBasicInfo> existReserveManagementList = new ArrayList<>();
        Iterator<InfrastructureBasicInfo> iterator = reserveManagement.iterator();
        while (iterator.hasNext()) {
            InfrastructureBasicInfo rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            InfrastructureBasicInfo reserveManag = dao.queryByProjectCode(rm);

            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }
        }
        map.put("without",reserveManagement);
        map.put("exist",existReserveManagementList);
        return map;
    }

    /**
     * 删除方法
     * @param basicInfo
     */
    @Transactional(readOnly = false)
    public void delete(InfrastructureBasicInfo basicInfo) {
        super.delete(basicInfo);
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }
}
