package com.jeeplus.modules.cg.infrastructure.util;

import com.jeeplus.modules.cg.infrastructure.entity.ConstructionBatch;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * 获取变化时间util
 * @author: 王强
 * @create: 2023-05-12 08:41
 **/
public class ChangeTimeUtil {

    public static ChangeTimeUtil getOne(){

        return new ChangeTimeUtil();
    }

    public SimpleDateFormat SHORT_DATE_FORMAT = new SimpleDateFormat("yyyy/MM/dd");

    public String determineTimeFormat(String date){
        if (date.matches("\\d{4}/\\d{2}/\\d{2}")) {
            // 日期格式为 yyyy/MM/dd
            return date;
        } else if (date.matches("\\d{4}-\\d{2}-\\d{2}")) {
            // 日期格式为 yyyy-MM-dd
            DateFormat inputFormat = new SimpleDateFormat("yyyy-MM-dd");
            DateFormat outputFormat = new SimpleDateFormat("yyyy/MM/dd");
            try {
                Date dateTime = inputFormat.parse(date);
                String formattedDate = outputFormat.format(dateTime);
                System.out.println("转换后的日期：" + formattedDate);
                return formattedDate;
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }
        return null;
    }

    /**
     * 判断是哪一个时间区间
     * @param time
     * @param batches
     * @return
     */
    public ConstructionBatch getTimeInterval(String time, List<ConstructionBatch> batches) throws ParseException {
        SimpleDateFormat inputFormat = new SimpleDateFormat("yyyy/M/dd");

        // 待判断日期
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy/MM/dd");
        LocalDate targetDate = LocalDate.parse(time, formatter);

        for (int i=0;i<batches.size();i++){
            Date da = inputFormat.parse(batches.get(i).getEndTime());
            LocalDate startTime = LocalDate.parse(SHORT_DATE_FORMAT.format(da), formatter);
            if (targetDate.isBefore(startTime)){
                return batches.get(i);
            } else {
                for (int k=i+1;k<batches.size();k++){
                    da = inputFormat.parse(batches.get(k).getEndTime());
                    LocalDate startTime2 = LocalDate.parse(SHORT_DATE_FORMAT.format(da), formatter);
                    if (targetDate.isBefore(startTime2)){
                        return batches.get(k);
                    }
                }
            }
        }

        return null;
    }

    /**
     * 根据（一）初步设计内审时间获取（二）初步设计评审计划时间
     * @param internalTime
     * @return
     */
    public String getDesignReview(String internalTime){
        //下月的15号
        Calendar calendar = Calendar.getInstance();
        try {
            if (internalTime != null && !"".equals(internalTime)){
                calendar.setTime(SHORT_DATE_FORMAT.parse(internalTime));
            }
        }catch (ParseException e){
            e.printStackTrace();
        }
        calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH)+1,calendar.get(Calendar.DAY_OF_MONTH));
        calendar.set(Calendar.DAY_OF_MONTH,15);
        return SHORT_DATE_FORMAT.format(calendar.getTime());
    }

    /**
     * 根据（二）初步设计评审计划时间获取（三）初设外审评审时间
     * @param internalTime
     * @return
     */
    public List<String> getExternalReview(String internalTime){
        List<String> list = new ArrayList<>();
        //下月的10号 或者是25号
        Calendar calendar = Calendar.getInstance();
        try {
            if (internalTime != null && !"".equals(internalTime)){
                calendar.setTime(SHORT_DATE_FORMAT.parse(internalTime));
            }
        }catch (ParseException e){
            e.printStackTrace();
        }
        calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH)+1,calendar.get(Calendar.DAY_OF_MONTH));
        calendar.set(Calendar.DAY_OF_MONTH,10);
        list.add(SHORT_DATE_FORMAT.format(calendar.getTime()));
        calendar.set(Calendar.DAY_OF_MONTH,25);
        list.add(SHORT_DATE_FORMAT.format(calendar.getTime()));
        return list;
    }

    /**
     * 根据（三）初设外审评审时间获取（四）初设评审意见时间
     * @param time
     * @return
     */
    public List<String> getReviewComments(String time){
        List<String> list = new ArrayList<>();
        //15天后，或者是30天后
        Calendar calendar = Calendar.getInstance();
        try {
            if (time != null && !"".equals(time)){
                calendar.setTime(SHORT_DATE_FORMAT.parse(time));
                //15天
                calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH),calendar.get(Calendar.DAY_OF_MONTH)+15);
                list.add(SHORT_DATE_FORMAT.format(calendar.getTime()));

                calendar.setTime(SHORT_DATE_FORMAT.parse(time));
                //30天
                calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH),calendar.get(Calendar.DAY_OF_MONTH)+30);
                list.add(SHORT_DATE_FORMAT.format(calendar.getTime()));
            }
        }catch (ParseException e){
            e.printStackTrace();
        }
        return list;
    }

    /**
     * 根据（四）初设评审意见时间获取（五）施工图评审计划时间 60天
     * @param time
     * @return
     */
    public String getReviewPlan(String time){
        //60天后，若超过20号则为下个月的20号
        Calendar calendar = Calendar.getInstance();
        try {
            if (time != null && !"".equals(time)){
                calendar.setTime(SHORT_DATE_FORMAT.parse(time));
                //60天
                calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH),calendar.get(Calendar.DAY_OF_MONTH)+60);

                String format = SHORT_DATE_FORMAT.format(calendar.getTime());
                calendar.setTime(SHORT_DATE_FORMAT.parse(format));
                int day = calendar.get(Calendar.DAY_OF_MONTH);
                if (day<=20){
                    calendar.set(Calendar.DAY_OF_MONTH,20);
                } else {
                    calendar.set(Calendar.MONTH,calendar.get(Calendar.MONTH)+1);
                    calendar.set(Calendar.DAY_OF_MONTH,20);
                }
                return SHORT_DATE_FORMAT.format(calendar.getTime());
            }
        }catch (ParseException e){
            e.printStackTrace();
        }
        return "";
    }

    /**
     * 根据（四）初设评审意见时间获取（五）施工图评审计划时间 30天
     * @param time
     * @return
     */
    public String getReviewPlan2(String time){
        //30天后，若超过20号则为下个月的20号
        Calendar calendar = Calendar.getInstance();
        try {
            if (time != null && !"".equals(time)){
                calendar.setTime(SHORT_DATE_FORMAT.parse(time));
                //30天
                calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH),calendar.get(Calendar.DAY_OF_MONTH)+30);

                String format = SHORT_DATE_FORMAT.format(calendar.getTime());
                calendar.setTime(SHORT_DATE_FORMAT.parse(format));
                int day = calendar.get(Calendar.DAY_OF_MONTH);
                if (day<=20){
                    calendar.set(Calendar.DAY_OF_MONTH,20);
                } else {
                    calendar.set(Calendar.MONTH,calendar.get(Calendar.MONTH)+1);
                    calendar.set(Calendar.DAY_OF_MONTH,20);
                }
                return SHORT_DATE_FORMAT.format(calendar.getTime());
            }
        }catch (ParseException e){
            e.printStackTrace();
        }
        return "";
    }

    /**
     * 根据（五）施工图评审计划时间获取（六）施工图评审时间
     * @param time
     * @return
     */
    public List<String> getDrawingReview(String time){
        //下个月的10号，或者是25号
        List<String> list = new ArrayList<>();
        Calendar calendar = Calendar.getInstance();
        try {
            if (time != null && !"".equals(time)){
                calendar.setTime(SHORT_DATE_FORMAT.parse(time));
                //10天
//                calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH)+1,calendar.get(Calendar.DAY_OF_MONTH));
                calendar.set(Calendar.MONTH,calendar.get(Calendar.MONTH)+1);
                calendar.set(Calendar.DAY_OF_MONTH,10);
                list.add(SHORT_DATE_FORMAT.format(calendar.getTime()));

                calendar.setTime(SHORT_DATE_FORMAT.parse(time));
                //25天
                calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH)+1,calendar.get(Calendar.DAY_OF_MONTH));
                calendar.set(Calendar.DAY_OF_MONTH,25);
                list.add(SHORT_DATE_FORMAT.format(calendar.getTime()));
            }
        }catch (ParseException e){
            e.printStackTrace();
        }
        return list;
    }
    /**
     * 根据（六）施工图评审时间时间获取（七）施工图评审意见时间
     * @param time
     * @return
     */
    public List<String> getDrawReview(String time){
        //15天后，或者30天后
        List<String> list = new ArrayList<>();
        Calendar calendar = Calendar.getInstance();
        try {
            if (time != null && !"".equals(time)){
                calendar.setTime(SHORT_DATE_FORMAT.parse(time));
                //15天后
                calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH),calendar.get(Calendar.DAY_OF_MONTH)+15);
                list.add(SHORT_DATE_FORMAT.format(calendar.getTime()));

                calendar.setTime(SHORT_DATE_FORMAT.parse(time));
                //30天后
                calendar.set(calendar.get(Calendar.YEAR),calendar.get(Calendar.MONTH),calendar.get(Calendar.DAY_OF_MONTH)+30);
                list.add(SHORT_DATE_FORMAT.format(calendar.getTime()));
            }
        }catch (ParseException e){
            e.printStackTrace();
        }
        return list;
    }

    /**
     * 获取当前月份的第一天
     * @return
     */
    public String getMonth(){
        LocalDate now = LocalDate.now();
        LocalDate firstDayOfMonth = now.withDayOfMonth(1);
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy/MM/dd");
        String formattedDate = firstDayOfMonth.format(formatter);
        return formattedDate;
    }

    /**
     * 获取当前年份所有月份的第一天
     * @return
     */
    public List<String> getMonths(int year){
        List<String> list = new ArrayList<>();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy/MM/dd");

        for (int month = 1; month <= 12; month++) {
            LocalDate firstDayOfMonth = LocalDate.of(year, month, 1);
            String formattedDate = firstDayOfMonth.format(formatter);
            list.add(formattedDate);
        }
        return list;
    }
}
