package com.jeeplus.modules.cg.infrastructure.util;

import com.jeeplus.modules.cg.infrastructure.entity.ConstructionBatch;
import com.jeeplus.modules.cg.infrastructure.entity.InfrastructureBasicInfo;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.xssf.usermodel.XSSFCellStyle;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.net.URLEncoder;
import java.util.List;

/**
 * @author: 王强
 * @create: 2023-05-09 09:15
 **/
public class InfrastructureExcelExportUtil {

    private XSSFCellStyle style = null;

    public static InfrastructureExcelExportUtil getOne(){

        return new InfrastructureExcelExportUtil();
    }

    /**
     * 基建 - 基本信息 - 导出数据
     * @param response
     * @param workbook
     * @param list
     */
    public void exportBasic(HttpServletResponse response, XSSFWorkbook workbook, List<InfrastructureBasicInfo> list){
        try {
            int index = 1;//第一列序号
            int rowNum = 1;//数据起始列
            Sheet sheet = workbook.getSheetAt(0);
            for(int i=0;i<list.size();i++){
                Row row = sheet.createRow(rowNum+i);
                Cell cell0 = crateCell(workbook,row,0); //序号
                Cell cell1 = crateCell(workbook,row,1); //国网编码
                Cell cell2 = crateCell(workbook,row,2); //项目名称
                Cell cell3 = crateCell(workbook,row,3); //项目编码
                Cell cell4 = crateCell(workbook,row,4); //单体项目名称
                Cell cell5 = crateCell(workbook,row,5); //电压等级
                Cell cell6 = crateCell(workbook,row,6); //项目类别（变电/线路）
                Cell cell7 = crateCell(workbook,row,7); //规模
                Cell cell8 = crateCell(workbook,row,8); //设计单位
                Cell cell9 = crateCell(workbook,row,9); //施工单位
                Cell cell10 = crateCell(workbook,row,9); //监理单位
                Cell cell11 = crateCell(workbook,row,10); //（一）初步设计内审
                Cell cell12 = crateCell(workbook,row,11); //（二）初步设计评审计划
                Cell cell13 = crateCell(workbook,row,12); //（三）初设外审评审
                Cell cell14 = crateCell(workbook,row,13); //（四）初设评审意见
                Cell cell15 = crateCell(workbook,row,14); //（五）施工图评审计划
                Cell cell16 = crateCell(workbook,row,15); //（六）施工图评审
                Cell cell17 = crateCell(workbook,row,16); //（七）施工图评审意见
                Cell cell18 = crateCell(workbook,row,17); //施工计划批次
                Cell cell19 = crateCell(workbook,row,18); //施工定标日期

                InfrastructureBasicInfo basicInfo = list.get(i);

                cell0.setCellValue(String.valueOf(index++));
                cell1.setCellValue(basicInfo.getStateGridCode());
                cell2.setCellValue(basicInfo.getProjectName());
                cell3.setCellValue(basicInfo.getProjectCode());
                cell4.setCellValue(basicInfo.getIndividualProjectName());
                cell5.setCellValue(basicInfo.getVoltageLevel());
                cell6.setCellValue(basicInfo.getProjectCategory());
                cell7.setCellValue(basicInfo.getScale());
                cell8.setCellValue(basicInfo.getDesignUnit());
                cell9.setCellValue(basicInfo.getConstructionUnit());
                cell10.setCellValue(basicInfo.getControlUnit());
                cell11.setCellValue(basicInfo.getPreliminaryDesignInternalReview());
                cell12.setCellValue(basicInfo.getPreliminaryDesignReviewPlan());
                cell13.setCellValue(basicInfo.getPreliminaryExternalAuditReview());
                cell14.setCellValue(basicInfo.getPreliminaryDesignReviewComments());
                cell15.setCellValue(basicInfo.getConstructionDrawingReviewPlan());
                cell16.setCellValue(basicInfo.getConstructionDrawingReview());
                cell17.setCellValue(basicInfo.getConstructionDrawReview());
                cell18.setCellValue(basicInfo.getConstructionPlanBatch());
                cell19.setCellValue(basicInfo.getConstructionAwardDate());
            }

            String str = URLEncoder.encode("基建项目基本信息.xlsx", "UTF8");
            response.setHeader("Content-Disposition", "attachment;filename="+str);
            response.setContentType("application/vnd.ms-excel;charset=UTF-8");
            OutputStream outputStream = response.getOutputStream();
            workbook.write(outputStream);
            outputStream.flush();
            outputStream.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * 基建 - 施工计划批次信息 - 导出数据
     * @param response
     * @param workbook
     * @param list
     */
    public void exportBatch(HttpServletResponse response, XSSFWorkbook workbook, List<ConstructionBatch> list){
        try {
            int index = 1;//第一列序号
            int rowNum = 1;//数据起始列
            Sheet sheet = workbook.getSheetAt(0);
            for(int i=0;i<list.size();i++){
                Row row = sheet.createRow(rowNum+i);
                Cell cell0 = crateCell(workbook,row,0); //序号
                Cell cell1 = crateCell(workbook,row,1); //批次名称
                Cell cell2 = crateCell(workbook,row,2); //批次编号
                Cell cell3 = crateCell(workbook,row,3); //施工图纸收集截止时间
                Cell cell4 = crateCell(workbook,row,4); //拟定开标时间

                ConstructionBatch batch = list.get(i);

                cell0.setCellValue(String.valueOf(index++));
                cell1.setCellValue(batch.getBatchName());
                cell2.setCellValue(batch.getBatchNumber());
                cell3.setCellValue(batch.getEndTime());
                cell4.setCellValue(batch.getBidOpenTime());
            }

            String str = URLEncoder.encode("基建项目施工计划批次信息.xlsx", "UTF8");
            response.setHeader("Content-Disposition", "attachment;filename="+str);
            response.setContentType("application/vnd.ms-excel;charset=UTF-8");
            OutputStream outputStream = response.getOutputStream();
            workbook.write(outputStream);
            outputStream.flush();
            outputStream.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * 创建Cell对象 同时设置style
     * @param workbook
     * @param row
     * @param num
     * @return
     */
    Cell crateCell(XSSFWorkbook workbook,Row row, int num){
        Cell cell = row.createCell(num);
        if(style == null){
            style =workbook.createCellStyle();
            style.setWrapText(true);
            style.setVerticalAlignment(XSSFCellStyle.VERTICAL_CENTER);
        }
        cell.setCellStyle(style);
        return cell;
    }

    /**
     * 传入excel模板名称 获取workbook对象
     * @param fileName excel模板名称
     * @return
     */
    public  XSSFWorkbook getWorkbook(String fileName){
        InputStream inputStream = null;
        XSSFWorkbook workbook = null;
        try {
            File file = new File(this.getClass().getResource("/").getPath() + "/freemarker/excelmodel/"+fileName+".xlsx");
            inputStream = new FileInputStream(file);// 将excel文件转为输入流
            workbook = new XSSFWorkbook(inputStream);// 创建个workbook，
        } catch (Exception e) {
            e.printStackTrace();
        }
        return workbook;
    }
}
