package com.jeeplus.modules.cg.infrastructure.util;

import com.jeeplus.modules.cg.infrastructure.entity.ConstructionBatch;
import com.jeeplus.modules.cg.infrastructure.entity.InfrastructureBasicInfo;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Row;

import java.util.ArrayList;
import java.util.List;

/**
 * @author: 王强
 * @create: 2023-05-08 15:32
 **/
public class InfrastructureExcelImportUtil {

    /**
     * 基建 - 基础信息 - 导入数据
     *
     * @param importUtil
     * @return List<BudgetStats> 导入表格数据
     */
    public static List<InfrastructureBasicInfo> getBudgetUtil(ImportUtil importUtil, List<String> proIdList) throws Exception {
        int lastRow = importUtil.getLastDataRowNum();
        List<InfrastructureBasicInfo> list = new ArrayList<InfrastructureBasicInfo>();
        InfrastructureBasicInfo basicInfo = null;

        for(int i=1; i<=lastRow;i++) {
            basicInfo = new InfrastructureBasicInfo();
            Row row = importUtil.getRow(i);

            //获取项目编码
            String projectReserveId = (String) importUtil.getCellValue(row, 3);
            if (StringUtils.isNotBlank(projectReserveId)) {

                basicInfo.setStateGridCode((String) importUtil.getCellValue(row, 1));
                basicInfo.setProjectName((String) importUtil.getCellValue(row, 2));
                basicInfo.setProjectCode((String) importUtil.getCellValue(row, 3));
                basicInfo.setIndividualProjectName((String) importUtil.getCellValue(row, 4));
                basicInfo.setVoltageLevel((String) importUtil.getCellValue(row, 5));
                basicInfo.setProjectCategory((String) importUtil.getCellValue(row, 6));
                basicInfo.setScale((String) importUtil.getCellValue(row, 7));
                basicInfo.setDesignUnit((String) importUtil.getCellValue(row, 8));
                basicInfo.setConstructionUnit((String) importUtil.getCellValue(row, 9));
                basicInfo.setControlUnit((String) importUtil.getCellValue(row, 10));

                list.add(basicInfo);
            }
        }
        return list;
    }

    /**
     * 基建 - 施工计划批次信息 - 导入数据
     *
     * @param importUtil
     * @return List<BudgetStats> 导入表格数据
     */
    public static List<ConstructionBatch> getBatchUtil(ImportUtil importUtil) throws Exception {
        int lastRow = importUtil.getLastDataRowNum();
        List<ConstructionBatch> list = new ArrayList<ConstructionBatch>();
        ConstructionBatch batch = null;

        for(int i=1; i<=lastRow;i++) {
            batch = new ConstructionBatch();
            Row row = importUtil.getRow(i);

            //获取批次编号
            String projectReserveId = (String) importUtil.getCellValue(row, 2);
            if (StringUtils.isNotBlank(projectReserveId)) {

                batch.setBatchName((String) importUtil.getCellValue(row, 1));
                batch.setBatchNumber((String) importUtil.getCellValue(row, 2));
                String endTime = ChangeTimeUtil.getOne().determineTimeFormat((String) importUtil.getCellValue(row, 3));
                batch.setEndTime(endTime);
                String openTime = ChangeTimeUtil.getOne().determineTimeFormat((String) importUtil.getCellValue(row, 4));
                batch.setBidOpenTime(openTime);
//                batch.setEndTime((String) importUtil.getCellValue(row, 3));
//                batch.setBidOpenTime((String) importUtil.getCellValue(row, 4));

                list.add(batch);
            }
        }
        return list;
    }
}
