package com.jeeplus.modules.cg.infrastructure.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.infrastructure.entity.ConstructionBatch;
import com.jeeplus.modules.cg.infrastructure.service.ConstructionBatchService;
import com.jeeplus.modules.cg.infrastructure.util.ChangeTimeUtil;
import com.jeeplus.modules.cg.infrastructure.util.InfrastructureExcelExportUtil;
import com.jeeplus.modules.cg.infrastructure.util.InfrastructureExcelImportUtil;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 基建 - 施工计划批次信息 - controller
 * @author: 王强
 * @create: 2023-05-09 10:53
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/infrastructure/constructionBatch")
public class ConstructionBatchController extends BaseController {

    @Autowired
    private ConstructionBatchService batchService;

    @ModelAttribute
    public ConstructionBatch get(@RequestParam(required = false) String id) throws ParseException {
        ConstructionBatch entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = batchService.get(id);
            DateFormat inputFormat = new SimpleDateFormat("yyyy/MM/dd");
            DateFormat outputFormat = new SimpleDateFormat("yyyy-MM-dd");
            Date end = inputFormat.parse(entity.getEndTime());
            Date open = inputFormat.parse(entity.getBidOpenTime());
            String endTime = outputFormat.format(end);
            String openTime = outputFormat.format(open);
            entity.setEndTime(endTime);
            entity.setBidOpenTime(openTime);
        }
        if (entity == null) {
            entity = new ConstructionBatch();
        }
        return entity;
    }

    /**
     * 增加，编辑表单页面
     * @param batch
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:infrastructure:constructionBatch:add","cg:infrastructure:constructionBatch:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(ConstructionBatch batch, Model model) {
        model.addAttribute("batch", batch);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(batch.getId())){
            return "modules/cg/infrastructure/constructionBatch/batchAddForm";
        }
        return "modules/cg/infrastructure/constructionBatch/batchUpdateForm";
    }

    /**
     * 保存表单
     * @param batch
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:constructionBatch:add"},logical=Logical.OR)
    @RequestMapping(value = "save")
    public AjaxJson save(ConstructionBatch batch){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(batch);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        ConstructionBatch constructionBatch = new ConstructionBatch();

        constructionBatch.setBatchNumber(batch.getBatchNumber());
        int count = batchService.getAllInfo(constructionBatch);
        if (count > 0 ){
            j.setSuccess(false);
            j.setMsg( "批次编号为" + batch.getBatchNumber() + "的施工计划批次信息已存在，不对数据进行保存！");
            return j;
        }
        String endTime = ChangeTimeUtil.getOne().determineTimeFormat(batch.getEndTime());
        batch.setEndTime(endTime);
        String openTime = ChangeTimeUtil.getOne().determineTimeFormat(batch.getBidOpenTime());
        batch.setBidOpenTime(openTime);
        //新增或编辑表单保存
        batchService.save(batch);//保存
        j.setSuccess(true);
        j.setMsg("保存基建项目基本信息成功");
        return j;
    }

    /**
     * 修改表单
     * @param batch
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:constructionBatch:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(ConstructionBatch batch) {
        String endTime = ChangeTimeUtil.getOne().determineTimeFormat(batch.getEndTime());
        batch.setEndTime(endTime);
        String openTime = ChangeTimeUtil.getOne().determineTimeFormat(batch.getBidOpenTime());
        batch.setBidOpenTime(openTime);
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(batch);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //新增或编辑表单保存
        batchService.update(batch);
        j.setSuccess(true);
        j.setMsg("修改基建项目基本信息成功");
        return j;
    }

    /**
     * 基建 - 施工计划批次信息 - 列表页面
     * @param batch
     * @param model
     * @return
     */
    @RequiresPermissions("cg:infrastructure:constructionBatch:list")
    @RequestMapping(value = "budgetList")
    public String budgetList(ConstructionBatch batch, Model model) {
        model.addAttribute("batch", batch);
        return "modules/cg/infrastructure/constructionBatch/constructionBatch";
    }

    /**
     * 基建 - 施工计划批次信息 - 列表数据
     * @param batch
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:infrastructure:constructionBatch:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(ConstructionBatch batch, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {


        Page<ConstructionBatch> page = batchService.findPage(new Page<ConstructionBatch>(request, response), batch);
        return getBootstrapData(page);
    }

    /**
     * 删除表单
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:constructionBatch:del"},logical= Logical.OR)
    @RequestMapping(value = "deleteAll")
    public AjaxJson delete(String ids){
        AjaxJson j = new AjaxJson();
        String idArray[] =ids.split(",");
        for(String id : idArray){
            try {
                //删除前判断该项目是否在流程中
                ConstructionBatch batch = batchService.get(id);
                batchService.delete(batch);
            }catch (Exception e){
                j.setSuccess(false);
                j.setMsg("存在关联数据，无法删除！" + e);
                return j;
            }

        }
        j.setMsg("删除储备项目基本信息成功");
        return j;
    }

    /**
     *  导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:infrastructure:constructionBatch:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);

            //获取导入表格所有数据
            List<ConstructionBatch> batches = InfrastructureExcelImportUtil.getBatchUtil(importUtil);

            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = batchService.getExistProjectList(batches);
            //未存在数据
            List<ConstructionBatch> withoutList = (List<ConstructionBatch>) map.get("without");
            //已存在数据
            List<ConstructionBatch> existList = (List<ConstructionBatch>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                batchService.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (ConstructionBatch batch : existList) {
                    batchService.update(batch);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条项目储备信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入储备项目概预算信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:infrastructure:constructionBatch:export")
    @RequestMapping(value = "export")
    public void exportExcel(ConstructionBatch batch, HttpServletRequest request, HttpServletResponse response) {
        List<ConstructionBatch> list = batchService.exportFindList(batch);
        //生成序列号
        int i = 1;
        for (ConstructionBatch s : list) {
            s.setId(String.valueOf(i));
            i++;
        }

        InfrastructureExcelExportUtil util = InfrastructureExcelExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("constructionBatch");
        util.exportBatch(response,workbook,list);
    }

}
