package com.jeeplus.modules.cg.infrastructure.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.infrastructure.entity.ConstructionBatch;
import com.jeeplus.modules.cg.infrastructure.entity.InfrastructureBasicInfo;
import com.jeeplus.modules.cg.infrastructure.entity.ReviewPlanArrangement;
import com.jeeplus.modules.cg.infrastructure.service.ConstructionBatchService;
import com.jeeplus.modules.cg.infrastructure.service.InfrastructureBasicInfoService;
import com.jeeplus.modules.cg.infrastructure.service.ReviewPlanArrangementService;
import com.jeeplus.modules.cg.infrastructure.util.ChangeTimeUtil;
import com.jeeplus.modules.cg.infrastructure.util.InfrastructureExcelExportUtil;
import com.jeeplus.modules.cg.infrastructure.util.InfrastructureExcelImportUtil;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author: 王强
 * @create: 2023-05-08 14:25
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/infrastructure/infrastructureBasicInfo")
public class InfrastructureBasicInfoController extends BaseController {

    @Autowired
    private ConstructionBatchService batchService;

    @Autowired
    private InfrastructureBasicInfoService infoService;

    @Autowired
    private ReviewPlanArrangementService arrangementService;

    @ModelAttribute
    public InfrastructureBasicInfo get(@RequestParam(required = false) String id) {
        InfrastructureBasicInfo entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = infoService.get(id);
        }
        if (entity == null) {
            entity = new InfrastructureBasicInfo();
        }
        return entity;
    }

    /**
     * 查看评审计划安排表页面
     */
    @RequiresPermissions(value={"cg:infrastructure:reviewPlan:list"},logical= Logical.OR)
    @RequestMapping(value = "view")
    public String view(ReviewPlanArrangement arrangement, Model model) {
        model.addAttribute("arrangement", arrangement);
        return "modules/cg/infrastructure/reviewPlan/reviewPlan";
    }

    /**
     * 获取评审计划安排表页面数据
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:reviewPlan:list"},logical= Logical.OR)
    @RequestMapping(value = "reviewList")
    public Map<String, Object> reviewList(ReviewPlanArrangement arrangement, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {

        Page<ReviewPlanArrangement> page = new Page<>(request,response);
        List<ReviewPlanArrangement> list = new ArrayList<>();

        //获取所有的施工图纸收集截止时间
        List<ConstructionBatch> batchList = batchService.getAllDeadLine();
        ChangeTimeUtil util = ChangeTimeUtil.getOne();
        //根据id查基础信息表中的项目名称、项目编码 （此id为前端传来的基础表id）
        InfrastructureBasicInfo basicInfo = infoService.get(arrangement.getId());
        String is = "";
        if (basicInfo.getProjectCategory().equals("变电")){
            is = "是";
        } else {
            is = "否";
        }
        //根据项目编码查询是否有评审计划安排相关数据
        ReviewPlanArrangement planArrangement = arrangementService.getByCode(basicInfo.getProjectCode());
        if (null == planArrangement){
            ReviewPlanArrangement display = setAttribute2(basicInfo);

            display.setIsItInvolved(is);
            list.add(display);

            ReviewPlanArrangement newDis = setAttribute(basicInfo);
            List<String> auditList = util.getExternalReview(newDis.getPreliminaryDesignReviewPlan());

            for (int i=0;i<auditList.size();i++){
                newDis = setAttribute(basicInfo);
                newDis.setPreliminaryExternalAuditReview(auditList.get(i));
                List<String> comments = util.getReviewComments(auditList.get(i));
                for (int j=0;j<comments.size();j++){
                    newDis = setAttribute(basicInfo);
                    if (is.equals("是")){
                        newDis.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                    }else {
                        newDis.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                    }

                    List<String> drawReview = util.getDrawingReview(newDis.getConstructionDrawingReviewPlan());
                    for (int k=0;k<drawReview.size();k++){
                        List<String> stringList = util.getDrawReview(drawReview.get(k));
                        for (int z=0;z<stringList.size();z++){
                            newDis = setAttribute(basicInfo);
                            newDis.setPhase("预计时间");
                            newDis.setIsItInvolved(is);
                            newDis.setPreliminaryExternalAuditReview(auditList.get(i));
                            newDis.setPreliminaryDesignReviewComments(newDis.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                            if (is.equals("是")){
                                newDis.setConstructionDrawingReviewPlan(newDis.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                            }else {
                                newDis.setConstructionDrawingReviewPlan(newDis.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                            }
                            newDis.setConstructionDrawingReview(drawReview.get(k));
                            newDis.setConstructionDrawReview(stringList.get(z));
                            ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                            if (null != timeInterval) {
                                newDis.setBatchNumber(timeInterval.getBatchNumber());
                                newDis.setBidOpenTime(timeInterval.getBidOpenTime());
                            }
                            list.add(newDis);
                        }
                    }

                }
            }
        } else {
            //判断哪一个项目阶段有实际时间
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignInternalReview())){

                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement arrangement1 = setAttribute3(planArrangement);

                List<String> auditList = util.getExternalReview(arrangement1.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));

                    for (int j=0;j<comments.size();j++){
                        arrangement1 = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }

                        List<String> drawReview = util.getDrawingReview(arrangement1.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                arrangement1 = setAttribute3(planArrangement);
                                arrangement1.setIsItInvolved(is);
                                arrangement1.setPhase("预计时间");
                                arrangement1.setApprovalTime(planArrangement.getApprovalTime());
                                arrangement1.setPreliminaryExternalAuditReview(auditList.get(i));
                                arrangement1.setPreliminaryDesignReviewComments(arrangement1.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                arrangement1.setConstructionDrawingReview(drawReview.get(k));
                                arrangement1.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    arrangement1.setBatchNumber(timeInterval.getBatchNumber());
                                    arrangement1.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(arrangement1);
                            }
                        }

                    }
                }

            }
            // 当（二）初步设计评审计划  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignReviewPlan())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> auditList = util.getExternalReview(ment.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        ment = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            ment.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            ment.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }
                        List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                ment = setAttribute3(planArrangement);
                                ment.setPhase("预计时间");
                                ment.setIsItInvolved(is);
                                ment.setApprovalTime(planArrangement.getApprovalTime());
                                ment.setPreliminaryDesignReviewPlan("");
                                ment.setPreliminaryExternalAuditReview(auditList.get(i));
                                ment.setPreliminaryDesignReviewComments(ment.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                ment.setConstructionDrawingReview(drawReview.get(k));
                                ment.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    ment.setBatchNumber(timeInterval.getBatchNumber());
                                    ment.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(ment);
                            }
                        }

                    }
                }
            }
            // 当（三）初设外审评审  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryExternalAuditReview())){
                list.clear();
                planArrangement.setPhase("实际时间");
                planArrangement.setIsItInvolved(is);
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> comments = util.getReviewComments(ment.getPreliminaryExternalAuditReview());
                for (int j=0;j<comments.size();j++){
                    ment = setAttribute3(planArrangement);
                    if (is.equals("是")){
                        ment.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                    }else {
                        ment.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                    }
                    List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                    for (int k=0;k<drawReview.size();k++){
                        List<String> stringList = util.getDrawReview(drawReview.get(k));
                        for (int z=0;z<stringList.size();z++){
                            ment = setAttribute3(planArrangement);
                            ment.setPhase("预计时间");
                            ment.setIsItInvolved(is);
                            ment.setApprovalTime(planArrangement.getApprovalTime());
                            ment.setPreliminaryDesignReviewPlan("");
                            ment.setPreliminaryExternalAuditReview("");
                            ment.setPreliminaryDesignReviewComments(ment.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                            if (is.equals("是")){
                                ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                            }else {
                                ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                            }
                            ment.setConstructionDrawingReview(drawReview.get(k));
                            ment.setConstructionDrawReview(stringList.get(z));
                            ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                            if (null != timeInterval) {
                                ment.setBatchNumber(timeInterval.getBatchNumber());
                                ment.setBidOpenTime(timeInterval.getBidOpenTime());
                            }
                            list.add(ment);
                        }
                    }

                }
            }
            // 当（四）初设评审意见  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignReviewComments())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                String s = "";
                if (is.equals("是")){
                    s = util.getReviewPlan(ment.getPreliminaryDesignReviewComments());
                }else {
                    s = util.getReviewPlan2(ment.getPreliminaryDesignReviewComments());
                }
                ment.setConstructionDrawingReviewPlan(s);
                List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        ment = setAttribute3(planArrangement);
                        ment.setPhase("预计时间");
                        ment.setIsItInvolved(is);
                        ment.setApprovalTime(planArrangement.getApprovalTime());
                        ment.setPreliminaryDesignReviewPlan("");
                        ment.setPreliminaryExternalAuditReview("");
                        ment.setPreliminaryDesignReviewComments("");
                        ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments() + "&" + s);
                        ment.setConstructionDrawingReview(drawReview.get(k));
                        ment.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            ment.setBatchNumber(timeInterval.getBatchNumber());
                            ment.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(ment);
                    }
                }
            }
            // 当（五）施工图评审计划  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawingReviewPlan())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        ment = setAttribute3(planArrangement);
                        ment.setPhase("预计时间");
                        ment.setApprovalTime(planArrangement.getApprovalTime());
                        ment.setPreliminaryDesignReviewPlan("");
                        ment.setPreliminaryExternalAuditReview("");
                        ment.setPreliminaryDesignReviewComments("");
                        ment.setConstructionDrawingReviewPlan("");
                        ment.setConstructionDrawingReview(drawReview.get(k));
                        ment.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            ment.setBatchNumber(timeInterval.getBatchNumber());
                            ment.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(ment);
                    }
                }
            }
            // 当（六）施工图评审  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawingReview())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> stringList = util.getDrawReview(ment.getConstructionDrawingReview());
                for (int z=0;z<stringList.size();z++){
                    ment = setAttribute3(planArrangement);
                    ment.setPhase("预计时间");
                    ment.setApprovalTime(planArrangement.getApprovalTime());
                    ment.setPreliminaryDesignReviewPlan("");
                    ment.setPreliminaryExternalAuditReview("");
                    ment.setPreliminaryDesignReviewComments("");
                    ment.setConstructionDrawingReviewPlan("");
                    ment.setConstructionDrawingReview("");
                    ment.setConstructionDrawReview(stringList.get(z));
                    ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                    if (null != timeInterval) {
                        ment.setBatchNumber(timeInterval.getBatchNumber());
                        ment.setBidOpenTime(timeInterval.getBidOpenTime());
                    }
                    list.add(ment);
                }
            }
            // 当（七）施工图评审意见  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawReview())){
                list.clear();

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);
                ment.setPhase("实际时间");

                list.add(ment);
            }

            // 当实际时间都没有的情况下
            if (StringUtils.isBlank(planArrangement.getPreliminaryDesignInternalReview())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryDesignReviewPlan())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryExternalAuditReview())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryDesignReviewComments())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawingReviewPlan())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawingReview())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawReview())){

                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement arrangement1 = setAttribute3(planArrangement);
                arrangement1.setPreliminaryDesignInternalReview(util.getMonth());
                arrangement1.setPreliminaryDesignReviewPlan(util.getDesignReview(arrangement1.getPreliminaryDesignInternalReview()));

                List<String> auditList = util.getExternalReview(arrangement1.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));

                    for (int j=0;j<comments.size();j++){
                        arrangement1 = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }

                        List<String> drawReview = util.getDrawingReview(arrangement1.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                arrangement1 = setAttribute3(planArrangement);
                                arrangement1.setPhase("预计时间");
                                arrangement1.setIsItInvolved(is);
                                arrangement1.setApprovalTime(planArrangement.getApprovalTime());
                                arrangement1.setPreliminaryDesignInternalReview(util.getMonth());
                                arrangement1.setPreliminaryExternalAuditReview(auditList.get(i));
                                arrangement1.setPreliminaryDesignReviewComments(arrangement1.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                                }else {
                                    arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                                }
                                arrangement1.setConstructionDrawingReview(drawReview.get(k));
                                arrangement1.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    arrangement1.setBatchNumber(timeInterval.getBatchNumber());
                                    arrangement1.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(arrangement1);
                            }
                        }

                    }
                }


            }

        }

        for (int i=0;i<list.size();i++){
            if (i==0){
                ReviewPlanArrangement planArrangement1 = list.get(i);
                planArrangement1.setPreliminaryDesignInternalReview(planArrangement1.getPreliminaryDesignInternalReview().replace("/","-"));
                planArrangement1.setPreliminaryDesignReviewPlan(planArrangement1.getPreliminaryDesignReviewPlan().replace("/","-"));
                planArrangement1.setPreliminaryExternalAuditReview(planArrangement1.getPreliminaryExternalAuditReview().replace("/","-"));
                planArrangement1.setPreliminaryDesignReviewComments(planArrangement1.getPreliminaryDesignReviewComments().replace("/","-"));
                planArrangement1.setConstructionDrawingReviewPlan(planArrangement1.getConstructionDrawingReviewPlan().replace("/","-"));
                planArrangement1.setConstructionDrawingReview(planArrangement1.getConstructionDrawingReview().replace("/","-"));
                planArrangement1.setConstructionDrawReview(planArrangement1.getConstructionDrawReview().replace("/","-"));
            }
        }

        page.setList(list);

        return getBootstrapData(page);

    }

    /**
     * 获取评审计划安排表页面数据
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:reviewPlan:list"},logical= Logical.OR)
    @RequestMapping(value = "reviewList2")
    public Map<String, Object> reviewList2(ReviewPlanArrangement arrangement, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {

        Page<ReviewPlanArrangement> page = new Page<>(request,response);
        List<ReviewPlanArrangement> list = new ArrayList<>();

        //获取所有的施工图纸收集截止时间
        List<ConstructionBatch> batchList = batchService.getAllDeadLine();
        ChangeTimeUtil util = ChangeTimeUtil.getOne();

        //根据id查基础信息表中的项目名称、项目编码 （此id为前端传来的基础表id）
        InfrastructureBasicInfo basicInfo = infoService.get(arrangement.getId());
        String is = "";
        if (basicInfo.getProjectCategory().equals("变电")){
            is = "是";
        } else {
            is = "否";
        }
        //根据项目编码查询是否有评审计划安排相关数据
        ReviewPlanArrangement planArrangement = arrangementService.getByCode(basicInfo.getProjectCode());
        if (null == planArrangement){

            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignInternalReview())){

                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                list.add(plan);
                List<String> auditList = util.getExternalReview(util.getDesignReview(arrangement.getPreliminaryDesignInternalReview()));

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                for (int i=0;i<auditList.size();i++){
                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        attribute = setAttribute2(basicInfo);
                        if (is.equals("是")){
                            attribute.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            attribute.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }
                        List<String> drawReview = util.getDrawingReview(attribute.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                attribute = setAttribute2(basicInfo);
                                attribute.setPhase("预计时间");
                                attribute.setIsItInvolved(is);
                                attribute.setPreliminaryDesignReviewPlan(util.getDesignReview(plan.getPreliminaryDesignInternalReview()));;
                                attribute.setPreliminaryDesignInternalReview("");
                                attribute.setPreliminaryExternalAuditReview(auditList.get(i));
                                attribute.setPreliminaryDesignReviewComments(attribute.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                attribute.setConstructionDrawingReview(drawReview.get(k));
                                attribute.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    attribute.setBatchNumber(timeInterval.getBatchNumber());
                                    attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(attribute);
                            }
                        }
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignReviewPlan())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                list.add(plan);
                List<String> auditList = util.getExternalReview(util.getDesignReview(arrangement.getPreliminaryDesignInternalReview()));

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                for (int i=0;i<auditList.size();i++){
                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        attribute = setAttribute2(basicInfo);
                        if (is.equals("是")){
                            attribute.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            attribute.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }
                        List<String> drawReview = util.getDrawingReview(attribute.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                attribute = setAttribute2(basicInfo);
                                attribute.setPhase("预计时间");
                                attribute.setIsItInvolved(is);
                                attribute.setPreliminaryDesignReviewPlan("");
                                attribute.setPreliminaryDesignInternalReview("");
                                attribute.setPreliminaryExternalAuditReview(auditList.get(i));
                                attribute.setPreliminaryDesignReviewComments(attribute.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                attribute.setConstructionDrawingReview(drawReview.get(k));
                                attribute.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    attribute.setBatchNumber(timeInterval.getBatchNumber());
                                    attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(attribute);
                            }
                        }
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryExternalAuditReview())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                list.add(plan);

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                List<String> comments = util.getReviewComments(arrangement.getPreliminaryExternalAuditReview());
                for (int j=0;j<comments.size();j++){
                    attribute = setAttribute2(basicInfo);
                    if (is.equals("是")){
                        attribute.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                    }else {
                        attribute.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                    }
                    List<String> drawReview = util.getDrawingReview(attribute.getConstructionDrawingReviewPlan());
                    for (int k=0;k<drawReview.size();k++){
                        List<String> stringList = util.getDrawReview(drawReview.get(k));
                        for (int z=0;z<stringList.size();z++){
                            attribute = setAttribute2(basicInfo);
                            attribute.setPhase("预计时间");
                            attribute.setIsItInvolved(is);
                            attribute.setPreliminaryDesignReviewPlan("");
                            attribute.setPreliminaryDesignInternalReview("");
                            attribute.setPreliminaryExternalAuditReview("");
                            attribute.setPreliminaryDesignReviewComments(attribute.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                            if (is.equals("是")){
                                attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                            }else {
                                attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                            }
                            attribute.setConstructionDrawingReview(drawReview.get(k));
                            attribute.setConstructionDrawReview(stringList.get(z));
                            ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                            if (null != timeInterval) {
                                attribute.setBatchNumber(timeInterval.getBatchNumber());
                                attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                            }
                            list.add(attribute);
                        }
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignReviewComments())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                plan.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
                list.add(plan);

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                attribute = setAttribute2(basicInfo);
                if (is.equals("是")){
                    attribute.setConstructionDrawingReviewPlan(util.getReviewPlan(arrangement.getPreliminaryDesignReviewComments()));
                }else {
                    attribute.setConstructionDrawingReviewPlan(util.getReviewPlan2(arrangement.getPreliminaryDesignReviewComments()));
                }
                List<String> drawReview = util.getDrawingReview(attribute.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        attribute = setAttribute2(basicInfo);
                        attribute.setPhase("预计时间");
                        attribute.setIsItInvolved(is);
                        attribute.setPreliminaryDesignReviewPlan("");
                        attribute.setPreliminaryDesignInternalReview("");
                        attribute.setPreliminaryExternalAuditReview("");
                        attribute.setPreliminaryDesignReviewComments("");
                        if (is.equals("是")){
                            attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(arrangement.getPreliminaryDesignReviewComments()));
                        }else {
                            attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(arrangement.getPreliminaryDesignReviewComments()));
                        }
                        attribute.setConstructionDrawingReview(drawReview.get(k));
                        attribute.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            attribute.setBatchNumber(timeInterval.getBatchNumber());
                            attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(attribute);
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawingReviewPlan())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                plan.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
                plan.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan());
                list.add(plan);

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                List<String> drawReview = util.getDrawingReview(arrangement.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        attribute = setAttribute2(basicInfo);
                        attribute.setPhase("预计时间");
                        attribute.setIsItInvolved(is);
                        attribute.setPreliminaryDesignReviewPlan("");
                        attribute.setPreliminaryDesignInternalReview("");
                        attribute.setPreliminaryExternalAuditReview("");
                        attribute.setPreliminaryDesignReviewComments("");
                        if (is.equals("是")){
                            attribute.setConstructionDrawingReviewPlan("");
                        }else {
                            attribute.setConstructionDrawingReviewPlan("");
                        }
                        attribute.setConstructionDrawingReview(drawReview.get(k));
                        attribute.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            attribute.setBatchNumber(timeInterval.getBatchNumber());
                            attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(attribute);
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawingReview())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                plan.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
                plan.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan());
                plan.setConstructionDrawingReview(arrangement.getConstructionDrawingReview());
                list.add(plan);

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                List<String> stringList = util.getDrawReview(arrangement.getConstructionDrawingReview());
                for (int z=0;z<stringList.size();z++){
                    attribute = setAttribute2(basicInfo);
                    attribute.setPhase("预计时间");
                    attribute.setIsItInvolved(is);
                    attribute.setPreliminaryDesignReviewPlan("");
                    attribute.setPreliminaryDesignInternalReview("");
                    attribute.setPreliminaryExternalAuditReview("");
                    attribute.setPreliminaryDesignReviewComments("");
                    if (is.equals("是")){
                        attribute.setConstructionDrawingReviewPlan("");
                    }else {
                        attribute.setConstructionDrawingReviewPlan("");
                    }
                    attribute.setConstructionDrawingReview("");
                    attribute.setConstructionDrawReview(stringList.get(z));
                    ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                    if (null != timeInterval) {
                        attribute.setBatchNumber(timeInterval.getBatchNumber());
                        attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                    }
                    list.add(attribute);
                }
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawReview())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                plan.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
                plan.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan());
                plan.setConstructionDrawingReview(arrangement.getConstructionDrawingReview());
                plan.setConstructionDrawReview(arrangement.getConstructionDrawReview());
                list.add(plan);
            }

            if (StringUtils.isBlank(arrangement.getPreliminaryDesignInternalReview())&&
                    StringUtils.isBlank(arrangement.getPreliminaryDesignReviewPlan())&&
                    StringUtils.isBlank(arrangement.getPreliminaryExternalAuditReview())&&
                    StringUtils.isBlank(arrangement.getPreliminaryDesignReviewComments())&&
                    StringUtils.isBlank(arrangement.getConstructionDrawingReviewPlan())&&
                    StringUtils.isBlank(arrangement.getConstructionDrawingReview())&&
                    StringUtils.isBlank(arrangement.getConstructionDrawReview())){
                ReviewPlanArrangement display = setAttribute2(basicInfo);

                display.setIsItInvolved(is);
                list.add(display);

                ReviewPlanArrangement newDis = setAttribute(basicInfo);

                List<String> auditList = util.getExternalReview(newDis.getPreliminaryDesignReviewPlan());

                for (int i=0;i<auditList.size();i++){
                    newDis = setAttribute(basicInfo);
                    newDis.setPreliminaryExternalAuditReview(auditList.get(i));
                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        newDis = setAttribute(basicInfo);
                        if (is.equals("是")){
                            newDis.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            newDis.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }

                        List<String> drawReview = util.getDrawingReview(newDis.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                newDis = setAttribute(basicInfo);
                                newDis.setPhase("预计时间");
                                newDis.setIsItInvolved(is);
                                newDis.setPreliminaryExternalAuditReview(auditList.get(i));
                                newDis.setPreliminaryDesignReviewComments(newDis.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    newDis.setConstructionDrawingReviewPlan(newDis.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    newDis.setConstructionDrawingReviewPlan(newDis.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                newDis.setConstructionDrawingReview(drawReview.get(k));
                                newDis.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    newDis.setBatchNumber(timeInterval.getBatchNumber());
                                    newDis.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(newDis);
                            }
                        }

                    }
                }
            }


        } else {
            planArrangement.setIsItInvolved(is);
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignInternalReview())){
                planArrangement.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignReviewPlan())){
                planArrangement.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryExternalAuditReview())){
                planArrangement.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignReviewComments())){
                planArrangement.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawingReviewPlan())){
                planArrangement.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan());
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawingReview())){
                planArrangement.setConstructionDrawingReview(arrangement.getConstructionDrawingReview());
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawReview())){
                planArrangement.setConstructionDrawReview(arrangement.getConstructionDrawReview());
            }

            //判断哪一个项目阶段有实际时间
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignInternalReview())){

                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement arrangement1 = setAttribute3(planArrangement);

                List<String> auditList = util.getExternalReview(arrangement1.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));

                    for (int j=0;j<comments.size();j++){
                        arrangement1 = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        } else {
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }


                        List<String> drawReview = util.getDrawingReview(arrangement1.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                arrangement1 = setAttribute3(planArrangement);
                                arrangement1.setPhase("预计时间");
                                arrangement1.setApprovalTime(planArrangement.getApprovalTime());
                                arrangement1.setPreliminaryExternalAuditReview(auditList.get(i));
                                arrangement1.setPreliminaryDesignReviewComments(comments.get(j));
                                arrangement1.setPreliminaryDesignReviewComments(arrangement1.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                arrangement1.setConstructionDrawingReview(drawReview.get(k));
                                arrangement1.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    arrangement1.setBatchNumber(timeInterval.getBatchNumber());
                                    arrangement1.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(arrangement1);
                            }
                        }

                    }
                }

            }
            // 当（二）初步设计评审计划  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignReviewPlan())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> auditList = util.getExternalReview(ment.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        ment = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            ment.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        } else {
                            ment.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }
                        List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                ment = setAttribute3(planArrangement);
                                ment.setPhase("预计时间");
                                ment.setApprovalTime(planArrangement.getApprovalTime());
                                ment.setPreliminaryDesignReviewPlan("");
                                ment.setPreliminaryExternalAuditReview(auditList.get(i));
                                ment.setPreliminaryDesignReviewComments(ment.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                ment.setConstructionDrawingReview(drawReview.get(k));
                                ment.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    ment.setBatchNumber(timeInterval.getBatchNumber());
                                    ment.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(ment);
                            }
                        }

                    }
                }
            }
            // 当（三）初设外审评审  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryExternalAuditReview())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> comments = util.getReviewComments(ment.getPreliminaryExternalAuditReview());
                for (int j=0;j<comments.size();j++){
                    ment = setAttribute3(planArrangement);
                    if (is.equals("是")){
                        ment.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                    } else {
                        ment.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                    }
                    List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                    for (int k=0;k<drawReview.size();k++){
                        List<String> stringList = util.getDrawReview(drawReview.get(k));
                        for (int z=0;z<stringList.size();z++){
                            ment = setAttribute3(planArrangement);
                            ment.setPhase("预计时间");
                            ment.setApprovalTime(planArrangement.getApprovalTime());
                            ment.setPreliminaryDesignReviewPlan("");
                            ment.setPreliminaryExternalAuditReview("");
                            ment.setPreliminaryDesignReviewComments(ment.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                            if (is.equals("是")){
                                ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                            }else {
                                ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                            }
                            ment.setConstructionDrawingReview(drawReview.get(k));
                            ment.setConstructionDrawReview(stringList.get(z));
                            ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                            if (null != timeInterval) {
                                ment.setBatchNumber(timeInterval.getBatchNumber());
                                ment.setBidOpenTime(timeInterval.getBidOpenTime());
                            }
                            list.add(ment);
                        }
                    }

                }
            }
            // 当（四）初设评审意见  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignReviewComments())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);


                String s = "";
                if (is.equals("是")){
                    s = util.getReviewPlan(ment.getPreliminaryDesignReviewComments());
                } else {
                    s = util.getReviewPlan2(ment.getPreliminaryDesignReviewComments());
                }

                ment.setConstructionDrawingReviewPlan(s);
                List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        ment = setAttribute3(planArrangement);
                        ment.setPhase("预计时间");
                        ment.setApprovalTime(planArrangement.getApprovalTime());
                        ment.setPreliminaryDesignReviewPlan("");
                        ment.setPreliminaryExternalAuditReview("");
                        ment.setPreliminaryDesignReviewComments("");
                        ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments() + "&" + s);
                        ment.setConstructionDrawingReview(drawReview.get(k));
                        ment.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            ment.setBatchNumber(timeInterval.getBatchNumber());
                            ment.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(ment);
                    }
                }
            }
            // 当（五）施工图评审计划  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawingReviewPlan())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        ment = setAttribute3(planArrangement);
                        ment.setPhase("预计时间");
                        ment.setApprovalTime(planArrangement.getApprovalTime());
                        ment.setPreliminaryDesignReviewPlan("");
                        ment.setPreliminaryExternalAuditReview("");
                        ment.setPreliminaryDesignReviewComments("");
                        ment.setConstructionDrawingReviewPlan("");
                        ment.setConstructionDrawingReview(drawReview.get(k));
                        ment.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            ment.setBatchNumber(timeInterval.getBatchNumber());
                            ment.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(ment);
                    }
                }
            }
            // 当（六）施工图评审  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawingReview())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);
                List<String> stringList = util.getDrawReview(ment.getConstructionDrawingReview());
                for (int z=0;z<stringList.size();z++){
                    ment = setAttribute3(planArrangement);
                    ment.setPhase("预计时间");
                    ment.setApprovalTime(planArrangement.getApprovalTime());
                    ment.setPreliminaryDesignReviewPlan("");
                    ment.setPreliminaryExternalAuditReview("");
                    ment.setPreliminaryDesignReviewComments("");
                    ment.setConstructionDrawingReviewPlan("");
                    ment.setConstructionDrawingReview("");
                    ment.setConstructionDrawReview(stringList.get(z));
                    ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                    if (null != timeInterval) {
                        ment.setBatchNumber(timeInterval.getBatchNumber());
                        ment.setBidOpenTime(timeInterval.getBidOpenTime());
                    }
                    list.add(ment);
                }
            }
            // 当（七）施工图评审意见  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawReview())){
                list.clear();

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);
                ment.setPhase("实际时间");

                list.add(ment);
            }

            // 当实际时间都没有的情况下
            if (StringUtils.isBlank(planArrangement.getPreliminaryDesignInternalReview())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryDesignReviewPlan())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryExternalAuditReview())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryDesignReviewComments())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawingReviewPlan())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawingReview())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawReview())){

                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement arrangement1 = setAttribute3(planArrangement);
                arrangement1.setPreliminaryDesignInternalReview(util.getMonth());
                arrangement1.setPreliminaryDesignReviewPlan(util.getDesignReview(arrangement1.getPreliminaryDesignInternalReview()));

                List<String> auditList = util.getExternalReview(arrangement1.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));

                    for (int j=0;j<comments.size();j++){
                        arrangement1 = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        } else {
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }

                        List<String> drawReview = util.getDrawingReview(arrangement1.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                arrangement1 = setAttribute3(planArrangement);
                                arrangement1.setPhase("预计时间");
                                arrangement1.setApprovalTime(planArrangement.getApprovalTime());
                                arrangement1.setPreliminaryDesignInternalReview(util.getMonth());
                                arrangement1.setPreliminaryExternalAuditReview(auditList.get(i));
                                arrangement1.setPreliminaryDesignReviewComments(arrangement1.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                arrangement1.setConstructionDrawingReview(drawReview.get(k));
                                arrangement1.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    arrangement1.setBatchNumber(timeInterval.getBatchNumber());
                                    arrangement1.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(arrangement1);
                            }
                        }

                    }
                }


            }
        }

        for (int i=0;i<list.size();i++){
            if (i==0){
                ReviewPlanArrangement planArrangement1 = list.get(i);
                planArrangement1.setPreliminaryDesignInternalReview(planArrangement1.getPreliminaryDesignInternalReview().replace("/","-"));
                planArrangement1.setPreliminaryDesignReviewPlan(planArrangement1.getPreliminaryDesignReviewPlan().replace("/","-"));
                planArrangement1.setPreliminaryExternalAuditReview(planArrangement1.getPreliminaryExternalAuditReview().replace("/","-"));
                planArrangement1.setPreliminaryDesignReviewComments(planArrangement1.getPreliminaryDesignReviewComments().replace("/","-"));
                planArrangement1.setConstructionDrawingReviewPlan(planArrangement1.getConstructionDrawingReviewPlan().replace("/","-"));
                planArrangement1.setConstructionDrawingReview(planArrangement1.getConstructionDrawingReview().replace("/","-"));
                planArrangement1.setConstructionDrawReview(planArrangement1.getConstructionDrawReview().replace("/","-"));
            }
        }

        page.setList(list);

        return getBootstrapData(page);

    }

    /**
     * 获取评审计划安排表页面数据
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:reviewPlan:list"},logical= Logical.OR)
    @RequestMapping(value = "reviewList3")
    public Map<String, Object> reviewList3(ReviewPlanArrangement arrangement, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {

        Page<ReviewPlanArrangement> page = new Page<>(request,response);
        List<ReviewPlanArrangement> list = new ArrayList<>();

        //获取所有的施工图纸收集截止时间
        List<ConstructionBatch> batchList = batchService.getAllDeadLine();
        ChangeTimeUtil util = ChangeTimeUtil.getOne();

        //根据id查基础信息表中的项目名称、项目编码 （此id为前端传来的基础表id）
        InfrastructureBasicInfo basicInfo = infoService.get(arrangement.getId());
        String is = "";
        if (basicInfo.getProjectCategory().equals("变电")){
            is = "是";
        } else {
            is = "否";
        }
        //根据项目编码查询是否有评审计划安排相关数据
        ReviewPlanArrangement planArrangement = arrangementService.getByCode(basicInfo.getProjectCode());
        if (null == planArrangement){

            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignInternalReview())){

                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                list.add(plan);
                List<String> auditList = util.getExternalReview(util.getDesignReview(arrangement.getPreliminaryDesignInternalReview()));

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                for (int i=0;i<auditList.size();i++){
                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        attribute = setAttribute2(basicInfo);
                        if (is.equals("是")){
                            attribute.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            attribute.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }
                        List<String> drawReview = util.getDrawingReview(attribute.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                attribute = setAttribute2(basicInfo);
                                attribute.setPhase("预计时间");
                                attribute.setIsItInvolved(is);
                                attribute.setPreliminaryDesignReviewPlan(util.getDesignReview(plan.getPreliminaryDesignInternalReview()));;
                                attribute.setPreliminaryDesignInternalReview("");
                                attribute.setPreliminaryExternalAuditReview(auditList.get(i));
                                attribute.setPreliminaryDesignReviewComments(attribute.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                attribute.setConstructionDrawingReview(drawReview.get(k));
                                attribute.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    attribute.setBatchNumber(timeInterval.getBatchNumber());
                                    attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(attribute);
                            }
                        }
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignReviewPlan())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                list.add(plan);
                List<String> auditList = util.getExternalReview(util.getDesignReview(arrangement.getPreliminaryDesignInternalReview()));

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                for (int i=0;i<auditList.size();i++){
                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        attribute = setAttribute2(basicInfo);
                        if (is.equals("是")){
                            attribute.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            attribute.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }
                        List<String> drawReview = util.getDrawingReview(attribute.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                attribute = setAttribute2(basicInfo);
                                attribute.setPhase("预计时间");
                                attribute.setIsItInvolved(is);
                                attribute.setPreliminaryDesignReviewPlan("");
                                attribute.setPreliminaryDesignInternalReview("");
                                attribute.setPreliminaryExternalAuditReview(auditList.get(i));
                                attribute.setPreliminaryDesignReviewComments(attribute.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                attribute.setConstructionDrawingReview(drawReview.get(k));
                                attribute.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    attribute.setBatchNumber(timeInterval.getBatchNumber());
                                    attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(attribute);
                            }
                        }
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryExternalAuditReview())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                list.add(plan);

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                List<String> comments = util.getReviewComments(arrangement.getPreliminaryExternalAuditReview());
                for (int j=0;j<comments.size();j++){
                    attribute = setAttribute2(basicInfo);
                    if (is.equals("是")){
                        attribute.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                    }else {
                        attribute.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                    }
                    List<String> drawReview = util.getDrawingReview(attribute.getConstructionDrawingReviewPlan());
                    for (int k=0;k<drawReview.size();k++){
                        List<String> stringList = util.getDrawReview(drawReview.get(k));
                        for (int z=0;z<stringList.size();z++){
                            attribute = setAttribute2(basicInfo);
                            attribute.setPhase("预计时间");
                            attribute.setIsItInvolved(is);
                            attribute.setPreliminaryDesignReviewPlan("");
                            attribute.setPreliminaryDesignInternalReview("");
                            attribute.setPreliminaryExternalAuditReview("");
                            attribute.setPreliminaryDesignReviewComments(attribute.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                            if (is.equals("是")){
                                attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                            }else {
                                attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                            }
                            attribute.setConstructionDrawingReview(drawReview.get(k));
                            attribute.setConstructionDrawReview(stringList.get(z));
                            ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                            if (null != timeInterval) {
                                attribute.setBatchNumber(timeInterval.getBatchNumber());
                                attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                            }
                            list.add(attribute);
                        }
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignReviewComments())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                plan.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
                list.add(plan);

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                attribute = setAttribute2(basicInfo);
                if (is.equals("是")){
                    attribute.setConstructionDrawingReviewPlan(util.getReviewPlan(arrangement.getPreliminaryDesignReviewComments()));
                }else {
                    attribute.setConstructionDrawingReviewPlan(util.getReviewPlan2(arrangement.getPreliminaryDesignReviewComments()));
                }
                List<String> drawReview = util.getDrawingReview(attribute.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        attribute = setAttribute2(basicInfo);
                        attribute.setPhase("预计时间");
                        attribute.setIsItInvolved(is);
                        attribute.setPreliminaryDesignReviewPlan("");
                        attribute.setPreliminaryDesignInternalReview("");
                        attribute.setPreliminaryExternalAuditReview("");
                        attribute.setPreliminaryDesignReviewComments("");
                        if (is.equals("是")){
                            attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(arrangement.getPreliminaryDesignReviewComments()));
                        }else {
                            attribute.setConstructionDrawingReviewPlan(attribute.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(arrangement.getPreliminaryDesignReviewComments()));
                        }
                        attribute.setConstructionDrawingReview(drawReview.get(k));
                        attribute.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            attribute.setBatchNumber(timeInterval.getBatchNumber());
                            attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(attribute);
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawingReviewPlan())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                plan.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
                plan.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan());
                list.add(plan);

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                List<String> drawReview = util.getDrawingReview(arrangement.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        attribute = setAttribute2(basicInfo);
                        attribute.setPhase("预计时间");
                        attribute.setIsItInvolved(is);
                        attribute.setPreliminaryDesignReviewPlan("");
                        attribute.setPreliminaryDesignInternalReview("");
                        attribute.setPreliminaryExternalAuditReview("");
                        attribute.setPreliminaryDesignReviewComments("");
                        if (is.equals("是")){
                            attribute.setConstructionDrawingReviewPlan("");
                        }else {
                            attribute.setConstructionDrawingReviewPlan("");
                        }
                        attribute.setConstructionDrawingReview(drawReview.get(k));
                        attribute.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            attribute.setBatchNumber(timeInterval.getBatchNumber());
                            attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(attribute);
                    }
                }
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawingReview())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                plan.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
                plan.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan());
                plan.setConstructionDrawingReview(arrangement.getConstructionDrawingReview());
                list.add(plan);

                ReviewPlanArrangement attribute = new ReviewPlanArrangement();
                List<String> stringList = util.getDrawReview(arrangement.getConstructionDrawingReview());
                for (int z=0;z<stringList.size();z++){
                    attribute = setAttribute2(basicInfo);
                    attribute.setPhase("预计时间");
                    attribute.setIsItInvolved(is);
                    attribute.setPreliminaryDesignReviewPlan("");
                    attribute.setPreliminaryDesignInternalReview("");
                    attribute.setPreliminaryExternalAuditReview("");
                    attribute.setPreliminaryDesignReviewComments("");
                    if (is.equals("是")){
                        attribute.setConstructionDrawingReviewPlan("");
                    }else {
                        attribute.setConstructionDrawingReviewPlan("");
                    }
                    attribute.setConstructionDrawingReview("");
                    attribute.setConstructionDrawReview(stringList.get(z));
                    ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                    if (null != timeInterval) {
                        attribute.setBatchNumber(timeInterval.getBatchNumber());
                        attribute.setBidOpenTime(timeInterval.getBidOpenTime());
                    }
                    list.add(attribute);
                }
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawReview())){

                list.clear();
                ReviewPlanArrangement plan = setAttribute2(basicInfo);
                plan.setIsItInvolved(is);
                plan.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
                plan.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
                plan.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
                plan.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
                plan.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan());
                plan.setConstructionDrawingReview(arrangement.getConstructionDrawingReview());
                plan.setConstructionDrawReview(arrangement.getConstructionDrawReview());
                list.add(plan);
            }

            if (StringUtils.isBlank(arrangement.getPreliminaryDesignInternalReview())&&
                    StringUtils.isBlank(arrangement.getPreliminaryDesignReviewPlan())&&
                    StringUtils.isBlank(arrangement.getPreliminaryExternalAuditReview())&&
                    StringUtils.isBlank(arrangement.getPreliminaryDesignReviewComments())&&
                    StringUtils.isBlank(arrangement.getConstructionDrawingReviewPlan())&&
                    StringUtils.isBlank(arrangement.getConstructionDrawingReview())&&
                    StringUtils.isBlank(arrangement.getConstructionDrawReview())){
                ReviewPlanArrangement display = setAttribute2(basicInfo);

                display.setIsItInvolved(is);
                list.add(display);

                ReviewPlanArrangement newDis = setAttribute(basicInfo);

                List<String> auditList = util.getExternalReview(newDis.getPreliminaryDesignReviewPlan());

                for (int i=0;i<auditList.size();i++){
                    newDis = setAttribute(basicInfo);
                    newDis.setPreliminaryExternalAuditReview(auditList.get(i));
                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        newDis = setAttribute(basicInfo);
                        if (is.equals("是")){
                            newDis.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        }else {
                            newDis.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }

                        List<String> drawReview = util.getDrawingReview(newDis.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                newDis = setAttribute(basicInfo);
                                newDis.setPhase("预计时间");
                                newDis.setIsItInvolved(is);
                                newDis.setPreliminaryExternalAuditReview(auditList.get(i));
                                newDis.setPreliminaryDesignReviewComments(newDis.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    newDis.setConstructionDrawingReviewPlan(newDis.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    newDis.setConstructionDrawingReviewPlan(newDis.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                newDis.setConstructionDrawingReview(drawReview.get(k));
                                newDis.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    newDis.setBatchNumber(timeInterval.getBatchNumber());
                                    newDis.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(newDis);
                            }
                        }

                    }
                }
            }


        } else {
            planArrangement.setIsItInvolved(is);
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignInternalReview())){
                planArrangement.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview());
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignReviewPlan())){
                planArrangement.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan());
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryExternalAuditReview())){
                planArrangement.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview());
            }
            if (StringUtils.isNotBlank(arrangement.getPreliminaryDesignReviewComments())){
                planArrangement.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments());
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawingReviewPlan())){
                planArrangement.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan());
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawingReview())){
                planArrangement.setConstructionDrawingReview(arrangement.getConstructionDrawingReview());
            }
            if (StringUtils.isNotBlank(arrangement.getConstructionDrawReview())){
                planArrangement.setConstructionDrawReview(arrangement.getConstructionDrawReview());
            }

            //判断哪一个项目阶段有实际时间
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignInternalReview())){

                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement arrangement1 = setAttribute3(planArrangement);

                List<String> auditList = util.getExternalReview(arrangement1.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));

                    for (int j=0;j<comments.size();j++){
                        arrangement1 = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        } else {
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }


                        List<String> drawReview = util.getDrawingReview(arrangement1.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                arrangement1 = setAttribute3(planArrangement);
                                arrangement1.setPhase("预计时间");
                                arrangement1.setApprovalTime(planArrangement.getApprovalTime());
                                arrangement1.setPreliminaryExternalAuditReview(auditList.get(i));
                                arrangement1.setPreliminaryDesignReviewComments(comments.get(j));
                                arrangement1.setPreliminaryDesignReviewComments(arrangement1.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                arrangement1.setConstructionDrawingReview(drawReview.get(k));
                                arrangement1.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    arrangement1.setBatchNumber(timeInterval.getBatchNumber());
                                    arrangement1.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(arrangement1);
                            }
                        }

                    }
                }

            }
            // 当（二）初步设计评审计划  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignReviewPlan())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> auditList = util.getExternalReview(ment.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));
                    for (int j=0;j<comments.size();j++){
                        ment = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            ment.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        } else {
                            ment.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }
                        List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                ment = setAttribute3(planArrangement);
                                ment.setPhase("预计时间");
                                ment.setApprovalTime(planArrangement.getApprovalTime());
                                ment.setPreliminaryDesignReviewPlan("");
                                ment.setPreliminaryExternalAuditReview(auditList.get(i));
                                ment.setPreliminaryDesignReviewComments(ment.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                ment.setConstructionDrawingReview(drawReview.get(k));
                                ment.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    ment.setBatchNumber(timeInterval.getBatchNumber());
                                    ment.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(ment);
                            }
                        }

                    }
                }
            }
            // 当（三）初设外审评审  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryExternalAuditReview())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> comments = util.getReviewComments(ment.getPreliminaryExternalAuditReview());
                for (int j=0;j<comments.size();j++){
                    ment = setAttribute3(planArrangement);
                    if (is.equals("是")){
                        ment.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                    } else {
                        ment.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                    }
                    List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                    for (int k=0;k<drawReview.size();k++){
                        List<String> stringList = util.getDrawReview(drawReview.get(k));
                        for (int z=0;z<stringList.size();z++){
                            ment = setAttribute3(planArrangement);
                            ment.setPhase("预计时间");
                            ment.setApprovalTime(planArrangement.getApprovalTime());
                            ment.setPreliminaryDesignReviewPlan("");
                            ment.setPreliminaryExternalAuditReview("");
                            ment.setPreliminaryDesignReviewComments(ment.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                            if (is.equals("是")){
                                ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                            }else {
                                ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                            }
                            ment.setConstructionDrawingReview(drawReview.get(k));
                            ment.setConstructionDrawReview(stringList.get(z));
                            ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                            if (null != timeInterval) {
                                ment.setBatchNumber(timeInterval.getBatchNumber());
                                ment.setBidOpenTime(timeInterval.getBidOpenTime());
                            }
                            list.add(ment);
                        }
                    }

                }
            }
            // 当（四）初设评审意见  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getPreliminaryDesignReviewComments())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);


                String s = "";
                if (is.equals("是")){
                    s = util.getReviewPlan(ment.getPreliminaryDesignReviewComments());
                } else {
                    s = util.getReviewPlan2(ment.getPreliminaryDesignReviewComments());
                }

                ment.setConstructionDrawingReviewPlan(s);
                List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        ment = setAttribute3(planArrangement);
                        ment.setPhase("预计时间");
                        ment.setApprovalTime(planArrangement.getApprovalTime());
                        ment.setPreliminaryDesignReviewPlan("");
                        ment.setPreliminaryExternalAuditReview("");
                        ment.setPreliminaryDesignReviewComments("");
                        ment.setConstructionDrawingReviewPlan(ment.getPreliminaryDesignReviewComments() + "&" + s);
                        ment.setConstructionDrawingReview(drawReview.get(k));
                        ment.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            ment.setBatchNumber(timeInterval.getBatchNumber());
                            ment.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(ment);
                    }
                }
            }
            // 当（五）施工图评审计划  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawingReviewPlan())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);

                List<String> drawReview = util.getDrawingReview(ment.getConstructionDrawingReviewPlan());
                for (int k=0;k<drawReview.size();k++){
                    List<String> stringList = util.getDrawReview(drawReview.get(k));
                    for (int z=0;z<stringList.size();z++){
                        ment = setAttribute3(planArrangement);
                        ment.setPhase("预计时间");
                        ment.setApprovalTime(planArrangement.getApprovalTime());
                        ment.setPreliminaryDesignReviewPlan("");
                        ment.setPreliminaryExternalAuditReview("");
                        ment.setPreliminaryDesignReviewComments("");
                        ment.setConstructionDrawingReviewPlan("");
                        ment.setConstructionDrawingReview(drawReview.get(k));
                        ment.setConstructionDrawReview(stringList.get(z));
                        ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                        if (null != timeInterval) {
                            ment.setBatchNumber(timeInterval.getBatchNumber());
                            ment.setBidOpenTime(timeInterval.getBidOpenTime());
                        }
                        list.add(ment);
                    }
                }
            }
            // 当（六）施工图评审  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawingReview())){
                list.clear();
                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);
                List<String> stringList = util.getDrawReview(ment.getConstructionDrawingReview());
                for (int z=0;z<stringList.size();z++){
                    ment = setAttribute3(planArrangement);
                    ment.setPhase("预计时间");
                    ment.setApprovalTime(planArrangement.getApprovalTime());
                    ment.setPreliminaryDesignReviewPlan("");
                    ment.setPreliminaryExternalAuditReview("");
                    ment.setPreliminaryDesignReviewComments("");
                    ment.setConstructionDrawingReviewPlan("");
                    ment.setConstructionDrawingReview("");
                    ment.setConstructionDrawReview(stringList.get(z));
                    ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                    if (null != timeInterval) {
                        ment.setBatchNumber(timeInterval.getBatchNumber());
                        ment.setBidOpenTime(timeInterval.getBidOpenTime());
                    }
                    list.add(ment);
                }
            }
            // 当（七）施工图评审意见  实际时间有值时
            if (StringUtils.isNotBlank(planArrangement.getConstructionDrawReview())){
                list.clear();

                ReviewPlanArrangement ment = new ReviewPlanArrangement();
                BeanUtils.copyProperties(planArrangement,ment);
                ment.setPhase("实际时间");

                list.add(ment);
            }

            // 当实际时间都没有的情况下
            if (StringUtils.isBlank(planArrangement.getPreliminaryDesignInternalReview())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryDesignReviewPlan())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryExternalAuditReview())&&
                    StringUtils.isBlank(planArrangement.getPreliminaryDesignReviewComments())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawingReviewPlan())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawingReview())&&
                    StringUtils.isBlank(planArrangement.getConstructionDrawReview())){

                planArrangement.setPhase("实际时间");
                list.add(planArrangement);

                ReviewPlanArrangement arrangement1 = setAttribute3(planArrangement);
                arrangement1.setPreliminaryDesignInternalReview(util.getMonth());
                arrangement1.setPreliminaryDesignReviewPlan(util.getDesignReview(arrangement1.getPreliminaryDesignInternalReview()));

                List<String> auditList = util.getExternalReview(arrangement1.getPreliminaryDesignReviewPlan());
                for (int i=0;i<auditList.size();i++){

                    List<String> comments = util.getReviewComments(auditList.get(i));

                    for (int j=0;j<comments.size();j++){
                        arrangement1 = setAttribute3(planArrangement);
                        if (is.equals("是")){
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        } else {
                            arrangement1.setConstructionDrawingReviewPlan(util.getReviewPlan2(comments.get(j)));
                        }

                        List<String> drawReview = util.getDrawingReview(arrangement1.getConstructionDrawingReviewPlan());
                        for (int k=0;k<drawReview.size();k++){
                            List<String> stringList = util.getDrawReview(drawReview.get(k));
                            for (int z=0;z<stringList.size();z++){
                                arrangement1 = setAttribute3(planArrangement);
                                arrangement1.setPhase("预计时间");
                                arrangement1.setApprovalTime(planArrangement.getApprovalTime());
                                arrangement1.setPreliminaryDesignInternalReview(util.getMonth());
                                arrangement1.setPreliminaryExternalAuditReview(auditList.get(i));
                                arrangement1.setPreliminaryDesignReviewComments(arrangement1.getPreliminaryExternalAuditReview()+"&"+comments.get(j));
                                if (is.equals("是")){
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan(comments.get(j)));
                                }else {
                                    arrangement1.setConstructionDrawingReviewPlan(arrangement1.getPreliminaryDesignReviewComments()+"&"+util.getReviewPlan2(comments.get(j)));
                                }
                                arrangement1.setConstructionDrawingReview(drawReview.get(k));
                                arrangement1.setConstructionDrawReview(stringList.get(z));
                                ConstructionBatch timeInterval = util.getTimeInterval(stringList.get(z),batchList);
                                if (null != timeInterval) {
                                    arrangement1.setBatchNumber(timeInterval.getBatchNumber());
                                    arrangement1.setBidOpenTime(timeInterval.getBidOpenTime());
                                }
                                list.add(arrangement1);
                            }
                        }

                    }
                }


            }
        }

        for (int i=0;i<list.size();i++){
            if (i==0){
                ReviewPlanArrangement planArrangement1 = list.get(i);
                planArrangement1.setPreliminaryDesignInternalReview(planArrangement1.getPreliminaryDesignInternalReview().replace("/","-"));
                planArrangement1.setPreliminaryDesignReviewPlan(planArrangement1.getPreliminaryDesignReviewPlan().replace("/","-"));
                planArrangement1.setPreliminaryExternalAuditReview(planArrangement1.getPreliminaryExternalAuditReview().replace("/","-"));
                planArrangement1.setPreliminaryDesignReviewComments(planArrangement1.getPreliminaryDesignReviewComments().replace("/","-"));
                planArrangement1.setConstructionDrawingReviewPlan(planArrangement1.getConstructionDrawingReviewPlan().replace("/","-"));
                planArrangement1.setConstructionDrawingReview(planArrangement1.getConstructionDrawingReview().replace("/","-"));
                planArrangement1.setConstructionDrawReview(planArrangement1.getConstructionDrawReview().replace("/","-"));
            }
        }

        page.setList(list);

        return getBootstrapData(page);

    }

    /**
     * 保存 评审计划安排表页面数据
     * @param arrangement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:reviewPlan:add"},logical=Logical.OR)
    @RequestMapping(value = "reviewSave")
    public AjaxJson reviewSave(@RequestBody ReviewPlanArrangement arrangement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(arrangement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        arrangement.setPreliminaryDesignInternalReview(arrangement.getPreliminaryDesignInternalReview().replace("-","/"));
        arrangement.setPreliminaryDesignReviewPlan(arrangement.getPreliminaryDesignReviewPlan().replace("-","/"));
        arrangement.setPreliminaryExternalAuditReview(arrangement.getPreliminaryExternalAuditReview().replace("-","/"));
        arrangement.setPreliminaryDesignReviewComments(arrangement.getPreliminaryDesignReviewComments().replace("-","/"));
        arrangement.setConstructionDrawingReviewPlan(arrangement.getConstructionDrawingReviewPlan().replace("-","/"));
        arrangement.setConstructionDrawingReview(arrangement.getConstructionDrawingReview().replace("-","/"));
        arrangement.setConstructionDrawReview(arrangement.getConstructionDrawReview().replace("-","/"));

        //新增或编辑表单保存
        arrangementService.save(arrangement);//保存
        j.setSuccess(true);
        j.setMsg("保存基建项目评审计划安排信息成功");
        return j;
    }

    /**
     * 基建 - 基础信息 - 列表页面
     * @param basicInfo
     * @param model
     * @return
     */
    @RequiresPermissions("cg:infrastructure:infrastructureBasicInfo:list")
    @RequestMapping(value = "budgetList")
    public String budgetList(InfrastructureBasicInfo basicInfo, Model model) {
        model.addAttribute("basicInfo", basicInfo);
        return "modules/cg/infrastructure/basicInfo/basicInfo";
    }

    /**
     * 增加，编辑表单页面
     * @param basicInfo
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:infrastructure:infrastructureBasicInfo:add","cg:infrastructure:infrastructureBasicInfo:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(InfrastructureBasicInfo basicInfo, Model model) {
        model.addAttribute("basicInfo", basicInfo);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(basicInfo.getId())){
            return "modules/cg/infrastructure/basicInfo/basicInfoAddForm";
        }
        return "modules/cg/infrastructure/basicInfo/basicInfoUpdateForm";
    }

    /**
     * 基建 - 基础信息 - 列表数据
     * @param basicInfo
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:infrastructure:infrastructureBasicInfo:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(InfrastructureBasicInfo basicInfo, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {

        Page<InfrastructureBasicInfo> page = infoService.findPage(new Page<InfrastructureBasicInfo>(request, response), basicInfo);
        return getBootstrapData(page);
    }

    /**
     * 删除表单
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:infrastructureBasicInfo:del"},logical= Logical.OR)
    @RequestMapping(value = "deleteAll")
    public AjaxJson delete(String ids){
        AjaxJson j = new AjaxJson();
        String idArray[] =ids.split(",");
        for(String id : idArray){
            try {
                InfrastructureBasicInfo processProject = infoService.get(id);
                infoService.delete(processProject);
                //同时删除评审计划安排表中的相关数据
                arrangementService.deleteByCode(processProject.getProjectCode());
            }catch (Exception e){
                j.setSuccess(false);
                j.setMsg("存在关联数据，无法删除！" + e);
                return j;
            }

        }
        j.setMsg("删除储备项目基本信息成功");
        return j;
    }

    /**
     * 保存表单
     * @param basicInfo
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:infrastructureBasicInfo:add"},logical=Logical.OR)
    @RequestMapping(value = "save")
    public AjaxJson save(InfrastructureBasicInfo basicInfo){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(basicInfo);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        InfrastructureBasicInfo infrastructureBasicInfo = new InfrastructureBasicInfo();
        infrastructureBasicInfo.setStateGridCode(basicInfo.getStateGridCode());

        int count = infoService.getAllInfo(infrastructureBasicInfo);
        if (count > 0 ){
            j.setSuccess(false);
            j.setMsg( "国网编码为" + basicInfo.getStateGridCode() + "的项目已存在，不对数据进行保存！");
            return j;
        }
        infrastructureBasicInfo.setProjectCode(basicInfo.getProjectCode());
        count = infoService.getAllInfo(infrastructureBasicInfo);
        if (count > 0 ){
            j.setSuccess(false);
            j.setMsg( "项目编码为" + basicInfo.getProjectCode() + "的项目已存在，不对数据进行保存！");
            return j;
        }

        infrastructureBasicInfo.setProjectName(basicInfo.getProjectName());
        count = infoService.getAllInfo(infrastructureBasicInfo);

        if ( count > 0 ) {
            j.setSuccess(false);
            j.setMsg( "项目名称为" + basicInfo.getProjectName() + "的项目已存在，不对数据进行保存！");
            return j;
        }

        //新增或编辑表单保存
        infoService.save(basicInfo);//保存
        j.setSuccess(true);
        j.setMsg("保存基建项目基本信息成功");
        return j;
    }

    /**
     * 修改表单
     * @param basicInfo
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:infrastructure:infrastructureBasicInfo:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(InfrastructureBasicInfo basicInfo) {
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(basicInfo);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //新增或编辑表单保存
        infoService.update(basicInfo);
        j.setSuccess(true);
        j.setMsg("修改基建项目基本信息成功");
        return j;
    }

    /**
     *  导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:infrastructure:infrastructureBasicInfo:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);

            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = infoService.getAllProId();
            //获取导入表格所有数据
            List<InfrastructureBasicInfo> budgetStats = InfrastructureExcelImportUtil.getBudgetUtil(importUtil,proIdList);

            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = infoService.getExistProjectList(budgetStats);
            //未存在数据
            List<InfrastructureBasicInfo> withoutList = (List<InfrastructureBasicInfo>) map.get("without");
            //已存在数据
            List<InfrastructureBasicInfo> existList = (List<InfrastructureBasicInfo>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                infoService.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (InfrastructureBasicInfo basicInfo : existList) {
                    infoService.update(basicInfo);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条基建项目基本信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入基建项目基本信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:infrastructure:infrastructureBasicInfo:export")
    @RequestMapping(value = "export")
    public void exportExcel(InfrastructureBasicInfo basicInfo, HttpServletRequest request, HttpServletResponse response) {
        List<InfrastructureBasicInfo> list = infoService.exportFindList(basicInfo);
        //生成序列号
        int i = 1;
        for (InfrastructureBasicInfo s : list) {
            s.setId(String.valueOf(i));
            i++;
        }

        InfrastructureExcelExportUtil util = InfrastructureExcelExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("infrastructureBasicInfo");
        util.exportBasic(response,workbook,list);
    }

    public ReviewPlanArrangement setAttribute(InfrastructureBasicInfo basicInfo){
        ChangeTimeUtil util = ChangeTimeUtil.getOne();
        String month = util.getMonth();
        ReviewPlanArrangement display = new ReviewPlanArrangement();
        display.setProjectName(basicInfo.getProjectName());
        display.setProjectCode(basicInfo.getProjectCode());
        display.setPreliminaryDesignInternalReview(month);
        display.setPreliminaryDesignReviewPlan(util.getDesignReview(display.getPreliminaryDesignInternalReview()));
        return display;
    }

    public ReviewPlanArrangement setAttribute2(InfrastructureBasicInfo basicInfo){
        ReviewPlanArrangement display = setAttribute(basicInfo);
        display.setPhase("实际时间");
        display.setPreliminaryDesignReviewPlan("");
        display.setPreliminaryDesignInternalReview("");
        display.setPreliminaryExternalAuditReview("");
        display.setPreliminaryDesignReviewComments("");
        display.setConstructionDrawingReviewPlan("");
        display.setConstructionDrawingReview("");
        display.setConstructionDrawReview("");
        display.setBatchNumber("");
        display.setBidOpenTime("");
        display.setApprovalTime("");
        return display;
    }

    public ReviewPlanArrangement setAttribute3(ReviewPlanArrangement arrangement){
        ChangeTimeUtil util = ChangeTimeUtil.getOne();
        ReviewPlanArrangement display = new ReviewPlanArrangement();
        display.setProjectName(arrangement.getProjectName());
        display.setProjectCode(arrangement.getProjectCode());
        display.setPreliminaryDesignInternalReview("");
        display.setIsItInvolved(arrangement.getIsItInvolved());
        display.setPreliminaryDesignReviewPlan(util.getDesignReview(arrangement.getPreliminaryDesignInternalReview()));
        return display;
    }
}
