package com.jeeplus.modules.cg.infrastructure.web;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.infrastructure.entity.AnnualBatchDisplay;
import com.jeeplus.modules.cg.infrastructure.entity.ConstructionBatch;
import com.jeeplus.modules.cg.infrastructure.service.ConstructionBatchService;
import com.jeeplus.modules.cg.infrastructure.util.ChangeTimeUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * 基建 - 评审计划安排表
 * @author: 王强
 * @create: 2023-05-10 16:57
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/infrastructure/transformer")
public class TransformerController extends BaseController {

    @Autowired
    private ConstructionBatchService batchService;

    public static final SimpleDateFormat SHORT_DATE_FORMAT = new SimpleDateFormat("yyyy/MM/dd");

    /**
     * 基建 - 全年批次信息展示 - 新建变电站 - 列表页面
     * @param arrangement
     * @param model
     * @return
     */
    @RequiresPermissions("cg:infrastructure:transformer:list")
    @RequestMapping(value = "budgetList")
    public String budgetList(AnnualBatchDisplay arrangement, Model model) {
        model.addAttribute("arrangement", arrangement);
        return "modules/cg/infrastructure/annualBatchDisplay/transformer";
    }

    /**
     * 基建 - 新建变电站 - 列表数据
     * @param basicInfo
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:infrastructure:transformer:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(AnnualBatchDisplay basicInfo, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {

        Page<AnnualBatchDisplay> page = new Page<>(request,response);
        List<AnnualBatchDisplay> list = new ArrayList<>();
        //获取所有的施工图纸收集截止时间
        List<ConstructionBatch> batchList = batchService.getAllDeadLine();

        ChangeTimeUtil util = ChangeTimeUtil.getOne();

        List<String> months = new ArrayList<>();;
        if (StringUtils.isNotBlank(basicInfo.getYear())){
            Integer year = Integer.parseInt(basicInfo.getYear());
            months = util.getMonths(year);
        }else {
            int year = LocalDate.now().getYear();
            months = util.getMonths(year);
        }
        for (int v = 0;v<months.size();v++){
            AnnualBatchDisplay display = new AnnualBatchDisplay();
            display.setPreliminaryDesignInternalReview(months.get(v));
            display.setPreliminaryDesignReviewPlan(util.getDesignReview(display.getPreliminaryDesignInternalReview()));
            List<String> auditList = util.getExternalReview(display.getPreliminaryDesignReviewPlan());

            for (int i=0;i<auditList.size();i++){
                display = new AnnualBatchDisplay();
                display.setPreliminaryDesignInternalReview(months.get(v));
                display.setPreliminaryDesignReviewPlan(util.getDesignReview(display.getPreliminaryDesignInternalReview()));
                display.setPreliminaryExternalAuditReview(auditList.get(i));
                List<String> comments = util.getReviewComments(auditList.get(i));
                for (int j=0;j<comments.size();j++){
                    display = new AnnualBatchDisplay();
                    display.setPreliminaryDesignInternalReview(months.get(v));
                    display.setPreliminaryDesignReviewPlan(util.getDesignReview(display.getPreliminaryDesignInternalReview()));
                    display.setPreliminaryExternalAuditReview(auditList.get(i));
                    display.setPreliminaryDesignReviewComments(comments.get(j));
                    display.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                    List<String> drawReview = util.getDrawingReview(display.getConstructionDrawingReviewPlan());
                    for (int k=0;k<drawReview.size();k++){
                        display = new AnnualBatchDisplay();
                        display.setPreliminaryDesignInternalReview(months.get(v));
                        display.setPreliminaryDesignReviewPlan(util.getDesignReview(display.getPreliminaryDesignInternalReview()));
                        display.setPreliminaryExternalAuditReview(auditList.get(i));
                        display.setPreliminaryDesignReviewComments(comments.get(j));
                        display.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                        display.setConstructionDrawingReview(drawReview.get(k));
                        List<String> stringList = util.getDrawReview(drawReview.get(k));
                        for (int z=0;z<stringList.size();z++){
                            display = new AnnualBatchDisplay();
                            display.setPreliminaryDesignInternalReview(months.get(v));
                            display.setPreliminaryDesignReviewPlan(util.getDesignReview(display.getPreliminaryDesignInternalReview()));
                            display.setPreliminaryExternalAuditReview(auditList.get(i));
                            display.setPreliminaryDesignReviewComments(comments.get(j));
                            display.setConstructionDrawingReviewPlan(util.getReviewPlan(comments.get(j)));
                            display.setConstructionDrawingReview(drawReview.get(k));
                            display.setConstructionDrawReview(stringList.get(z));
                            ConstructionBatch timeInterval = getTimeInterval(stringList.get(z),batchList);
                            if (null != timeInterval) {
                                display.setBatchNumber(timeInterval.getBatchNumber());
                                display.setBidOpenTime(timeInterval.getBidOpenTime());
                            }
                            list.add(display);
                        }
                    }

                }
            }
            list.add(null);
        }

        page.setList(list);

        return getBootstrapData(page);
    }

    /**
     * 判断是哪一个时间区间
     * @param time
     * @param batches
     * @return
     */
    public ConstructionBatch getTimeInterval(String time,List<ConstructionBatch> batches) throws ParseException {
        SimpleDateFormat inputFormat = new SimpleDateFormat("yyyy/M/dd");

        // 待判断日期
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy/MM/dd");
        LocalDate targetDate = LocalDate.parse(time, formatter);

        for (int i=0;i<batches.size();i++){
            Date da = inputFormat.parse(batches.get(i).getEndTime());
            LocalDate startTime = LocalDate.parse(SHORT_DATE_FORMAT.format(da), formatter);
            if (targetDate.isBefore(startTime)){
                return batches.get(i);
            } else {
                for (int k=i+1;k<batches.size();k++){
                    da = inputFormat.parse(batches.get(k).getEndTime());
                    LocalDate startTime2 = LocalDate.parse(SHORT_DATE_FORMAT.format(da), formatter);
                    if (targetDate.isBefore(startTime2)){
                        return batches.get(k);
                    }
                }
            }
        }

        return null;
    }

}
