package com.jeeplus.modules.cg.reservemanagementcenter.distribution.web;

import com.google.common.collect.Maps;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.PropertiesLoader;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.web.Servlets;
import com.jeeplus.modules.act.entity.Act;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.entity.DistributionNetwork;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.entity.DistributionNetworkProcess;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.service.DistributionNetworkProcessService;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.service.DistributionNetworkService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.Demolite;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.DocumentInfo;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ReserveProcessProject;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ReserveSummaryProcess;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.DemoliteService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.DocumentInfoService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveProcessProjectService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveSummaryProcessService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.DataList;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectProUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.CableService;
import com.jeeplus.modules.sg.managementcenter.materialinfo.entity.MaterialInfo;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import com.jeeplus.modules.sg.picking.activiti.entity.ShowList;
import com.jeeplus.modules.sys.entity.User;
import com.jeeplus.modules.sys.utils.UserUtils;
import org.activiti.engine.TaskService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.mock.web.MockMultipartFile;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author 王强
 * @version 1.0
 * @date 2023-09-07 15:53
 */

@Controller
@RequestMapping(value = "${adminPath}/cg/distribution/distribution")
public class DistributionController {

    @Autowired
    private DistributionNetworkProcessService processService;

    @Autowired
    private DistributionNetworkService networkService;

    @Autowired
    private ReserveProcessProjectService projectService;

    @Autowired
    private TaskService taskService;

    @Autowired
    private DocumentInfoService infoService;

    @Autowired
    private DemoliteService demoliteService;

    @Autowired
    private ReserveSummaryProcessService reserveProcessService;

    @Autowired
    private CableService cableService;

    /**
     * 判断服务器系统类型，1是windows系统，2是linux系统
     */
    public static final String SYS_TYPE = System.getProperty("os.name").toLowerCase().startsWith("win") ? "1" : "2";


    /**
     * 属性文件加载对象
     */
    private static PropertiesLoader loader = new PropertiesLoader("/properties/jeeplus.properties");

    @ModelAttribute
    public DistributionNetworkProcess get(@RequestParam(required = false) String id) {
        DistributionNetworkProcess entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = processService.get(id);
        }
        if (entity == null) {
            entity = new DistributionNetworkProcess();
        }
        //查询项目中心领导信息
        List<String> users = processService.getUserInfo();
        entity.setUserList(users);
        return entity;
    }

    /**
     * 业主项目经理审核
     */
    @RequestMapping(value = "designUnit")
    public String designUnit(DistributionNetworkProcess reserveProcess, Model model) {
        //获取当前用户
        String loginName = UserUtils.getUser().getName();
        if (StringUtils.isBlank(reserveProcess.getProblemSolverLeader())){
            reserveProcess.setProblemSolver(loginName);
        }
        //查询项目中心领导信息
        List<String> users = processService.getUserInfo();
        reserveProcess.setUserList(users);
        model.addAttribute("reserveProcess", reserveProcess);
        return "modules/cg/reservemanagementcenter/distribution/process/designUnit";
    }

    /**
     * 业主项目经理再次审核
     */
    @RequestMapping(value = "designUnitAgain")
    public String designUnitAgain(DistributionNetworkProcess reserveProcess, Model model) {
        //获取当前用户
        String loginName = UserUtils.getUser().getName();
        if (StringUtils.isBlank(reserveProcess.getProblemSolverLeader())){
            reserveProcess.setProblemSolver(loginName);
        }
        //查询项目中心领导信息
        List<String> users = processService.getUserInfo();
        reserveProcess.setUserList(users);
        model.addAttribute("reserveProcess", reserveProcess);
        return "modules/cg/reservemanagementcenter/distribution/process/designUnitAgain";
    }

    /**
     * 业主领导审核
     */
    @RequestMapping(value = "leaderProcess")
    public String leaderProcess(DistributionNetworkProcess reserveProcess, Model model) {
        model.addAttribute("reserveProcess", reserveProcess);
        return "modules/cg/reservemanagementcenter/distribution/process/leaderProcess";
    }

    /**
     * 技经人员审核
     */
    @RequestMapping(value = "skillUnit")
    public String skillUnit(DistributionNetworkProcess reserveProcess, Model model) {
        model.addAttribute("reserveProcess", reserveProcess);
        return "modules/cg/reservemanagementcenter/distribution/process/skillUnit";
    }

    /**
     * 设计人员上传文件
     */
    @RequestMapping(value = "designUnitFile")
    public String designUnitFile(DistributionNetworkProcess reserveProcess, Model model) {
        model.addAttribute("reserveProcess", reserveProcess);
        return "modules/cg/reservemanagementcenter/distribution/process/designUnitFile";
    }

    /***
     * 业主项目经理 - 问题已解决
     * */
    @ResponseBody
    @RequestMapping(value = "actDesignUnitNew")
    public AjaxJson actDesignUnitNew(Act act, DistributionNetworkProcess reserveProcess) throws Exception {
        AjaxJson j = new AjaxJson();

        String flag = act.getFlag();
        //提交流程任务
        Map<String, Object> vars = Maps.newHashMap();
        String comment = URLDecoder.decode(act.getComment(), "UTF-8");
        act.setComment(comment);
        DistributionNetwork network = networkService.getByReserveId(reserveProcess.getProjectReserveId());
        if ("agree".equals(flag)){
            network.setProblemSolver(reserveProcess.getProblemSolver());
            network.setProblemResolved(reserveProcess.getProblemResolved());
            network.setProblemResolvedDescript(reserveProcess.getProblemResolvedDescript());
            network.setProcessStatus("2");
            vars.put("agree",true);
            vars.put("disAgree",false);
            vars.put("pass",false);
            vars.put("tg",false);
        } else if ("disAgree".equals(flag)){
            //驳回
            network.setProcessStatus("3");
            vars.put("disAgree",true);
            vars.put("agree",false);
            vars.put("pass",false);
            vars.put("tg",false);
        } else if ("pass".equals(flag)){
            //领导审批
            String  userName = networkService.getByUserName(reserveProcess.getProblemSolverLeader());
            network.setProblemSolver("");
            network.setProblemResolved(reserveProcess.getProblemResolved());
            network.setProblemResolvedDescript(reserveProcess.getProblemResolvedDescript());
            network.setDesignChange(reserveProcess.getDesignChange());
            network.setReportToLeader(reserveProcess.getReportToLeader());
            network.setProblemSolverLeader(reserveProcess.getProblemSolverLeader());
            vars.put("manager", userName);
            vars.put("pass",true);
            vars.put("disAgree",false);
            vars.put("agree",false);
            vars.put("tg",false);
        } else if ("tg".equals(flag)){
            //设计单位上传文件
            ReserveProcessProject processProject = projectService.queryByProjectId(reserveProcess.getProjectReserveId());
            network.setProblemSolver("");
            network.setProblemSolverLeader("");
            network.setDesignChange(reserveProcess.getDesignChange());
            network.setChangeType(reserveProcess.getChangeType());
            network.setDesignChangeType(reserveProcess.getDesignChangeType());
            vars.put("manager", UserUtils.getByUserName(processProject.getDesigner()).getLoginName());
            vars.put("pass",false);
            vars.put("disAgree",false);
            vars.put("agree",false);
            vars.put("tg",true);
        }
        act.preUpdate();
        // 提交流程任务
        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);

        networkService.update(network);
        j.setMsg("流程结束");
        return j;
    }

    /***
     * 业主项目经理再次审核
     * */
    @ResponseBody
    @RequestMapping(value = "actDesignUnitAgain")
    public AjaxJson actDesignUnitAgain(Act act, DistributionNetworkProcess reserveProcess) throws Exception {
        AjaxJson j = new AjaxJson();

        String flag = act.getFlag();
        //提交流程任务
        Map<String, Object> vars = Maps.newHashMap();
        String comment = URLDecoder.decode(act.getComment(), "UTF-8");
        act.setComment(comment);
        DistributionNetwork network = networkService.getByReserveId(reserveProcess.getProjectReserveId());
        ReserveProcessProject processProject = projectService.queryByProjectId(reserveProcess.getProjectReserveId());
        if ("agree".equals(flag)){
            vars.put("agree",true);
            vars.put("disAgree",false);
            vars.put("manager", UserUtils.getByUserName(processProject.getTechnicalStaff()).getLoginName());
        } else if ("disAgree".equals(flag)){
            vars.put("manager", UserUtils.getByUserName(processProject.getOwnerReserveProjectManagre()).getLoginName());
            //驳回
            vars.put("disAgree",true);
            vars.put("agree",false);
        }

        // 提交流程任务
        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);

        networkService.update(network);
        j.setMsg("流程结束");
        return j;
    }

    /***
     * 技经人员审核
     * */
    @ResponseBody
    @RequestMapping(value = "technicalStaff")
    public AjaxJson technicalStaff(Act act, DistributionNetworkProcess reserveProcess) throws Exception {
        AjaxJson j = new AjaxJson();

        String flag = act.getFlag();
        //提交流程任务
        Map<String, Object> vars = Maps.newHashMap();
        String comment = URLDecoder.decode(act.getComment(), "UTF-8");
        act.setComment(comment);
        DistributionNetwork network = networkService.getByReserveId(reserveProcess.getProjectReserveId());
        ReserveProcessProject processProject = projectService.queryByProjectId(reserveProcess.getProjectReserveId());
        if ("agree".equals(flag)){
            network.setProcessStatus("2");
            vars.put("agree",true);
            vars.put("disAgree",false);
        } else if ("disAgree".equals(flag)){
            vars.put("manager", UserUtils.getByUserName(processProject.getOwnerReserveProjectManagre()).getLoginName());
            //驳回
            vars.put("disAgree",true);
            vars.put("agree",false);
        }

        // 提交流程任务
        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);

        networkService.update(network);
        j.setMsg("流程结束");
        return j;
    }

    /***
     * 业主单位领导 - 问题已解决
     * */
    @ResponseBody
    @RequestMapping(value = "actDesignUnitLeader")
    public AjaxJson actDesignUnitLeader(Act act, DistributionNetworkProcess reserveProcess) throws Exception {
        AjaxJson j = new AjaxJson();
        String comment = URLDecoder.decode(act.getComment(), "UTF-8");
        act.setComment(comment);
        String flag = act.getFlag();
        //提交流程任务
        Map<String, Object> vars = Maps.newHashMap();
        DistributionNetwork network = networkService.getByReserveId(reserveProcess.getProjectReserveId());
        if ("agree".equals(flag)){
            network.setProblemResolvedLeader(reserveProcess.getProblemResolvedLeader());
            network.setProblemResolvedDescriptLeader(reserveProcess.getProblemResolvedDescriptLeader());
            network.setProcessStatus("2");
            vars.put("agree",true);
            vars.put("disAgree",false);
            vars.put("tg",false);
        } else if ("disAgree".equals(flag)){
            ReserveProcessProject processProject = projectService.queryByProjectId(reserveProcess.getProjectReserveId());
            //驳回
            network.setProblemSolverLeader("");
            vars.put("disAgree",true);
            vars.put("agree",false);
            vars.put("tg",false);
            vars.put("manager", UserUtils.getByUserName(processProject.getOwnerReserveProjectManagre()).getLoginName());
            network.setProblemResolvedLeader(reserveProcess.getProblemResolvedLeader());
        } else if ("tg".equals(flag)){
            network.setProblemResolvedLeader(reserveProcess.getProblemResolvedLeader());
            //设计单位上传文件
            ReserveProcessProject processProject = projectService.queryByProjectId(reserveProcess.getProjectReserveId());
            network.setProblemSolver(reserveProcess.getProblemSolver());
            network.setProblemSolverLeader(reserveProcess.getProblemSolverLeader());
            network.setDesignChangeLeader(reserveProcess.getDesignChangeLeader());
            network.setChangeTypeLeader(reserveProcess.getChangeTypeLeader());
            network.setDesignChangeTypeLeader(reserveProcess.getDesignChangeTypeLeader());
            vars.put("manager", UserUtils.getByUserName(processProject.getDesigner()).getLoginName());
            vars.put("disAgree",false);
            vars.put("agree",false);
            vars.put("tg",true);
        }

        // 提交流程任务
        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);

        networkService.update(network);
        j.setMsg("流程结束");
        return j;
    }

    /**
     * 提交任务, 并保存意见
     *
     * @param taskId    任务ID
     * @param procInsId 流程实例ID，如果为空，则不保存任务提交意见
     * @param comment   任务提交意见的内容
     * @param vars      任务变量
     */
    @Transactional(readOnly = false)
    public void complete(String taskId, String procInsId, String comment, Map<String, Object> vars) {
        complete(taskId, procInsId, comment, "", vars);
    }

    @Transactional(readOnly = false)
    public void complete(String taskId, String procInsId, String comment, String title, Map<String, Object> vars) {
        // 添加意见
        if (StringUtils.isNotBlank(procInsId) && StringUtils.isNotBlank(comment)) {
            taskService.addComment(taskId, procInsId, comment);
        }

        // 设置流程变量
        if (vars == null) {
            vars = Maps.newHashMap();
        }

        // 设置流程标题
        if (StringUtils.isNotBlank(title)) {
            vars.put("title", title);
        }

        // 提交任务
        taskService.complete(taskId, vars);
    }

    /***
     * 设计单位审核
     * */
    @ResponseBody
    @RequestMapping(value = "actDesignUnitFile")
    public AjaxJson actDesignUnitFile(Act act, ReserveSummaryProcess reserveProcess,String material,String drjgc,String uid) throws Exception {
        AjaxJson j = new AjaxJson();

        if (material != null || drjgc != null){
            //将上传的文件进行持久化操作
            //保存文件地址
            DocumentInfo infoByProId = new DocumentInfo(reserveProcess.getProjectReserveId(),reserveProcess.getBudgetStatement(),reserveProcess.getProjectProposal(),
                    reserveProcess.getDrawings(),
                    reserveProcess.getDrawingSpecification(),reserveProcess.getDemolition(),
                    reserveProcess.getApprovalForm());
            infoService.distributionFileSave(infoByProId);

            //在将拆旧清册数据存入数据库前先查出库中有没有这个project ReserveId的相关数据
            String projectReserveId = reserveProcess.getProjectReserveId();
            demoliteService.deleteDistributionByProjectReserveId(projectReserveId);
            //获取拆旧清册数据
            //String index out of range: -1 这个异常一般是截取字符串时报的错误。
            File file = new File(reserveProcess.getDemolition());
            String path = file.getAbsolutePath();
//            int index = file.getAbsolutePath().indexOf("\\fileServer");
            int index = file.getAbsolutePath().indexOf("fileServer");
//            path = path.substring(index);

            String FILE_PREFIX = loader.getProperty("linux.file.store.prefix");

            if (SYS_TYPE.equals("1")) {
                path = path.substring(index-1);

            } else {
                //liunx file store prefix
                path = FILE_PREFIX + Servlets.getRequest().getContextPath() + path.substring(index-1);
                path = path.replaceAll("\\\\","/");
            }

            File demoFile = new File(path);

            InputStream inputStream = new FileInputStream(demoFile);
            MultipartFile multipartFile = new MockMultipartFile("file", demoFile.getName(), null, inputStream);
            ImportUtil importUtil = new ImportUtil(multipartFile, 0, 0);
            //获取导入表格所有数据
            List<Demolite> reserveManagementList = ReserveProcessProjectProUtil.getDemoliteUtil(importUtil, projectReserveId);
            //将数据存入数据库
            demoliteService.insertDistributionList(reserveManagementList);

            String flag = act.getFlag();
            try {
                String comment = URLDecoder.decode(act.getComment(), "UTF-8");
                act.setComment(comment);
                if ("yes".equals(flag)) {

                    //从redis中查看是否有在线开甲供材数据
                    List<?> list = DataList.getList(reserveProcess.getProjectReserveId());
                    List<MaterialInfo> infoList = new ArrayList<>();
                    ShowList showList = null;
                    MaterialInfo info = null;
                    if ("".equals(drjgc) & "".equals(material)) {
                        j.setMsg("该项目没有甲供材清册");
                        j.setSuccess(false);
                        return j;
                    }else if ("".equals(drjgc) & !"".equals(material)){
                        //将redis中的数据存入数据库   cg_material_data
                        for (int i=0;i<list.size();i++){
                            showList = (ShowList) list.get(i);
                            info = new MaterialInfo();
                            info.setProjectName(showList.getProjectName());
                            info.setMaterialCode(showList.getMaterialCode());
                            info.setMaterialName(showList.getMaterialDescription());
                            info.setExtendDescription(showList.getExtensionDescription());
                            info.setUnit(showList.getMdUnits());
                            info.setTotalCount(showList.getMdTotalAmount());
                            info.setWeightKg(showList.getMdSingleWeight());
                            info.setWeightTon(showList.getMdTotalWeight());
                            info.setSupplyType(showList.getMdTheParty());
                            info.setNote(showList.getMdText());
                            infoList.add(info);
                        }
                        //保存甲供材信息
                        reserveProcessService.saveDistributionList(infoList);
                        //保存项目储备编号及电缆分段存入redis的id
                        //保存前先根据项目储备编号去删除
                        cableService.deleteDistributionCableRedis(reserveProcess.getProjectReserveId());
                        cableService.insertDistributionIntoCableRedis(reserveProcess.getProjectReserveId(),uid);

                        //提交流程任务
                        Map<String, Object> vars = Maps.newHashMap();
                        ReserveProcessProject processProject = projectService.queryByProjectId(reserveProcess.getProjectReserveId());
                        vars.put("manager", UserUtils.getByUserName(processProject.getOwnerReserveProjectManagre()).getLoginName());
                        // 提交流程任务
                        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);

                    }
                }
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
        }

        j.setMsg("审批成功");
        return j;
    }

    /**
     * 年度物资上报明细 多文件导入验证
     */
    @ResponseBody
    @RequestMapping(value = "importCGValidations")
    public AjaxJson importCGValidations(@RequestParam("file") MultipartFile[] file,String projectReserveId) {
        AjaxJson j = new AjaxJson();

        try {
            for (int k = 0; k < file.length; k++) {
                reserveProcessService.saveDistributData(file[k],projectReserveId);
            }
            j.setSuccess(true);
            j.setErrorCode("0");
            j.setMsg("导入成功");
        } catch (Exception e) {
            j.setSuccess(true);
            j.setMsg("导入失败！失败信息：" + e.getMessage());
        }
        return j;
    }
}
