package com.jeeplus.modules.cg.reservemanagementcenter.distribution.web;

import com.google.common.collect.Maps;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.entity.DistributionDesignChange;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.service.DistributionDesignChangeService;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.util.DistributionExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.util.DistributionImportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ReserveProcessProject;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ProjectTypeVerificateService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.ProgressStatsService;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import com.jeeplus.modules.sg.picking.activiti.entity.PickList;
import com.jeeplus.modules.sg.raiseCapital.service.RaiseCapitalService;
import com.jeeplus.modules.sys.utils.UserUtils;
import org.activiti.engine.repository.ProcessDefinition;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 配网项目设计变更记录表
 * @author 王强
 * @version 1.0
 * @date 2023-09-07 10:06
 */
@Controller
@RequestMapping(value = "${adminPath}/cg/distribution/designChange")
public class DistributionDesignChangeController extends BaseController {

    @Autowired
    private DistributionDesignChangeService designChangeService;

    @Autowired
    private ProgressStatsService statsService;

    @Autowired
    private ProjectTypeVerificateService verificateService;

    @Autowired
    private RaiseCapitalService raiseCapitalService;

    @ModelAttribute
    public DistributionDesignChange get(@RequestParam(required = false) String id) {
        DistributionDesignChange entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = designChangeService.get(id);
        }
        if (entity == null) {
            entity = new DistributionDesignChange();
        }

        if (StringUtils.isNotBlank(entity.getDesignChangeTypeLeader())){
            entity.setDesignChangeType(entity.getDesignChangeTypeLeader());
        }
        if (StringUtils.isNotBlank(entity.getChangeTypeLeader())){
            entity.setChangeType(entity.getChangeTypeLeader());
        }
        //设置设计变更状态
        String procInsId = statsService.getDistributionByProjectReserveId(entity.getProjectReserveId());
        List<History> jlHistory = statsService.getHistoryByProInsId(procInsId, "是否需上报领导");
        if (jlHistory.size()>0){
            //获取最近的一个上报领导节点，
            //根据这个节点的结束时间去查下一个节点信息，该节点的结束时间也是下一个节点的开始时间
            if (StringUtils.isNotBlank(jlHistory.get(0).getEndTime())){
                //不为空，说明已经到了  领导审核节点或者是设计变更节点
                History history = statsService.getHistoryByStartTime(jlHistory.get(0).getEndTime());
                if (null == history) {
                    //流程直接结束了
                    entity.setDesignChangeStatus("无");
                } else if (history.getName().equals("领导-问题审核")){
                    //根据领导审核节点的结束时间去查下一个节点的信息，判断是结束了还是设计变更节点
                    if (StringUtils.isNotBlank(history.getEndTime())){
                        //说明领导审批流程结束
                        history = statsService.getHistoryByStartTime(history.getEndTime());
                        if (null != history) {
                            //说明流程没有结束
                            if (StringUtils.isNotBlank(history.getEndTime())){
                                //设计单位上传预算书节点结束了
                                entity.setDesignChangeStatus("已变更");
                                entity.setCompleteDesignChangeType("是");
                                history = statsService.getHistoryByStartTime(history.getEndTime());
                                if (StringUtils.isNotBlank(history.getEndTime())){
                                    //说明通过了项目经理-审核节点
                                    entity.setProjectManagerApproved("是");
                                    entity.setElectronDiagramCompleteTime(history.getEndTime());
                                    //根据项目经理-审核节点的结束时间查技经人员审核节点信息
                                    history = statsService.getHistoryByStartTime(history.getEndTime());
                                    if (StringUtils.isNotBlank(history.getEndTime())){
                                        //通过了
                                        entity.setCompleteBudgetAdjust("是");
                                        entity.setJjApproved("是");
                                        entity.setBudgetCompleteTime(history.getEndTime());
                                    } else {
                                        entity.setJjApproved("否");
                                    }
                                } else {
                                    entity.setProjectManagerApproved("否");
                                }
                            } else {
                                entity.setDesignChangeStatus("变更中");
                                entity.setCompleteDesignChangeType("否");
                                entity.setProjectManagerApproved("否");
                            }
                            entity.setDesignChangeProposeTime(history.getStartTime());
                        } else {
                            //流程直接结束了
                            entity.setDesignChangeStatus("无");
                            entity.setCompleteDesignChangeType("否");
                            entity.setProjectManagerApproved("否");
                        }
                    }


                }else if (history.getName().equals("设计单位上传预算书")){
                    //设计变更节点
                    if (StringUtils.isNotBlank(history.getEndTime())){
                        //设计单位上传预算书节点结束了
                        entity.setDesignChangeStatus("已变更");
                        entity.setCompleteDesignChangeType("是");
                        //根据上传预算书节点的结束时间去查项目经理-审核节点的信息
                        history = statsService.getHistoryByStartTime(history.getEndTime());
                        if (StringUtils.isNotBlank(history.getEndTime())){
                            //说明通过了项目经理-审核节点
                            entity.setProjectManagerApproved("是");
                            entity.setElectronDiagramCompleteTime(history.getEndTime());
                            history = statsService.getHistoryByStartTime(history.getEndTime());
                            if (StringUtils.isNotBlank(history.getEndTime())){
                                //通过了
                                entity.setCompleteBudgetAdjust("是");
                                entity.setJjApproved("是");
                                entity.setBudgetCompleteTime(history.getEndTime());
                            } else {
                                entity.setJjApproved("否");
                            }
                        } else {
                            entity.setProjectManagerApproved("否");
                        }
                    } else {
                        entity.setDesignChangeStatus("变更中");
                        entity.setCompleteDesignChangeType("否");
                        entity.setProjectManagerApproved("否");
                    }
                    entity.setDesignChangeProposeTime(history.getStartTime());
                }
            } else {
                //说明才发起流程，是否上报领导节点未结束
                entity.setDesignChangeStatus("无");
                entity.setCompleteDesignChangeType("否");
                entity.setProjectManagerApproved("否");
            }

            //计算设计变更时长
            // 定义两个 LocalDateTime 对象
            if (StringUtils.isNotBlank(entity.getBudgetCompleteTime())){
                DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
                LocalDateTime dateTime1 = LocalDateTime.parse(entity.getBudgetCompleteTime(), formatter);
                LocalDateTime dateTime2 = LocalDateTime.parse(jlHistory.get(0).getStartTime(), formatter);

                // 计算两个日期时间之间的时间差（秒数）
                Long time = ChronoUnit.SECONDS.between(dateTime2, dateTime1);

                entity.setDesignChangeTime(time.toString());
            }

        }
        return entity;
    }

    /**
     * 项目储备信息列表页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions("cg:distribution:designChange:list")
    @RequestMapping(value = "skipList")
    public String skipList(DistributionDesignChange reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/distribution/designChange/reserveManagementInformation";
    }

    /**
     * 查看表单页面
     */
    @RequiresPermissions(value={"cg:distribution:designChange:view"},logical= Logical.OR)
    @RequestMapping(value = "view")
    public String view(DistributionDesignChange reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/distribution/designChange/reserveManagementView";
    }

    /**
     * 项目储备信息数据列表
     * @param reserveManagement
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:distribution:designChange:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(DistributionDesignChange reserveManagement, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<DistributionDesignChange> page = designChangeService.findPage(new Page<DistributionDesignChange>(request, response), reserveManagement);
        List<DistributionDesignChange> list = page.getList();
        List<DistributionDesignChange> changes = new ArrayList<>();

        List<String> nameList = new ArrayList<>();
        //获取所有小类的名称
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        DistributionDesignChange change = new DistributionDesignChange();
        for (int i=0;i<list.size();i++){
            change = list.get(i);

            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = verificateService.getMaterialName2(change.getProjectName());
            if (null != nameList & null != materialNameList){
                DistributionDesignChange finalChange = change;
                nameList.forEach(n->{
                    if (StringUtils.isBlank(finalChange.getProjectNature())){
                        if (materialNameList.contains(n)){
                            finalChange.setProjectNature("资本");
                        } else {
                            finalChange.setProjectNature("成本");
                        }
                    }
                });
            }

            if (StringUtils.isBlank(change.getDesignChangeType())){
                change.setDesignChangeType(change.getDesignChangeTypeLeader());
            }
            if (StringUtils.isBlank(change.getChangeType())){
                change.setChangeType(change.getChangeTypeLeader());
            }
            //设置设计变更状态
            String procInsId = statsService.getDistributionByProjectReserveId(change.getProjectReserveId());
            List<History> jlHistory = statsService.getHistoryByProInsId(procInsId, "是否需上报领导");
            if (jlHistory.size()>0){
                //获取最近的一个上报领导节点，
                //根据这个节点的结束时间去查下一个节点信息，该节点的结束时间也是下一个节点的开始时间
                if (StringUtils.isNotBlank(jlHistory.get(0).getEndTime())){
                    //不为空，说明已经到了  领导审核节点或者是设计变更节点
                    History history = statsService.getHistoryByStartTime(jlHistory.get(0).getEndTime());
                    if (null == history) {
                        //流程直接结束了
                        change.setDesignChangeStatus("无");
                    } else if (history.getName().equals("领导-问题审核")){
                        //根据领导审核节点的结束时间去查下一个节点的信息，判断是结束了还是设计变更节点
                        if (StringUtils.isNotBlank(history.getEndTime())){
                            //说明领导审批流程结束
                            history = statsService.getHistoryByStartTime(history.getEndTime());
                            if (null != history) {
                                //说明流程没有结束
                                if (StringUtils.isNotBlank(history.getEndTime())){
                                    //设计单位上传预算书节点结束了
                                    change.setDesignChangeStatus("已变更");
                                    change.setCompleteDesignChangeType("是");
                                    history = statsService.getHistoryByStartTime(history.getEndTime());
                                    if (StringUtils.isNotBlank(history.getEndTime())){
                                        //说明通过了项目经理-审核节点
                                        change.setProjectManagerApproved("是");
                                        change.setElectronDiagramCompleteTime(history.getEndTime());
                                        //根据项目经理-审核节点的结束时间查技经人员审核节点信息
                                        history = statsService.getHistoryByStartTime(history.getEndTime());
                                        if (StringUtils.isNotBlank(history.getEndTime())){
                                            //通过了
                                            change.setCompleteBudgetAdjust("是");
                                            change.setJjApproved("是");
                                            change.setBudgetCompleteTime(history.getEndTime());
                                        } else {
                                            change.setJjApproved("否");
                                        }
                                    } else {
                                        change.setProjectManagerApproved("否");
                                    }
                                } else {
                                    change.setDesignChangeStatus("变更中");
                                    change.setCompleteDesignChangeType("否");
                                    change.setProjectManagerApproved("否");
                                }
                                change.setDesignChangeProposeTime(history.getStartTime());
                            } else {
                                //流程直接结束了
                                change.setDesignChangeStatus("无");
                                change.setCompleteDesignChangeType("否");
                                change.setProjectManagerApproved("否");
                            }
                        }


                    }else if (history.getName().equals("设计单位上传预算书")){
                        //设计变更节点
                        if (StringUtils.isNotBlank(history.getEndTime())){
                            //设计单位上传预算书节点结束了
                            change.setDesignChangeStatus("已变更");
                            change.setCompleteDesignChangeType("是");
                            //根据上传预算书节点的结束时间去查项目经理-审核节点的信息
                            history = statsService.getHistoryByStartTime(history.getEndTime());
                            if (StringUtils.isNotBlank(history.getEndTime())){
                                //说明通过了项目经理-审核节点
                                change.setProjectManagerApproved("是");
                                change.setElectronDiagramCompleteTime(history.getEndTime());
                                history = statsService.getHistoryByStartTime(history.getEndTime());
                                if (StringUtils.isNotBlank(history.getEndTime())){
                                    //通过了
                                    change.setCompleteBudgetAdjust("是");
                                    change.setJjApproved("是");
                                    change.setBudgetCompleteTime(history.getEndTime());
                                } else {
                                    change.setJjApproved("否");
                                }
                            } else {
                                change.setProjectManagerApproved("否");
                            }
                        } else {
                            change.setDesignChangeStatus("变更中");
                            change.setCompleteDesignChangeType("否");
                            change.setProjectManagerApproved("否");
                        }
                        change.setDesignChangeProposeTime(history.getStartTime());
                    }
                } else {
                    //说明才发起流程，是否上报领导节点未结束
                    change.setDesignChangeStatus("无");
                    change.setCompleteDesignChangeType("否");
                    change.setProjectManagerApproved("否");
                }

                //计算设计变更时长
                // 定义两个 LocalDateTime 对象
                if (StringUtils.isNotBlank(change.getBudgetCompleteTime())){
                    DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
                    LocalDateTime dateTime1 = LocalDateTime.parse(change.getBudgetCompleteTime(), formatter);
                    LocalDateTime dateTime2 = LocalDateTime.parse(jlHistory.get(0).getStartTime(), formatter);

                    // 计算两个日期时间之间的时间差（秒数）
                    Long time = ChronoUnit.SECONDS.between(dateTime2, dateTime1);

                    change.setDesignChangeTime(time.toString());
                }

            }

            changes.add(change);
        }

        return getBootstrapData(page);
    }

    /**
     * 专职人员增加，编辑表单页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:distribution:designChange:add","cg:distribution:designChange:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(DistributionDesignChange reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(reserveManagement.getId())){
            return "modules/cg/reservemanagementcenter/distribution/designChange/reserveManagementForm";
        }
        return "modules/cg/reservemanagementcenter/distribution/designChange/reserveManagementModifyByzz";
    }

    /**
     * 专职人员保存表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:distribution:designChange:add"},logical=Logical.OR)
    @RequestMapping(value = "save")
    public AjaxJson save(DistributionDesignChange reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //新增或编辑表单保存
        designChangeService.save(reserveManagement);//保存
        j.setSuccess(true);
        j.setMsg("保存政策处理进度表信息成功");
        return j;
    }

    /**
     * 专职人员修改表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:distribution:designChange:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(DistributionDesignChange reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }

        //根据项目储备编号查是否有改数据
        DistributionDesignChange safety = designChangeService.getByReserveId(reserveManagement.getProjectReserveId());
        if (null == safety){
            safety = new DistributionDesignChange();
            safety.setProjectReserveId(reserveManagement.getProjectReserveId());
            safety.setDesignChangeContent(reserveManagement.getDesignChangeContent());
            safety.setDrawingTransfer(reserveManagement.getDrawingTransfer());
            safety.setDrawingTransferTime(reserveManagement.getDrawingTransferTime());
            safety.setDataIntegrity(reserveManagement.getDataIntegrity());
            safety.setRemarks(reserveManagement.getRemarks());
        }else {
            safety.setProjectReserveId(reserveManagement.getProjectReserveId());
            safety.setDesignChangeContent(reserveManagement.getDesignChangeContent());
            safety.setDrawingTransfer(reserveManagement.getDrawingTransfer());
            safety.setDrawingTransferTime(reserveManagement.getDrawingTransferTime());
            safety.setDataIntegrity(reserveManagement.getDataIntegrity());
            safety.setRemarks(reserveManagement.getRemarks());
        }

        designChangeService.save(safety);
        j.setSuccess(true);
        j.setMsg("修改政策处理进度表信息成功");
        return j;
    }

    /**
     * 导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:distribution:designChange:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);

            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = designChangeService.getAllProId();

            //从基本数据表中查出所有的 项目储备编号
            List<String> proIdList2 = designChangeService.getAllProId2();

            //获取导入表格所有数据
            List<DistributionDesignChange> reserveManagementList = DistributionImportUtil.getDistributionDesignChangeUtil(importUtil,proIdList,proIdList2);
            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = designChangeService.getExistProjectList(reserveManagementList);
            //未存在数据
            List<DistributionDesignChange> withoutList = (List<DistributionDesignChange>) map.get("without");
            //已存在数据
            List<DistributionDesignChange> existList = (List<DistributionDesignChange>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                designChangeService.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (DistributionDesignChange reserveManagement : existList) {
                    designChangeService.update(reserveManagement);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条政策处理进度表信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入政策处理进度表信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:distribution:designChange:export")
    @RequestMapping(value = "export")
    public void exportExcel(DistributionDesignChange reserveManagement, HttpServletRequest request, HttpServletResponse response) {
        List<DistributionDesignChange> list = designChangeService.exportFindList(reserveManagement);

        List<DistributionDesignChange> changes = new ArrayList<>();
        DistributionDesignChange change = new DistributionDesignChange();
        for (int i=0;i<list.size();i++){
            change = list.get(i);
            if (StringUtils.isBlank(change.getDesignChangeType())){
                change.setDesignChangeType(change.getDesignChangeTypeLeader());
            }
            if (StringUtils.isBlank(change.getChangeType())){
                change.setChangeType(change.getChangeTypeLeader());
            }
            //设置设计变更状态
            String procInsId = statsService.getDistributionByProjectReserveId(change.getProjectReserveId());
            List<History> jlHistory = statsService.getHistoryByProInsId(procInsId, "是否需上报领导");
            if (jlHistory.size()>0){
                //获取最近的一个上报领导节点，
                //根据这个节点的结束时间去查下一个节点信息，该节点的结束时间也是下一个节点的开始时间
                if (StringUtils.isNotBlank(jlHistory.get(0).getEndTime())){
                    //不为空，说明已经到了  领导审核节点或者是设计变更节点
                    History history = statsService.getHistoryByStartTime(jlHistory.get(0).getEndTime());
                    if (null == history) {
                        //流程直接结束了
                        change.setDesignChangeStatus("无");
                    } else if (history.getName().equals("领导-问题审核")){
                        //根据领导审核节点的结束时间去查下一个节点的信息，判断是结束了还是设计变更节点
                        if (StringUtils.isNotBlank(history.getEndTime())){
                            //说明领导审批流程结束
                            history = statsService.getHistoryByStartTime(history.getEndTime());
                            if (null != history) {
                                //说明流程没有结束
                                if (StringUtils.isNotBlank(history.getEndTime())){
                                    //设计单位上传预算书节点结束了
                                    change.setDesignChangeStatus("已变更");
                                    change.setCompleteDesignChangeType("是");
                                    history = statsService.getHistoryByStartTime(history.getEndTime());
                                    if (StringUtils.isNotBlank(history.getEndTime())){
                                        //说明通过了项目经理-审核节点
                                        change.setProjectManagerApproved("是");
                                        change.setElectronDiagramCompleteTime(history.getEndTime());
                                        //根据项目经理-审核节点的结束时间查技经人员审核节点信息
                                        history = statsService.getHistoryByStartTime(history.getEndTime());
                                        if (StringUtils.isNotBlank(history.getEndTime())){
                                            //通过了
                                            change.setCompleteBudgetAdjust("是");
                                            change.setJjApproved("是");
                                            change.setBudgetCompleteTime(history.getEndTime());
                                        } else {
                                            change.setJjApproved("否");
                                        }
                                    } else {
                                        change.setProjectManagerApproved("否");
                                    }
                                } else {
                                    change.setDesignChangeStatus("变更中");
                                    change.setCompleteDesignChangeType("否");
                                    change.setProjectManagerApproved("否");
                                }
                                change.setDesignChangeProposeTime(history.getStartTime());
                            } else {
                                //流程直接结束了
                                change.setDesignChangeStatus("无");
                                change.setCompleteDesignChangeType("否");
                                change.setProjectManagerApproved("否");
                            }
                        }


                    }else if (history.getName().equals("设计单位上传预算书")){
                        //设计变更节点
                        if (StringUtils.isNotBlank(history.getEndTime())){
                            //设计单位上传预算书节点结束了
                            change.setDesignChangeStatus("已变更");
                            change.setCompleteDesignChangeType("是");
                            //根据上传预算书节点的结束时间去查项目经理-审核节点的信息
                            history = statsService.getHistoryByStartTime(history.getEndTime());
                            if (StringUtils.isNotBlank(history.getEndTime())){
                                //说明通过了项目经理-审核节点
                                change.setProjectManagerApproved("是");
                                change.setElectronDiagramCompleteTime(history.getEndTime());
                                history = statsService.getHistoryByStartTime(history.getEndTime());
                                if (StringUtils.isNotBlank(history.getEndTime())){
                                    //通过了
                                    change.setCompleteBudgetAdjust("是");
                                    change.setJjApproved("是");
                                    change.setBudgetCompleteTime(history.getEndTime());
                                } else {
                                    change.setJjApproved("否");
                                }
                            } else {
                                change.setProjectManagerApproved("否");
                            }
                        } else {
                            change.setDesignChangeStatus("变更中");
                            change.setCompleteDesignChangeType("否");
                            change.setProjectManagerApproved("否");
                        }
                        change.setDesignChangeProposeTime(history.getStartTime());
                    }
                } else {
                    //说明才发起流程，是否上报领导节点未结束
                    change.setDesignChangeStatus("无");
                    change.setCompleteDesignChangeType("否");
                    change.setProjectManagerApproved("否");
                }

                //计算设计变更时长
                // 定义两个 LocalDateTime 对象
                if (StringUtils.isNotBlank(change.getBudgetCompleteTime())){
                    DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
                    LocalDateTime dateTime1 = LocalDateTime.parse(change.getBudgetCompleteTime(), formatter);
                    LocalDateTime dateTime2 = LocalDateTime.parse(jlHistory.get(0).getStartTime(), formatter);

                    // 计算两个日期时间之间的时间差（秒数）
                    Long time = ChronoUnit.SECONDS.between(dateTime2, dateTime1);

                    change.setDesignChangeTime(time.toString());
                }

            }

            changes.add(change);
        }

        //生成序列号
        int j = 1;
        for (DistributionDesignChange s : changes) {
            s.setId(String.valueOf(j));
            j++;
        }

        DistributionExportUtil util = DistributionExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("distributionDesignChange");
        util.exportDistributionDesignChange(response,workbook,changes);
    }
}
