package com.jeeplus.modules.cg.reservemanagementcenter.distribution.web;

import com.google.common.collect.Maps;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.act.service.ActProcessService;
import com.jeeplus.modules.act.service.ActTaskService;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.entity.DistributionNetwork;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.entity.DistributionNetworkProcess;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.service.DistributionNetworkProcessService;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.service.DistributionNetworkService;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.util.DistributionExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.distribution.util.DistributionImportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ReserveProcessProject;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ProjectTypeVerificateService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveProcessProjectService;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import com.jeeplus.modules.sg.picking.activiti.entity.PickList;
import com.jeeplus.modules.sg.raiseCapital.service.RaiseCapitalService;
import com.jeeplus.modules.sys.utils.UserUtils;
import org.activiti.engine.repository.ProcessDefinition;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.StringJoiner;

/**
 * 配网项目配网项目问题表表
 * @author 王强
 * @version 1.0
 * @date 2023-09-07 9:35
 */
@Controller
@RequestMapping(value = "${adminPath}/cg/distribution/network")
public class DistributionNetworkController extends BaseController {

    @Autowired
    private ActTaskService actTaskService;

    @Autowired
    private ReserveProcessProjectService projectService;

    @Autowired
    private DistributionNetworkService networkService;

    @Autowired
    private ActProcessService actProcessService;

    @Autowired
    private DistributionNetworkProcessService processService;

    @Autowired
    private ProjectTypeVerificateService verificateService;

    @Autowired
    private RaiseCapitalService raiseCapitalService;

    @ModelAttribute
    public DistributionNetwork get(@RequestParam(required = false) String id) {
        DistributionNetwork entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = networkService.get(id);
        }
        if (entity == null) {
            entity = new DistributionNetwork();
        }
        return entity;
    }

    /**
     * 项目储备信息列表页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions("cg:distribution:network:list")
    @RequestMapping(value = "skipList")
    public String skipList(DistributionNetwork reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/distribution/network/reserveManagementInformation";
    }

    /**
     * 查看表单页面
     */
    @RequiresPermissions(value={"cg:distribution:network:view"},logical= Logical.OR)
    @RequestMapping(value = "view")
    public String view(DistributionNetwork reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/distribution/network/reserveManagementView";
    }

    /**
     * 项目储备信息数据列表
     * @param reserveManagement
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:distribution:network:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(DistributionNetwork reserveManagement, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<DistributionNetwork> page = networkService.findPage(new Page<DistributionNetwork>(request, response), reserveManagement);
        List<DistributionNetwork> list = page.getList();

        List<String> nameList = new ArrayList<>();
        //获取所有小类的名称
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        for (DistributionNetwork network : list) {
            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = verificateService.getMaterialName2(network.getProjectName());
            if (null != nameList & null != materialNameList){
                nameList.forEach(n->{
                    if (StringUtils.isBlank(network.getProjectNature())){
                        if (materialNameList.contains(n)){
                            network.setProjectNature("资本");
                        } else {
                            network.setProjectNature("成本");
                        }
                    }
                });
            }
        }


        return getBootstrapData(page);
    }

    /**
     * 专职人员增加，编辑表单页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:distribution:network:add","cg:distribution:network:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(DistributionNetwork reserveManagement, Model model) {
        if (StringUtils.isBlank(reserveManagement.getPromoter())){
            //获取当前用户
            String loginName = UserUtils.getUser().getName();
            reserveManagement.setPromoter(loginName);
        }
        model.addAttribute("reserveManagement", reserveManagement);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(reserveManagement.getId())){
            return "modules/cg/reservemanagementcenter/distribution/network/reserveManagementForm";
        }
        return "modules/cg/reservemanagementcenter/distribution/network/reserveManagementModifyByzz";
    }

    /**
     * 专职人员保存表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:distribution:network:add"},logical=Logical.OR)
    @RequestMapping(value = "save")
    public AjaxJson save(DistributionNetwork reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //新增或编辑表单保存
        networkService.save(reserveManagement);//保存
        j.setSuccess(true);
        j.setMsg("保存政策处理进度表信息成功");
        return j;
    }

    /**
     * 专职人员修改表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:distribution:network:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(DistributionNetwork reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        if (StringUtils.isBlank(reserveManagement.getReserStatus()) || !reserveManagement.getReserStatus().equals("2")){
            j.setSuccess(false);
            j.setMsg("该项目储备流程未结束，无法发起问题发起流程!");
            return j;
        }
        if (StringUtils.isNotBlank(reserveManagement.getProcessStatus()) && (reserveManagement.getProcessStatus().equals("1")||
                reserveManagement.getProcessStatus().equals("2"))){
            j.setSuccess(false);
            j.setMsg("该项目问题发起流程在进行中或已完成，无法进行修改!");
            return j;
        }

        //根据项目储备编号查是否有改数据
        DistributionNetwork safety = networkService.getByReserveId(reserveManagement.getProjectReserveId());
        if (null == safety){
            safety = new DistributionNetwork();
            safety.setProjectReserveId(reserveManagement.getProjectReserveId());
            safety.setPromoter(reserveManagement.getPromoter());
            safety.setProblemStage(reserveManagement.getProblemStage());
            safety.setProblemType(reserveManagement.getProblemType());
            safety.setProblemDescript(reserveManagement.getProblemDescript());
            safety.setProblemSolver(reserveManagement.getProblemSolver());
            safety.setProblemResolved(reserveManagement.getProblemResolved());
            safety.setProblemResolvedDescript(reserveManagement.getProblemResolvedDescript());
            safety.setDesignChange(reserveManagement.getDesignChange());
            safety.setChangeType(reserveManagement.getChangeType());
            safety.setDesignChangeType(reserveManagement.getDesignChangeType());
            safety.setReportToLeader(reserveManagement.getReportToLeader());
            safety.setProblemSolverLeader(reserveManagement.getProblemSolverLeader());
            safety.setProblemResolvedLeader(reserveManagement.getProblemResolvedLeader());
            safety.setProblemResolvedDescriptLeader(reserveManagement.getProblemResolvedDescriptLeader());
            safety.setDesignChangeLeader(reserveManagement.getDesignChangeLeader());
            safety.setChangeTypeLeader(reserveManagement.getChangeTypeLeader());
            safety.setDesignChangeTypeLeader(reserveManagement.getDesignChangeTypeLeader());
            safety.setProcessStatus("1");
        }else {
            safety.setProjectReserveId(reserveManagement.getProjectReserveId());
            safety.setPromoter(reserveManagement.getPromoter());
            safety.setProblemStage(reserveManagement.getProblemStage());
            safety.setProblemType(reserveManagement.getProblemType());
            safety.setProblemDescript(reserveManagement.getProblemDescript());
            safety.setProblemSolver(reserveManagement.getProblemSolver());
            safety.setProblemResolved(reserveManagement.getProblemResolved());
            safety.setProblemResolvedDescript(reserveManagement.getProblemResolvedDescript());
            safety.setDesignChange(reserveManagement.getDesignChange());
            safety.setChangeType(reserveManagement.getChangeType());
            safety.setDesignChangeType(reserveManagement.getDesignChangeType());
            safety.setReportToLeader(reserveManagement.getReportToLeader());
            safety.setProblemSolverLeader(reserveManagement.getProblemSolverLeader());
            safety.setProblemResolvedLeader(reserveManagement.getProblemResolvedLeader());
            safety.setProblemResolvedDescriptLeader(reserveManagement.getProblemResolvedDescriptLeader());
            safety.setDesignChangeLeader(reserveManagement.getDesignChangeLeader());
            safety.setChangeTypeLeader(reserveManagement.getChangeTypeLeader());
            safety.setDesignChangeTypeLeader(reserveManagement.getDesignChangeTypeLeader());
            safety.setProcessStatus("1");
            //新增或编辑表单保存
//            networkService.update(safety);
        }
        //去掉之前的流程，重新开始流程
        networkService.deleteAct(reserveManagement.getProjectReserveId());
        //发起流程
        DistributionNetworkProcess reserveProcess = new DistributionNetworkProcess();
        reserveProcess.preInsert();
        reserveProcess.setProjectReserveId(reserveManagement.getProjectReserveId());
        //更新
        processService.insert(reserveProcess);
        //发送流程，更改项目状态
        Map<String, Object> vars = Maps.newHashMap();

        ReserveProcessProject processProject = projectService.queryByProjectId(reserveManagement.getProjectReserveId());
        //审核代理人
        vars.put("manager", UserUtils.getByUserName(processProject.getOwnerReserveProjectManagre()).getLoginName());
        String procDefId = projectService.findDefId("pwlcTest");
        ProcessDefinition p = actProcessService.getProcessDefinition(procDefId);
        String title = reserveManagement.getCurrentUser().getName() + "在" + DateUtils.getDateTime() + "发起" + p.getName();
        actTaskService.startProcess(p.getKey(), "cg_personnel_activiti_distribution", reserveProcess.getId(), title, vars);

        networkService.save(safety);
        j.setSuccess(true);
        j.setMsg("修改政策处理进度表信息成功");
        return j;
    }

    /**
     * 导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:distribution:network:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);

            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = networkService.getAllProId();

            //从基本数据表中查出所有的 项目储备编号
            List<String> proIdList2 = networkService.getAllProId2();

            //获取导入表格所有数据
            List<DistributionNetwork> reserveManagementList = DistributionImportUtil.getDistributionNetworkUtil(importUtil,proIdList,proIdList2);
            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = networkService.getExistProjectList(reserveManagementList);
            //未存在数据
            List<DistributionNetwork> withoutList = (List<DistributionNetwork>) map.get("without");
            //已存在数据
            List<DistributionNetwork> existList = (List<DistributionNetwork>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                networkService.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (DistributionNetwork reserveManagement : existList) {
                    networkService.update(reserveManagement);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条政策处理进度表信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入政策处理进度表信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:distribution:network:export")
    @RequestMapping(value = "export")
    public void exportExcel(DistributionNetwork reserveManagement, HttpServletRequest request, HttpServletResponse response) {
        List<DistributionNetwork> list = networkService.exportFindList(reserveManagement);

        //生成序列号
        int j = 1;
        for (DistributionNetwork s : list) {
            s.setId(String.valueOf(j));
            j++;
        }

        DistributionExportUtil util = DistributionExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("distributionNetwork");
        util.exportDistributionNetwork(response,workbook,list);
    }
}
