package com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.service;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.entity.PoliceProcessBase;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.mapper.PoliceProcessBaseMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.util.*;

/**
 * @author 王强
 * @version 1.0
 * @date 2023-09-01 15:52
 */
@Service
@Transactional(readOnly = true)
public class PoliceProcessBaseService extends CrudService<PoliceProcessBaseMapper, PoliceProcessBase> {

    @Autowired
    private PoliceProcessBaseMapper dao;

    public PoliceProcessBase getByReserveId(String reserveId){
        return dao.getByReserveId(reserveId);
    }

    public Page<PoliceProcessBase> findPage(Page<PoliceProcessBase> page, PoliceProcessBase reserveManagement) {
        if (StringUtils.isBlank(reserveManagement.getProjectYear())){
            reserveManagement.setProjectYear(LocalDate.now().getYear()+"");
        }
        Page<PoliceProcessBase> pageList = super.findPage(page, reserveManagement);
        return pageList;
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId2(){
        return dao.getAllProId2();
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param reserveManagement
     * @return
     */
    public Map<String, List<PoliceProcessBase>> getExistProjectList(List<PoliceProcessBase> reserveManagement){
        Map<String,List<PoliceProcessBase>> map = new HashMap();
        List<PoliceProcessBase> existReserveManagementList = new ArrayList<>();
        Iterator<PoliceProcessBase> iterator = reserveManagement.iterator();
        while (iterator.hasNext()) {
            PoliceProcessBase rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            PoliceProcessBase reserveManag = dao.queryByProjectReserveId(rm);
            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }
        }
        map.put("without",reserveManagement);
        System.out.println("未存在数据：" + reserveManagement);
        map.put("exist",existReserveManagementList);
        System.out.println("已存在数据：" + existReserveManagementList);
        return map;
    }

    /**
     * 批量添加数据
     * @param reserveManagementList
     */
    @Transactional(readOnly = false)
    public void insertList(List<PoliceProcessBase> reserveManagementList){

        dao.insertList(reserveManagementList);
    }

    /**
     * 专职修改方法
     * @param reserveManagement
     */
    @Transactional(readOnly = false)
    public void update(PoliceProcessBase reserveManagement) {

        super.save(reserveManagement);
    }

    public List<PoliceProcessBase> exportFindList(PoliceProcessBase reserveManagement) {
        List<PoliceProcessBase> pageList = dao.exportFindList(reserveManagement);
        return pageList;
    }

    public String getByProjectReserveId(String projectReserveId){
        return dao.getByProjectReserveId(projectReserveId);
    }

    public List<History> getHistoryByExecuteId(String executeId){
        return dao.getHistoryByExecuteId(executeId);
    }

    public String getByExecuteId(String executeId){
        return dao.getByExecuteId(executeId);
    }
}
