package com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.service;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.entity.PoliceProcessRecord;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.mapper.PoliceProcessRecordMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.util.*;

/**
 * @author 王强
 * @version 1.0
 * @date 2023-09-01 15:48
 */
@Service
@Transactional(readOnly = true)
public class PoliceProcessRecordService extends CrudService<PoliceProcessRecordMapper, PoliceProcessRecord> {

    @Autowired
    private PoliceProcessRecordMapper dao;

    public PoliceProcessRecord get(String id,String serialNumber){
        return dao.get(id,serialNumber);
    }

    public List<String> getSerialNumByReserveId(String projectReserveId){
        return dao.getSerialNumByReserveId(projectReserveId);
    }

    public PoliceProcessRecord getInfoByReserveIdAndNum(String projectReserveId,String serialNumber){
        return dao.getInfoByReserveIdAndNum(projectReserveId,serialNumber);
    }

    public PoliceProcessRecord getByReserveId(String reserveId){
        return dao.getByReserveId(reserveId);
    }

    public Page<PoliceProcessRecord> findPage(Page<PoliceProcessRecord> page, PoliceProcessRecord reserveManagement) {
        if (StringUtils.isBlank(reserveManagement.getProjectYear())){
            reserveManagement.setProjectYear(LocalDate.now().getYear()+"");
        }
        Page<PoliceProcessRecord> pageList = super.findPage(page, reserveManagement);
        return pageList;
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId2(){
        return dao.getAllProId2();
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param reserveManagement
     * @return
     */
    public Map<String, List<PoliceProcessRecord>> getExistProjectList(List<PoliceProcessRecord> reserveManagement){
        Map<String,List<PoliceProcessRecord>> map = new HashMap();
        List<PoliceProcessRecord> existReserveManagementList = new ArrayList<>();
        Iterator<PoliceProcessRecord> iterator = reserveManagement.iterator();
        while (iterator.hasNext()) {
            PoliceProcessRecord rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            PoliceProcessRecord reserveManag = dao.getInfoByReserveIdAndNum(rm.getProjectReserveId(),rm.getSerialNumber());
            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }
        }
        map.put("without",reserveManagement);
        System.out.println("未存在数据：" + reserveManagement);
        map.put("exist",existReserveManagementList);
        System.out.println("已存在数据：" + existReserveManagementList);
        return map;
    }

    /**
     * 批量添加数据
     * @param reserveManagementList
     */
    @Transactional(readOnly = false)
    public void insertList(List<PoliceProcessRecord> reserveManagementList){

        dao.insertList(reserveManagementList);
    }

    /**
     * 专职修改方法
     * @param reserveManagement
     */
    @Transactional(readOnly = false)
    public void update(PoliceProcessRecord reserveManagement) {

        super.save(reserveManagement);
    }

    public List<PoliceProcessRecord> exportFindList(PoliceProcessRecord reserveManagement) {
        List<PoliceProcessRecord> pageList = dao.exportFindList(reserveManagement);
        return pageList;
    }

    public String getByProjectReserveId(String projectReserveId){
        return dao.getByProjectReserveId(projectReserveId);
    }

    public List<History> getHistoryByExecuteId(String executeId){
        return dao.getHistoryByExecuteId(executeId);
    }

    public String getByExecuteId(String executeId){
        return dao.getByExecuteId(executeId);
    }

    public void deleteByReserveId(String projectReserveId){
        dao.deleteByProjectReserveId(projectReserveId);
    }
}
