package com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.util;

import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.entity.PoliceProcessBase;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.entity.PoliceProcessRecord;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.entity.PoliceProcessSchedule;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Row;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author 王强
 * @version 1.0
 * @date 2023-09-04 8:49
 */
public class PolicyProcessImportUtil {

    /**
     * 获取政策处理基本信息表格数据
     * @param importUtil
     * @return List<ReserveManagementMapper> 导入表格数据
     */
    public static List<PoliceProcessBase> getPoliceProcessBaseUtil(ImportUtil importUtil, List<String> proIdList, List<String> proIdList2) throws Exception {
        int lastRow = importUtil.getLastDataRowNum();
        List<PoliceProcessBase> list = new ArrayList<PoliceProcessBase>();

        //项目储备编号唯一性判断
        List<String> cbbhList = new ArrayList<>();

        //建设必要性及内容
        List<String> jsList = new ArrayList<>();
        PoliceProcessBase reserveManagement = null;
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        for(int i=2; i<=lastRow;i++){
            reserveManagement = new PoliceProcessBase();
            Row row = importUtil.getRow(i);
            //获取项目储备编号
            String projectReserveId = (String) importUtil.getCellValue(row, 11);
            if(StringUtils.isNotBlank(projectReserveId)){

                reserveManagement.setProjectReserveId((String) importUtil.getCellValue(row,11));

                //和基本信息表比对，是否有对应的数据
                getBmList2(proIdList2,reserveManagement.getProjectReserveId());

                reserveManagement.setPowerStationJurisdiction((String) importUtil.getCellValue(row,31));
                reserveManagement.setConstructionLocation((String) importUtil.getCellValue(row,32));
                reserveManagement.setWhetherExitPolitical((String) importUtil.getCellValue(row,33));
                reserveManagement.setPoliticalType((String) importUtil.getCellValue(row,34));
                reserveManagement.setPoliticalDescribe((String) importUtil.getCellValue(row,35));
                reserveManagement.setPoliticalDifficulty((String) importUtil.getCellValue(row,36));
                reserveManagement.setWhetherReport((String) importUtil.getCellValue(row,37));
                reserveManagement.setSafetyProcedures((String) importUtil.getCellValue(row,38));
                reserveManagement.setAviationReviewProcedures((String) importUtil.getCellValue(row,39));
                reserveManagement.setStartPolitical((String) importUtil.getCellValue(row,40));
                if (StringUtils.isNotBlank(reserveManagement.getStartPolitical())
                        &&reserveManagement.getStartPolitical().equals("是")){
                    reserveManagement.setStartTime(format.format(new Date()));
                }
                reserveManagement.setPoliticalRemarks((String) importUtil.getCellValue(row,41));


                if (list.size() == 0){
                    list.add(reserveManagement);
                    cbbhList.add(reserveManagement.getProjectReserveId());
                }else {
                    if (!cbbhList.contains(reserveManagement.getProjectReserveId())){
                        list.add(reserveManagement);
                        cbbhList.add(reserveManagement.getProjectReserveId());
                        jsList.add(reserveManagement.getConstructionNecessityAndContent());
                    }
                }

            }
        }
        return list;
    }

    /**
     * 获取政策处理记录表格数据
     * @param importUtil
     * @return List<ReserveManagementMapper> 导入表格数据
     */
    public static List<PoliceProcessRecord> getPoliceProcessRecordUtil(ImportUtil importUtil, List<String> proIdList, List<String> proIdList2) throws Exception {
        int lastRow = importUtil.getLastDataRowNum();
        List<PoliceProcessRecord> list = new ArrayList<PoliceProcessRecord>();

        PoliceProcessRecord reserveManagement = null;
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        for(int i=2; i<=lastRow;i++){
            reserveManagement = new PoliceProcessRecord();
            Row row = importUtil.getRow(i);
            //获取项目储备编号
            String projectReserveId = (String) importUtil.getCellValue(row, 10);
            if(StringUtils.isNotBlank(projectReserveId)){

                reserveManagement.setProjectReserveId((String) importUtil.getCellValue(row,10));

                //和基本信息表比对，是否有对应的数据
                getBmList2(proIdList2,reserveManagement.getProjectReserveId());

                reserveManagement.setSerialNumber((String) importUtil.getCellValue(row,39));
                if (StringUtils.isNotBlank(reserveManagement.getSerialNumber())){
                    int num = Integer.parseInt(reserveManagement.getSerialNumber());
                    if (num>3){
                        throw new Exception( "项目储备编号为" + reserveManagement.getProjectReserveId() + "的项目在政策记录表中的序号最大只能为3！");
                    }
                    reserveManagement.setStartPoliticalWork((String) importUtil.getCellValue(row,40));
                    reserveManagement.setStartTime((String) importUtil.getCellValue(row,41));
                    reserveManagement.setAdministrativeObject((String) importUtil.getCellValue(row,42));
                    reserveManagement.setNeedCompensation((String) importUtil.getCellValue(row,43));
                    reserveManagement.setCompensationMoney((String) importUtil.getCellValue(row,45));
                    reserveManagement.setDocumentCommitTime((String) importUtil.getCellValue(row,46));
                    reserveManagement.setFinancialPayment((String) importUtil.getCellValue(row,47));
                    reserveManagement.setNeedSignContract((String) importUtil.getCellValue(row,48));
                    reserveManagement.setSignContractTime((String) importUtil.getCellValue(row,49));
                    reserveManagement.setWeatherLoan((String) importUtil.getCellValue(row,50));
                    reserveManagement.setLoanTime((String) importUtil.getCellValue(row,51));
                    reserveManagement.setCompleteFinancialReimbursement((String) importUtil.getCellValue(row,52));
                    reserveManagement.setCompleteFinancialReimbursementTime((String) importUtil.getCellValue(row,53));
                    reserveManagement.setPossibleToEnterSite((String) importUtil.getCellValue(row,54));
                    reserveManagement.setPossibleToEnterSiteTime((String) importUtil.getCellValue(row,55));
                    reserveManagement.setNegotiatingUnit((String) importUtil.getCellValue(row,57));
                    reserveManagement.setCoordinateUnit((String) importUtil.getCellValue(row,58));
                    reserveManagement.setRecordRemarks((String) importUtil.getCellValue(row,59));
                    list.add(reserveManagement);
                }
            }
        }
        return list;
    }

    public static void getBmList2(List<String> sjkList, String proId) throws Exception {
        if (!sjkList.contains(proId)){
            throw new Exception( "项目储备编号为" + proId + "等项目在基础信息表中不存在相关数据！");
        }
    }

    /**
     * 获取政策处理进度表数据
     * @param importUtil
     * @return List<ReserveManagementMapper> 导入表格数据
     */
    public static List<PoliceProcessSchedule> getPoliceProcessScheduleUtil(ImportUtil importUtil, List<String> proIdList, List<String> proIdList2) throws Exception {
        int lastRow = importUtil.getLastDataRowNum();
        List<PoliceProcessSchedule> list = new ArrayList<PoliceProcessSchedule>();

        //项目储备编号唯一性判断
        List<String> cbbhList = new ArrayList<>();

        //建设必要性及内容
        List<String> jsList = new ArrayList<>();
        PoliceProcessSchedule reserveManagement = null;
        for(int i=2; i<=lastRow;i++){
            reserveManagement = new PoliceProcessSchedule();
            Row row = importUtil.getRow(i);
            //获取项目储备编号
            String projectReserveId = (String) importUtil.getCellValue(row, 10);
            if(StringUtils.isNotBlank(projectReserveId)){

                reserveManagement.setProjectReserveId((String) importUtil.getCellValue(row,10));

                //和基本信息表比对，是否有对应的数据
                getBmList2(proIdList2,reserveManagement.getProjectReserveId());

                reserveManagement.setPowerStationJurisdiction((String) importUtil.getCellValue(row,59));
                reserveManagement.setScheduleRemarks((String) importUtil.getCellValue(row,61));


                if (list.size() == 0){
                    list.add(reserveManagement);
                    cbbhList.add(reserveManagement.getProjectReserveId());
                }else {
                    if (!cbbhList.contains(reserveManagement.getProjectReserveId())){
                        list.add(reserveManagement);
                        cbbhList.add(reserveManagement.getProjectReserveId());
                        jsList.add(reserveManagement.getConstructionNecessityAndContent());
                    }
                }

            }
        }
        return list;
    }
}
