package com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.entity.PoliceProcessSchedule;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.service.PoliceProcessScheduleService;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.util.PolicyProcessExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.policyProcess.util.PolicyProcessImportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ProjectTypeVerificateService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import com.jeeplus.modules.sg.picking.activiti.entity.PickList;
import com.jeeplus.modules.sg.raiseCapital.service.RaiseCapitalService;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 政策处理进度表
 * @author 王强
 * @version 1.0
 * @date 2023-09-01 15:41
 */
@Controller
@RequestMapping(value = "${adminPath}/cg/policeProcess/schedule")
public class PoliceProcessScheduleController extends BaseController {

    @Autowired
    private PoliceProcessScheduleService scheduleService;

    @Autowired
    private ProjectTypeVerificateService verificateService;

    @Autowired
    private RaiseCapitalService raiseCapitalService;

    @ModelAttribute
    public PoliceProcessSchedule get(@RequestParam(required = false) String id) {
        PoliceProcessSchedule entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = scheduleService.get(id);
        }
        if (entity == null) {
            entity = new PoliceProcessSchedule();
        }

        List<String> vaList = scheduleService.getInfoByProReserveId(entity.getProjectReserveId());
        StringJoiner joiner = new StringJoiner("");
        for (String val : vaList){
            joiner.add(val);
        }
        if (StringUtils.isNotBlank(joiner.toString()) && !joiner.toString().equals("null")){
            if (joiner.toString().contains("是") && joiner.toString().contains("否")){
                entity.setAdministrativeProgress("部分完成");
            }else if (joiner.toString().matches("^是*$")){
                entity.setAdministrativeProgress("已完成");
            }
        } else {
            entity.setAdministrativeProgress("洽谈中");
        }
        if (StringUtils.isBlank(entity.getProjectScheduleNum())){
            entity.setAdministrativeProgress("无政处");
        }
        List<String> value = scheduleService.getJcInfoByProReserveId(entity.getProjectReserveId());
        StringJoiner joiner2 = new StringJoiner("");
        for (String val : value){
            joiner2.add(val);
        }
        if (StringUtils.isNotBlank(joiner2.toString()) && !joiner2.toString().equals("null")){
            if (joiner2.toString().matches("^是*$")){
                //查最晚时间
                String dateVal = scheduleService.getDateValByProReserveId(entity.getProjectReserveId());
                entity.setEntryAllowed("是");
                entity.setEntryAllowedTime(dateVal);
            }else {
                entity.setEntryAllowed("否");
            }
        }else{
            entity.setEntryAllowed("否");
        }
        return entity;
    }

    /**
     * 项目储备信息列表页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions("cg:policeProcess:schedule:list")
    @RequestMapping(value = "skipList")
    public String skipList(PoliceProcessSchedule reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/policyProcess/policyProcessSchedule/reserveManagementInformation";
    }

    /**
     * 查看表单页面
     */
    @RequiresPermissions(value={"cg:policeProcess:schedule:view"},logical= Logical.OR)
    @RequestMapping(value = "view")
    public String view(PoliceProcessSchedule reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/policyProcess/policyProcessSchedule/reserveManagementView";
    }

    /**
     * 项目储备信息数据列表
     * @param reserveManagement
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:policeProcess:schedule:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(PoliceProcessSchedule reserveManagement, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<PoliceProcessSchedule> page = scheduleService.findPage(new Page<PoliceProcessSchedule>(request, response), reserveManagement);
        //根据projectReserveId查所有的是否完成财务报销及是否可进场
        List<PoliceProcessSchedule> list = page.getList();

        List<String> nameList = new ArrayList<>();
        //获取所有小类的名称
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        for (int i=0;i<list.size();i++){

            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = verificateService.getMaterialName(list.get(i).getProjectName());
            if (null != nameList & null != materialNameList){
                int finalI = i;
                nameList.forEach(n->{
                    if (StringUtils.isBlank(list.get(finalI).getProjectNature())){
                        if (materialNameList.contains(n)){
                            list.get(finalI).setProjectNature("资本");
                        } else {
                            list.get(finalI).setProjectNature("成本");
                        }
                    }
                });
            }

            List<String> vaList = scheduleService.getInfoByProReserveId(list.get(i).getProjectReserveId());
            StringJoiner joiner = new StringJoiner("");
            for (String val : vaList){
                joiner.add(val);
            }
            if (StringUtils.isNotBlank(joiner.toString()) && !joiner.toString().equals("null")){
                if (joiner.toString().contains("是") && joiner.toString().contains("否")){
                    list.get(i).setAdministrativeProgress("部分完成");
                }else if (joiner.toString().matches("^是*$")){
                    list.get(i).setAdministrativeProgress("已完成");
                }
            } else {
                list.get(i).setAdministrativeProgress("洽谈中");
            }
            if (StringUtils.isBlank(list.get(i).getProjectScheduleNum())){
                list.get(i).setAdministrativeProgress("无政处");
            }
            List<String> value = scheduleService.getJcInfoByProReserveId(list.get(i).getProjectReserveId());
            StringJoiner joiner2 = new StringJoiner("");
            for (String val : value){
                joiner2.add(val);
            }
            if (StringUtils.isNotBlank(joiner2.toString()) && !joiner2.toString().equals("null")){
                if (joiner2.toString().matches("^是*$")){
                    //查最晚时间
                    String dateVal = scheduleService.getDateValByProReserveId(list.get(i).getProjectReserveId());
                    list.get(i).setEntryAllowed("是");
                    list.get(i).setEntryAllowedTime(dateVal);
                }else {
                    list.get(i).setEntryAllowed("否");
                }
            }else{
                list.get(i).setEntryAllowed("否");
            }
        }

        return getBootstrapData(page);
    }

    /**
     * 专职人员增加，编辑表单页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:policeProcess:schedule:add","cg:policeProcess:schedule:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(PoliceProcessSchedule reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(reserveManagement.getId())){
            return "modules/cg/reservemanagementcenter/policyProcess/policyProcessSchedule/reserveManagementForm";
        }
        return "modules/cg/reservemanagementcenter/policyProcess/policyProcessSchedule/reserveManagementModifyByzz";
    }

    /**
     * 专职人员保存表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:policeProcess:schedule:add"},logical=Logical.OR)
    @RequestMapping(value = "save")
    public AjaxJson save(PoliceProcessSchedule reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //新增或编辑表单保存
        scheduleService.save(reserveManagement);//保存
        j.setSuccess(true);
        j.setMsg("保存政策处理进度表信息成功");
        return j;
    }

    /**
     * 专职人员修改表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:policeProcess:schedule:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(PoliceProcessSchedule reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //根据项目储备编号查是否有改数据
        PoliceProcessSchedule safety = scheduleService.getByReserveId(reserveManagement.getProjectReserveId());
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        if (null == safety){
            safety = new PoliceProcessSchedule();
            safety.setProjectReserveId(reserveManagement.getProjectReserveId());
            safety.setDesignChangeRequired(reserveManagement.getDesignChangeRequired());
            safety.setScheduleRemarks(reserveManagement.getScheduleRemarks());
            scheduleService.save(safety);
        }else {
            safety.setDesignChangeRequired(reserveManagement.getDesignChangeRequired());
            safety.setScheduleRemarks(reserveManagement.getScheduleRemarks());
            //新增或编辑表单保存
            scheduleService.update(safety);
        }

        j.setSuccess(true);
        j.setMsg("修改政策处理进度表信息成功");
        return j;
    }

    /**
     * 导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:policeProcess:schedule:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);

            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = scheduleService.getAllProId();

            //从基本数据表中查出所有的 项目储备编号
            List<String> proIdList2 = scheduleService.getAllProId2();

            //获取导入表格所有数据
            List<PoliceProcessSchedule> reserveManagementList = PolicyProcessImportUtil.getPoliceProcessScheduleUtil(importUtil,proIdList,proIdList2);
            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = scheduleService.getExistProjectList(reserveManagementList);
            //未存在数据
            List<PoliceProcessSchedule> withoutList = (List<PoliceProcessSchedule>) map.get("without");
            //已存在数据
            List<PoliceProcessSchedule> existList = (List<PoliceProcessSchedule>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                scheduleService.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (PoliceProcessSchedule reserveManagement : existList) {
                    scheduleService.update(reserveManagement);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条政策处理进度表信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入政策处理进度表信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:policeProcess:schedule:export")
    @RequestMapping(value = "export")
    public void exportExcel(PoliceProcessSchedule reserveManagement, HttpServletRequest request, HttpServletResponse response) {
        List<PoliceProcessSchedule> list = scheduleService.exportFindList(reserveManagement);

        //生成序列号
        int j = 1;
        for (PoliceProcessSchedule s : list) {
            s.setId(String.valueOf(j));
            j++;
        }

        for (int i=0;i<list.size();i++){
            List<String> vaList = scheduleService.getInfoByProReserveId(list.get(i).getProjectReserveId());
            StringJoiner joiner = new StringJoiner("");
            for (String val : vaList){
                joiner.add(val);
            }
            if (StringUtils.isNotBlank(joiner.toString()) && !joiner.toString().equals("null")){
                if (joiner.toString().contains("是") && joiner.toString().contains("否")){
                    list.get(i).setAdministrativeProgress("部分完成");
                }else if (joiner.toString().matches("^是*$")){
                    list.get(i).setAdministrativeProgress("已完成");
                }
            } else {
                list.get(i).setAdministrativeProgress("洽谈中");
            }
            if (StringUtils.isBlank(list.get(i).getProjectScheduleNum())){
                list.get(i).setAdministrativeProgress("无政处");
            }
            List<String> value = scheduleService.getJcInfoByProReserveId(list.get(i).getProjectReserveId());
            StringJoiner joiner2 = new StringJoiner("");
            for (String val : value){
                joiner2.add(val);
            }
            if (StringUtils.isNotBlank(joiner2.toString()) && !joiner2.toString().equals("null")){
                if (joiner2.toString().matches("^是*$")){
                    //查最晚时间
                    String dateVal = scheduleService.getDateValByProReserveId(list.get(i).getProjectReserveId());
                    list.get(i).setEntryAllowed("是");
                    list.get(i).setEntryAllowedTime(dateVal);
                }else {
                    list.get(i).setEntryAllowed("否");
                }
            }else{
                list.get(i).setEntryAllowed("否");
            }
        }

        PolicyProcessExportUtil util = PolicyProcessExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("policeProcessSchedule");
        util.exportSchedule(response,workbook,list);
    }
}
