package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper;

import com.jeeplus.core.persistence.BaseMapper;
import com.jeeplus.core.persistence.annotation.MyBatisMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ReserveSummary;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 储备项目交底信息汇总统计 mapper
 * @author: 王强
 * @create: 2022-07-27 11:06
 **/
@MyBatisMapper
public interface SummaryStatisticMapper extends BaseMapper<ReserveSummary> {

    /**
     * 根据项目储备编号删除交底信息汇总信息
     * @param projectReserveId
     */
    void deleteByProjectReserveId(String projectReserveId);

    /**
     * 查出所有的  项目编码 及 是否纳入储备字段
     * @return
     */
    List<ReserveSummary> getAllCode();

    /**
     * 查出 项目编码 及 是否纳入储备字段
     * @return
     */
    ReserveSummary getCodeByProId(String projectReserveId);

    /**
     * 从数据库中查出所有的 项目储备编号
     * @return
     */
    List<String> getAllProId();

    /**
     * 从基本数据表中查出所有的 项目储备编号
     * @return
     */
    List<String> getAllProId2();

    /**
     * 根据项目储备id查询项目信息
     * @param reserveManagement
     * @return
     */
    ReserveSummary queryByProjectReserveId(ReserveSummary reserveManagement);


    /**
     * 批量添加项目储备信息
     * @param list
     * @return
     */
    void insertList(@Param("list") List<ReserveSummary> list);

    /**
     * 导出数据查询
     * @param reserveManagement
     * @return
     */
    List<ReserveSummary> exportFindList(ReserveSummary reserveManagement);

    /**
     * 根据projectReserveId查出proc_ins_id
     * @param projectReserveId
     * @return
     */
    String getByProjectReserveId(String projectReserveId);

    /**
     * 根据executeId查出历史节点信息
     * @param executeId
     * @return
     */
    List<History> getHistoryByExecuteId(String executeId);

    /**
     * 根据executeId查出当前节点的名称
     * @param executeId
     * @return
     */
    String getByExecuteId(String executeId);

    /**
     * 根据项目储备id查数据
     * @param proId
     * @return
     */
    ReserveSummary getByProId(String proId);
}
