package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.PreliminaryPrepartion;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper.PreliminaryPrepartionMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * 储备项目前期准备工作 service
 * @author: 王强
 * @create: 2023-03-27 16:30
 **/
@Service
@Transactional(readOnly = true)
public class PreliminaryPrepartionService extends CrudService<PreliminaryPrepartionMapper, PreliminaryPrepartion> {

    @Autowired
    private PreliminaryPrepartionMapper dao;

    public Page<PreliminaryPrepartion> findPage(Page<PreliminaryPrepartion> page, PreliminaryPrepartion reserveManagement) {
        Page<PreliminaryPrepartion> pageList = super.findPage(page, reserveManagement);
        return pageList;
    }

    public String getByProjectReserveId(String projectReserveId){
        return dao.getByProjectReserveId(projectReserveId);
    }

    public List<History> getHistoryByExecuteId(String executeId){
        return dao.getHistoryByExecuteId(executeId);
    }

    public String getByExecuteId(String executeId){
        return dao.getByExecuteId(executeId);
    }

    /**
     * 专职修改方法
     * @param reserveManagement
     */
    @Transactional(readOnly = false)
    public void update(PreliminaryPrepartion reserveManagement) {

        super.save(reserveManagement);
    }

    public PreliminaryPrepartion getByProId(String proId){
        return dao.getByProId(proId);
    }

    public List<PreliminaryPrepartion> exportFindList( PreliminaryPrepartion reserveManagement) {
        List<PreliminaryPrepartion> pageList = dao.exportFindList(reserveManagement);
        return pageList;
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId2(){
        return dao.getAllProId2();
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param reserveManagement
     * @return
     */
    public Map<String, List<PreliminaryPrepartion>> getExistProjectList(List<PreliminaryPrepartion> reserveManagement){
        Map<String,List<PreliminaryPrepartion>> map = new HashMap();
        List<PreliminaryPrepartion> existReserveManagementList = new ArrayList<>();
        Iterator<PreliminaryPrepartion> iterator = reserveManagement.iterator();
        while (iterator.hasNext()) {
            PreliminaryPrepartion rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            PreliminaryPrepartion reserveManag = dao.queryByProjectReserveId(rm);

            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }

        }
        map.put("without",reserveManagement);
        map.put("exist",existReserveManagementList);
        return map;
    }

    /**
     * 批量添加数据
     * @param reserveManagementList
     */
    @Transactional(readOnly = false)
    public void insertList(List<PreliminaryPrepartion> reserveManagementList){

        dao.insertList(reserveManagementList);
    }
}
