package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ProjectScreen;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper.ProjectScreenMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.util.*;

/**
 * @author: 王强
 * @create: 2023-06-28 09:35
 **/
@Service
@Transactional(readOnly = true)
public class ProjectScreenService extends CrudService<ProjectScreenMapper, ProjectScreen> {

    @Autowired
    private ProjectScreenMapper dao;

    public List<ProjectScreen> exportFindList(ProjectScreen verificate) {
        List<ProjectScreen> pageList = dao.exportFindList(verificate);
        return pageList;
    }

    public Page<ProjectScreen> findPage(Page<ProjectScreen> page, ProjectScreen verificate) {
        if (StringUtils.isBlank(verificate.getProjectYear())){
            verificate.setProjectYear(LocalDate.now().getYear()+"");
        }
        Page<ProjectScreen> pageList = super.findPage(page, verificate);
        return pageList;
    }

    public String getByProjectReserveId(String projectReserveId){
        return dao.getByProjectReserveId(projectReserveId);
    }

    public List<History> getHistoryByExecuteId(String executeId){
        return dao.getHistoryByExecuteId(executeId);
    }

    public String getByExecuteId(String executeId){
        return dao.getByExecuteId(executeId);
    }

    public ProjectScreen getByProId(String proId){
        return dao.getByProId(proId);
    }

    /**
     * 专职修改方法
     * @param reserveManagement
     */
    @Transactional(readOnly = false)
    public void update(ProjectScreen reserveManagement) {

        super.save(reserveManagement);
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId2(){
        return dao.getAllProId2();
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param reserveManagement
     * @return
     */
    public Map<String, List<ProjectScreen>> getExistProjectList(List<ProjectScreen> reserveManagement){
        Map<String,List<ProjectScreen>> map = new HashMap();
        List<ProjectScreen> existReserveManagementList = new ArrayList<>();
        Iterator<ProjectScreen> iterator = reserveManagement.iterator();
        while (iterator.hasNext()) {
            ProjectScreen rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            ProjectScreen reserveManag = dao.queryByProjectReserveId(rm);

            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }

        }
        map.put("without",reserveManagement);
        map.put("exist",existReserveManagementList);
        return map;
    }

    /**
     * 批量添加数据
     * @param reserveManagementList
     */
    @Transactional(readOnly = false)
    public void insertList(List<ProjectScreen> reserveManagementList){

        dao.insertList(reserveManagementList);
    }
}
