package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ProjectTypeVerificate;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper.ProjectTypeVerificateMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.DemoliteList;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.util.*;

/**
 * @author: 王强
 * @create: 2023-06-26 14:02
 **/
@Service
@Transactional(readOnly = true)
public class ProjectTypeVerificateService extends CrudService<ProjectTypeVerificateMapper, ProjectTypeVerificate> {

    @Autowired
    private ProjectTypeVerificateMapper dao;

    public List<String> getMaterialName(String projectName){
        return dao.getMaterialName(projectName);
    }

    public List<DemoliteList> getByProjectName(){
        return dao.getByProjectName();
    }

    public List<String> getMaterialName2(String projectName){
        return dao.getMaterialName2(projectName);
    }

    public Page<ProjectTypeVerificate> findPage(Page<ProjectTypeVerificate> page, ProjectTypeVerificate verificate) {
        if (StringUtils.isBlank(verificate.getProjectYear())){
            verificate.setProjectYear(LocalDate.now().getYear()+"");
        }
        Page<ProjectTypeVerificate> pageList = super.findPage(page, verificate);
        return pageList;
    }

    public List<ProjectTypeVerificate> exportFindList(ProjectTypeVerificate verificate) {
        List<ProjectTypeVerificate> pageList = dao.exportFindList(verificate);
        return pageList;
    }

    /**
     * 专职修改方法
     * @param reserveManagement
     */
    @Transactional(readOnly = false)
    public void update(ProjectTypeVerificate reserveManagement) {

        super.save(reserveManagement);
    }

    /**
     * 批量添加数据
     * @param reserveManagementList
     */
    @Transactional(readOnly = false)
    public void insertList(List<ProjectTypeVerificate> reserveManagementList){

        dao.insertList(reserveManagementList);
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param reserveManagement
     * @return
     */
    public Map<String, List<ProjectTypeVerificate>> getExistProjectList(List<ProjectTypeVerificate> reserveManagement){
        Map<String,List<ProjectTypeVerificate>> map = new HashMap();
        List<ProjectTypeVerificate> existReserveManagementList = new ArrayList<>();
        Iterator<ProjectTypeVerificate> iterator = reserveManagement.iterator();
        while (iterator.hasNext()) {
            ProjectTypeVerificate rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            ProjectTypeVerificate reserveManag = dao.queryByProjectReserveId(rm);

            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }

        }
        map.put("without",reserveManagement);
        map.put("exist",existReserveManagementList);
        return map;
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId2(){
        return dao.getAllProId2();
    }

    public ProjectTypeVerificate getByProId(String proId){
        return dao.getByProId(proId);
    }

    public String getByProjectReserveId(String projectReserveId){
        return dao.getByProjectReserveId(projectReserveId);
    }

    public List<History> getHistoryByExecuteId(String executeId){
        return dao.getHistoryByExecuteId(executeId);
    }

    public String getByExecuteId(String executeId){
        return dao.getByExecuteId(executeId);
    }
}
