package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service;

import com.google.common.collect.Maps;
import com.jeeplus.common.utils.DateUtils;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ImportExcel;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.act.entity.Act;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.*;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper.FeedBackBudgetMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper.ReserveProcessProjectMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper.ReserveSummaryProcessMapper;
import com.jeeplus.modules.sg.managementcenter.activiti.utils.MyActiviUtils;
import com.jeeplus.modules.sg.managementcenter.materialinfo.entity.MaterialInfo;
import com.jeeplus.modules.sg.managementcenter.materialinfo.util.MaterialInfoUtil;
import com.jeeplus.modules.sg.raiseCapitalDesign.entity.CableSectionData;
import com.jeeplus.modules.sg.raiseCapitalDesign.entity.CableSectionInfo;
import com.jeeplus.modules.sg.raiseCapitalDesign.service.RaiseCapitalDesignService;
import org.activiti.engine.TaskService;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.ss.usermodel.Row;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author: 王强
 * @create: 2022-08-03 10:15
 **/
@Service
@Transactional(readOnly = true)
public class ReserveSummaryProcessService extends CrudService<ReserveSummaryProcessMapper, ReserveSummaryProcess> {

//    private static ActRunTaskTest taskTest;

    @Autowired
    private ReserveSummaryProcessMapper mapper;

    @Autowired
    private ReserveProcessProjectMapper projectMapper;

    @Autowired
    private TaskService taskService;

    @Autowired
    private SummaryStatisticService statisticService;

    @Autowired
    private BudgetBookService budgetBookService;

    @Autowired
    private FeedBackBudgetService budgetService;

    @Autowired
    private FeedBackBudgetMapper feedMapper;

    @Autowired
    private RaiseCapitalDesignService raiseCapitalDesignService;

    /**
     * 根据 项目储备编号  查出设计单位节点信息
     * @param proId
     * @return
     */
    public ActRunTaskTest getByProId(String proId){
        return mapper.getByProId(proId);
    }

    /**
     * 根据   proc_def_id,和节点名称找到 taskKey
     * @param procId
     * @param name
     * @return
     */
    public String selectTaskKey(String procId,String name){
        return mapper.selectTaskKey(procId, name);
    }

    /**
     * 根据   proc_def_id,和节点名称 删除 表 act_ru_task 的  项目经理审图 和 联合审图 相关数据
     * @param procId
     */
    @Transactional(readOnly = false)
    public void deleteByProcId(String procId, String name){
        mapper.deleteByProcId(procId, name);
    }
    /**
     * 根据 proc_def_id 和 task_def_key_来删除表act_ru_execution的相关数据
     * @param procId
     * @param taskKey
     */
    @Transactional(readOnly = false)
    public void deleteExecution(String procId, String taskKey){
        mapper.deleteExecution(procId, taskKey);
    }


    /**
     * 根据 项目名称 查看甲供材信息
     * @param projectName
     * @return
     */
    public int getCountByName(String projectName){
        return mapper.getCountByName(projectName);
    }

    public Double getAllNum(String materialCode){
        return mapper.getAllNum(materialCode);
    }

    @Transactional(readOnly = false)
    public void insert(ReserveSummaryProcess entity) {
        mapper.insert(entity);
    }

    @Transactional(readOnly = false)
    public void deleteAct(String projectReserveId) {
        mapper.deleteAct(projectReserveId);
    }



    @Override
    public ReserveSummaryProcess get(String id) {
        ReserveSummaryProcess entity = new ReserveSummaryProcess();
        entity.setId(id);
        String projectId = mapper.findProjectId(entity);
        ReserveSummaryProcess reserveProcess = mapper.get(projectId);
        return reserveProcess;
    }

    /**
     *在年度物资上报统计表中保存项目信息，在年度上报明细表中保存物资信息
     */
    @Transactional(readOnly = false)
    public void saveData(MultipartFile file,String projectReserveId) throws IOException, InvalidFormatException {
        ImportExcel module = new ImportExcel(file,1,"模块表");
        Row row = module.getRow(0);
        Object obj = module.getCellValue(row, 1);
        if(obj==null){
            throw new RuntimeException("找不到项目名称！");
        }
        String projectName = ((String) obj).trim();
        //删除对应项目名称的甲供材信息
        mapper.deleteMaterial(projectName);
        ImportExcel pick = new ImportExcel(file,7,"领料清单");
        List<MaterialInfo> materialInfos = MaterialInfoUtil.getCbData(pick,projectName);   //获取领料清单数据
        List<MaterialInfo> materialInfoList = new ArrayList<>();
        for (MaterialInfo materialInfo : materialInfos) {
            if (materialInfo.getTotalCount()>0){
                materialInfoList.add(materialInfo);
            }
        }
        List<MaterialInfo> list = MaterialInfoUtil.combineData(materialInfoList);      //合并数据
        //通过甲供材信息比对物料规范获得项目建设规模
        saveList(list);
        //获取电缆分段表的数据，将数据存入到redis中
//        ImportUtil importUtil = new ImportUtil(file, 0, 5);
        ImportExcel importUtil = new ImportExcel(file,3,"电缆分段表");
        int lastRow = importUtil.getLastDataRowNum();
        //获取指定的列数据  YJV22-3×400mm²单元格下的行数据
        List<CableSectionInfo> cableFourHundredList = new ArrayList<>();
        List<CableSectionInfo> cableThreeHundredList = new ArrayList<>();   //YJV22-3×300mm²
        List<CableSectionInfo> cableTwoHundredFortyList = new ArrayList<>();    //YJV22-3×240mm²
        List<CableSectionInfo> cableSeventyList = new ArrayList<>();       //YJV22-3×70mm²
        for (int i=2;i<=lastRow;i++){
            Row infoRow = importUtil.getRow(i);
            CableSectionInfo hundredInfo = new CableSectionInfo();
            if (StringUtils.isNotBlank(importUtil.getCellValue(infoRow,0).toString()) && !importUtil.getCellValue(infoRow,0).toString().equals("总长（km)：")){
                hundredInfo.setDestination(importUtil.getCellValue(infoRow,0).toString());
                hundredInfo.setPathLength(importUtil.getCellValue(infoRow,1).toString());
                hundredInfo.setUpperRod(importUtil.getCellValue(infoRow,2).toString());
                hundredInfo.setArrival(importUtil.getCellValue(infoRow,3).toString());
                hundredInfo.setIncomingEquipment(importUtil.getCellValue(infoRow,4).toString());
                hundredInfo.setCoefficient(importUtil.getCellValue(infoRow,5).toString());
                hundredInfo.setElectricalChief(importUtil.getCellValue(infoRow,6).toString());
                cableFourHundredList.add(hundredInfo);
            }

            if (StringUtils.isNotBlank(importUtil.getCellValue(infoRow,8).toString())&& !importUtil.getCellValue(infoRow,0).toString().equals("总长（km)：")){
                CableSectionInfo hundredAndTwenty = new CableSectionInfo();
                hundredAndTwenty.setDestination(importUtil.getCellValue(infoRow,8).toString());
                hundredAndTwenty.setPathLength(importUtil.getCellValue(infoRow,9).toString());
                hundredAndTwenty.setUpperRod(importUtil.getCellValue(infoRow,10).toString());
                hundredAndTwenty.setArrival(importUtil.getCellValue(infoRow,11).toString());
                hundredAndTwenty.setIncomingEquipment(importUtil.getCellValue(infoRow,12).toString());
                hundredAndTwenty.setCoefficient(importUtil.getCellValue(infoRow,13).toString());
                hundredAndTwenty.setElectricalChief(importUtil.getCellValue(infoRow,14).toString());
                cableThreeHundredList.add(hundredAndTwenty);
            }

            if (StringUtils.isNotBlank(importUtil.getCellValue(infoRow,16).toString())&& !importUtil.getCellValue(infoRow,0).toString().equals("总长（km)：")){
                CableSectionInfo hundredAndTwenty = new CableSectionInfo();
                hundredAndTwenty.setDestination(importUtil.getCellValue(infoRow,16).toString());
                hundredAndTwenty.setPathLength(importUtil.getCellValue(infoRow,17).toString());
                hundredAndTwenty.setUpperRod(importUtil.getCellValue(infoRow,18).toString());
                hundredAndTwenty.setArrival(importUtil.getCellValue(infoRow,19).toString());
                hundredAndTwenty.setIncomingEquipment(importUtil.getCellValue(infoRow,20).toString());
                hundredAndTwenty.setCoefficient(importUtil.getCellValue(infoRow,21).toString());
                hundredAndTwenty.setElectricalChief(importUtil.getCellValue(infoRow,22).toString());
                cableTwoHundredFortyList.add(hundredAndTwenty);
            }
            if (StringUtils.isNotBlank(importUtil.getCellValue(infoRow,24).toString())&& !importUtil.getCellValue(infoRow,0).toString().equals("总长（km)：")){
                CableSectionInfo hundredAndTwenty = new CableSectionInfo();
                hundredAndTwenty.setDestination(importUtil.getCellValue(infoRow,24).toString());
                hundredAndTwenty.setPathLength(importUtil.getCellValue(infoRow,25).toString());
                hundredAndTwenty.setUpperRod(importUtil.getCellValue(infoRow,26).toString());
                hundredAndTwenty.setArrival(importUtil.getCellValue(infoRow,27).toString());
                hundredAndTwenty.setIncomingEquipment( importUtil.getCellValue(infoRow,28).toString());
                hundredAndTwenty.setCoefficient(importUtil.getCellValue(infoRow,29).toString());
                hundredAndTwenty.setElectricalChief(importUtil.getCellValue(infoRow,30).toString());
                cableSeventyList.add(hundredAndTwenty);
            }
        }
        CableSectionData cableSectionData = new CableSectionData();
        cableSectionData.setCableFourHundredList(cableFourHundredList);
        cableSectionData.setCableThreeHundredList(cableThreeHundredList);
        cableSectionData.setCableTwoHundredFortyList(cableTwoHundredFortyList);
        cableSectionData.setCableSeventyList(cableSeventyList);
        raiseCapitalDesignService.saveCableOnline(cableSectionData,projectReserveId);
    }

    /**
     *在年度物资上报统计表中保存项目信息，在年度上报明细表中保存物资信息
     */
    @Transactional(readOnly = false)
    public void saveDistributData(MultipartFile file,String projectReserveId) throws IOException, InvalidFormatException {
        ImportExcel module = new ImportExcel(file,1,"模块表");
        Row row = module.getRow(0);
        Object obj = module.getCellValue(row, 1);
        if(obj==null){
            throw new RuntimeException("找不到项目名称！");
        }
        String projectName = ((String) obj).trim();
        //删除对应项目名称的甲供材信息
        mapper.deleteDistributionMaterial(projectName);
        ImportExcel pick = new ImportExcel(file,7,"领料清单");
        List<MaterialInfo> materialInfos = MaterialInfoUtil.getCbData(pick,projectName);   //获取领料清单数据
        List<MaterialInfo> materialInfoList = new ArrayList<>();
        for (MaterialInfo materialInfo : materialInfos) {
            if (materialInfo.getTotalCount()>0){
                materialInfoList.add(materialInfo);
            }
        }
        List<MaterialInfo> list = MaterialInfoUtil.combineData(materialInfoList);      //合并数据
        //通过甲供材信息比对物料规范获得项目建设规模
        saveDistributionList(list);
        //获取电缆分段表的数据，将数据存入到redis中
//        ImportUtil importUtil = new ImportUtil(file, 0, 5);
        ImportExcel importUtil = new ImportExcel(file,3,"电缆分段表");
        int lastRow = importUtil.getLastDataRowNum();
        //获取指定的列数据  YJV22-3×400mm²单元格下的行数据
        List<CableSectionInfo> cableFourHundredList = new ArrayList<>();
        List<CableSectionInfo> cableThreeHundredList = new ArrayList<>();   //YJV22-3×300mm²
        List<CableSectionInfo> cableTwoHundredFortyList = new ArrayList<>();    //YJV22-3×240mm²
        List<CableSectionInfo> cableSeventyList = new ArrayList<>();       //YJV22-3×70mm²
        for (int i=2;i<=lastRow;i++){
            Row infoRow = importUtil.getRow(i);
            CableSectionInfo hundredInfo = new CableSectionInfo();
            if (StringUtils.isNotBlank(importUtil.getCellValue(infoRow,0).toString()) && !importUtil.getCellValue(infoRow,0).toString().equals("总长（km)：")){
                hundredInfo.setDestination(importUtil.getCellValue(infoRow,0).toString());
                hundredInfo.setPathLength(importUtil.getCellValue(infoRow,1).toString());
                hundredInfo.setUpperRod(importUtil.getCellValue(infoRow,2).toString());
                hundredInfo.setArrival(importUtil.getCellValue(infoRow,3).toString());
                hundredInfo.setIncomingEquipment(importUtil.getCellValue(infoRow,4).toString());
                hundredInfo.setCoefficient(importUtil.getCellValue(infoRow,5).toString());
                hundredInfo.setElectricalChief(importUtil.getCellValue(infoRow,6).toString());
                cableFourHundredList.add(hundredInfo);
            }

            if (StringUtils.isNotBlank(importUtil.getCellValue(infoRow,8).toString())&& !importUtil.getCellValue(infoRow,0).toString().equals("总长（km)：")){
                CableSectionInfo hundredAndTwenty = new CableSectionInfo();
                hundredAndTwenty.setDestination(importUtil.getCellValue(infoRow,8).toString());
                hundredAndTwenty.setPathLength(importUtil.getCellValue(infoRow,9).toString());
                hundredAndTwenty.setUpperRod(importUtil.getCellValue(infoRow,10).toString());
                hundredAndTwenty.setArrival(importUtil.getCellValue(infoRow,11).toString());
                hundredAndTwenty.setIncomingEquipment(importUtil.getCellValue(infoRow,12).toString());
                hundredAndTwenty.setCoefficient(importUtil.getCellValue(infoRow,13).toString());
                hundredAndTwenty.setElectricalChief(importUtil.getCellValue(infoRow,14).toString());
                cableThreeHundredList.add(hundredAndTwenty);
            }

            if (StringUtils.isNotBlank(importUtil.getCellValue(infoRow,16).toString())&& !importUtil.getCellValue(infoRow,0).toString().equals("总长（km)：")){
                CableSectionInfo hundredAndTwenty = new CableSectionInfo();
                hundredAndTwenty.setDestination(importUtil.getCellValue(infoRow,16).toString());
                hundredAndTwenty.setPathLength(importUtil.getCellValue(infoRow,17).toString());
                hundredAndTwenty.setUpperRod(importUtil.getCellValue(infoRow,18).toString());
                hundredAndTwenty.setArrival(importUtil.getCellValue(infoRow,19).toString());
                hundredAndTwenty.setIncomingEquipment(importUtil.getCellValue(infoRow,20).toString());
                hundredAndTwenty.setCoefficient(importUtil.getCellValue(infoRow,21).toString());
                hundredAndTwenty.setElectricalChief(importUtil.getCellValue(infoRow,22).toString());
                cableTwoHundredFortyList.add(hundredAndTwenty);
            }
            if (StringUtils.isNotBlank(importUtil.getCellValue(infoRow,24).toString())&& !importUtil.getCellValue(infoRow,0).toString().equals("总长（km)：")){
                CableSectionInfo hundredAndTwenty = new CableSectionInfo();
                hundredAndTwenty.setDestination(importUtil.getCellValue(infoRow,24).toString());
                hundredAndTwenty.setPathLength(importUtil.getCellValue(infoRow,25).toString());
                hundredAndTwenty.setUpperRod(importUtil.getCellValue(infoRow,26).toString());
                hundredAndTwenty.setArrival(importUtil.getCellValue(infoRow,27).toString());
                hundredAndTwenty.setIncomingEquipment( importUtil.getCellValue(infoRow,28).toString());
                hundredAndTwenty.setCoefficient(importUtil.getCellValue(infoRow,29).toString());
                hundredAndTwenty.setElectricalChief(importUtil.getCellValue(infoRow,30).toString());
                cableSeventyList.add(hundredAndTwenty);
            }
        }
        CableSectionData cableSectionData = new CableSectionData();
        cableSectionData.setCableFourHundredList(cableFourHundredList);
        cableSectionData.setCableThreeHundredList(cableThreeHundredList);
        cableSectionData.setCableTwoHundredFortyList(cableTwoHundredFortyList);
        cableSectionData.setCableSeventyList(cableSeventyList);
        raiseCapitalDesignService.saveCableOnline(cableSectionData,projectReserveId);
    }

    @Transactional(readOnly = false)
    public void saveList(List<MaterialInfo> list) {

        for(MaterialInfo maintainData : list){
            maintainData.preInsert();
            mapper.deleteMaterial(maintainData.getProjectName());
        }
        mapper.insertList(list);
    }

    @Transactional(readOnly = false)
    public void saveDistributionList(List<MaterialInfo> list) {

        for(MaterialInfo maintainData : list){
            maintainData.preInsert();
            mapper.deleteDistributionMaterial(maintainData.getProjectName());
        }
        mapper.insertDistributionList(list);
    }

    @Transactional(readOnly = false)
    public void deleteMaterial(String projectName){
        mapper.deleteMaterial(projectName);
    }

    private String returnKva(String materialDescription) {
        if (null != materialDescription && !"".equals(materialDescription)) {
            boolean kVA = materialDescription.contains("kVA");
            if (kVA) {
                int kVA1 = materialDescription.lastIndexOf("kVA");
                String substring = materialDescription.substring(kVA1 - 3, kVA1+3);
                return substring;
            }
        }
        return "";
    }

    /**
     * 通过储备项目编号查询项目是否有甲供材清册
     */
    public Integer findMaterialData(String procInsId) {
        return mapper.findMaterialData(procInsId);
    }

    /**
     * 修改项目设计单位信息
     */
    @Transactional(readOnly = false)
    public void updateDesign(ReserveSummaryProcess reserveProcess) {
        mapper.updateDesign(reserveProcess);
    }

    /**
     * 设计单位判定是否关闭
     */
    @Transactional(readOnly = false)
    public void actDesignUnit(Act act, ReserveSummaryProcess reserveProcess) {

        //将设计单位节点相关信息保存到类中   持久化操作
//        taskTest = mapper.getInfo();
        ActRunTaskTest taskTest = mapper.getInfo();
        taskTest.setProjectReserveId(reserveProcess.getProjectReserveId());
        taskTest.preInsert();
        mapper.deleteIntoActRunTaskByProId(reserveProcess.getProjectReserveId());
        mapper.insertIntoActRunTask(taskTest);
        // 对不同环节的业务逻辑进行操作
        String taskDefKey = act.getTaskDefKey();
        //提交流程任务
        Map<String, Object> vars = Maps.newHashMap();

        ReserveProcessProject user = MyActiviUtils.findCgUser(act.getProcInsId());

        //候选人
        List list = new ArrayList<>();

        //根据用户名去数据库中查找登录名
        String cbzz = mapper.getLoginNameByName(user.getOwnerReserveFullTime());
        String xmjl = mapper.getLoginNameByName(user.getOwnerReserveProjectManagre());
//        list.add(cbzz);
//        list.add(xmjl);
        String title = user.getCurrentUser().getName() + "在" + DateUtils.getDateTime() + "发起联合审图";
        act.setTitle(title);
        vars.put("manager",xmjl);
        vars.put("managerTest",cbzz);

        //指定代理人
//        vars.put("manager",UserUtils.getByUserName(user.getOwnerProjectManager()).getLoginName());

        // 提交流程任务
        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);
    }

    /**
     * 提交任务, 并保存意见
     *
     * @param taskId    任务ID
     * @param procInsId 流程实例ID，如果为空，则不保存任务提交意见
     * @param comment   任务提交意见的内容
     * @param vars      任务变量
     */
    @Transactional(readOnly = false)
    public void complete(String taskId, String procInsId, String comment, Map<String, Object> vars) {
        complete(taskId, procInsId, comment, "", vars);
    }

    @Transactional(readOnly = false)
    public void complete(String taskId, String procInsId, String comment, String title, Map<String, Object> vars) {
        // 添加意见
        if (StringUtils.isNotBlank(procInsId) && StringUtils.isNotBlank(comment)) {
            taskService.addComment(taskId, procInsId, comment);
        }

        // 设置流程变量
        if (vars == null) {
            vars = Maps.newHashMap();
        }

        // 设置流程标题
        if (StringUtils.isNotBlank(title)) {
            vars.put("title", title);
        }

        // 提交任务
        taskService.complete(taskId, vars);
    }

    public Page<ReserveSummaryProcess> findAllUploadPage(Page<ReserveSummaryProcess> page, ReserveSummaryProcess entity) {
        dataRuleFilter(entity);
        entity.setPage(page);
        page.setList(mapper.findAllUpload(entity));
        return page;
    }

    public Page<ReserveSummaryProcess> findAllUploadPage2(Page<ReserveSummaryProcess> page, ReserveSummaryProcess entity) {
        dataRuleFilter(entity);
        entity.setPage(page);
        page.setList(mapper.findAllUpload2(entity));
        return page;
    }

    public Page<MaterialInfo> findMaterialPage(Page<MaterialInfo> page, MaterialInfo entity) {
        dataRuleFilter(entity);
        entity.setPage(page);
        page.setList(mapper.findMaterialList(entity));
        return page;
    }

    public Page<MaterialInfo> findMaterialPage2(Page<MaterialInfo> page, MaterialInfo entity) {
        dataRuleFilter(entity);
        entity.setPage(page);
        page.setList(mapper.findMaterialList2(entity));
        return page;
    }

    /**
     * 通过项目名称导出符合条件的数据
     */
    public List<MaterialInfo> findMaterialActiviti(String projectName) {
        return mapper.findMaterialActiviti(projectName);
    }

    /**
     * 通过项目名称导出符合条件的数据
     */
    public List<MaterialInfo> findMaterialActiviti2(String projectName) {
        return mapper.findMaterialActiviti2(projectName);
    }

    /**
     * 项目经理判定是否通过
     */
    @Transactional(readOnly = false)
    public void actDrawingReview(Act act,ReserveSummaryProcess reserveProcess) throws Exception {
        Map<String, Object> vars = Maps.newHashMap();
        String flag = act.getFlag();
        ReserveProcessProject user = MyActiviUtils.findCgUser(act.getProcInsId());

        //根据用户名去数据库中查找登录名
        String loginNameByName = mapper.getLoginNameByName(user.getDesigner());

        if ("yes".equals(flag)) {
            //通过流程到-技经人员审预算
            loginNameByName = mapper.getLoginNameByName(user.getOwnerReserveFullTime());
            vars.put("manager", loginNameByName);
            vars.put("pass",true);
            vars.put("no",false);
            vars.put("rural",false);
            vars.put("tg",false);
            act.setTitle("技经人员审预算");
        } else if ("disagree".equals(flag)){
            //将项目经理审图的问题反馈保存到数据库
            FeedBackBudget budget = new FeedBackBudget(reserveProcess.getProjectReserveId(),
                    reserveProcess.getPreferedCase(),reserveProcess.getTransferSituation(),
                    reserveProcess.getBudgetTemplateCheck(),reserveProcess.getQuotaApplicationCheck(),
                    reserveProcess.getWorkLoadCheck(),reserveProcess.getCheckTheFee(),
                    reserveProcess.getSupplyCheck(),reserveProcess.getMaterialCheck(),
                    reserveProcess.getLiveWorkFeeCheck(),reserveProcess.getDemolitionEngineeringProblems(),
                    reserveProcess.getOtherProblem(),reserveProcess.getDrawingAndSiteProblem(),
                    reserveProcess.getCommunicationProblem(),reserveProcess.getCivilPrefabricateProblem(),
                    reserveProcess.getLiveWorkNumProblem(),reserveProcess.getProjectManagerOtherProblem());

//            budgetService.deleteByProjectReserveId(budget.getProjectReserveId());
            FeedBackBudget infoByProId = budgetService.getInfoByProId(reserveProcess.getProjectReserveId());
            if (infoByProId == null){
                budgetService.save(budget);
            }else {
                budgetService.updateInFoByProId(budget);
            }

            //不通过-回到上一个流程
            vars.put("manager", loginNameByName);
            vars.put("pass",false);
            vars.put("tg",true);
            vars.put("no",false);
            vars.put("rural",false);
            act.setTitle("设计单位上传施工图纸");
            ActRunTaskTest taskTest = mapper.getByProId(reserveProcess.getProjectReserveId());
            //删除掉act_ru_task表的联合审图 及 项目经理审图数据
            mapper.deleteByProcId(taskTest.getProcInsId(),"联合审图");
            mapper.deleteByProcId(taskTest.getProcInsId(),"技经人员审预算");
            //删除联合审图的并行任务
            String taskKey = mapper.selectTaskKey(taskTest.getProcInsId(), "联合审图");
            mapper.deleteExecution(taskTest.getProcInsId(),taskKey);

        } else if ("cancel".equals(flag)){
            //取消-项目取消，修改第六张表的状态
            //先把表的状态改为取消
            ReserveSummary reserveSummary = new ReserveSummary();
            reserveSummary.setProjectReserveId(user.getProjectReserveId());
            ReserveSummary summary = statisticService.queryByProjectReserveId(reserveSummary);
            summary.setIncludeReserve("取消");
            summary.setStartDesignOrNot("否");
            //修改 基本信息表的流程状态
            projectMapper.updateProcessStatus(user.getProjectReserveId(),3);

            //流程结束  清空该项目流程的问题反馈
            feedMapper.deleteByProjectReserveId(user.getProjectReserveId());
            vars.put("tg",false);
            vars.put("pass",false);
            vars.put("no",true);
            vars.put("rural",false);


            //修改 汇总表的是否纳入储备为取消  并把取消原因获取到放到对应字段
            String message = mapper.getMessage();
            summary.setReasonForCancel(message);
            statisticService.update(summary);

//            //取消流程   将流程表中的流程信息删除
//            mapper.deleteActivityByProId(user.getProjectReserveId());

            ActRunTaskTest taskTest = mapper.getByProId(reserveProcess.getProjectReserveId());

            //删除掉act_ru_task表的联合审图 及 项目经理审图数据
            mapper.deleteByProcId(taskTest.getProcInsId(),"联合审图");
//            mapper.deleteByProcId(taskTest.getProcInsId(),"项目经理审图");
            mapper.deleteByProcId(taskTest.getProcInsId(),"技经人员审预算");
            //删除联合审图的并行任务
            String taskKey = mapper.selectTaskKey(taskTest.getProcInsId(), "联合审图");
//            String taskKey2 = mapper.selectTaskKey(taskTest.getProcInsId(), "项目经理审图");
            mapper.deleteExecution(taskTest.getProcInsId(),taskKey);
//            mapper.deleteExecution(taskTest.getProcInsId(),taskKey2);

            act.preUpdate();
            // 提交流程任务
            complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);
            return;
        } else if ("pending".equals(flag)){
            //待定 修改第六张表的状态
            ReserveSummary reserveSummary = new ReserveSummary();
            reserveSummary.setProjectReserveId(user.getProjectReserveId());
            ReserveSummary summary = statisticService.queryByProjectReserveId(reserveSummary);
            summary.setIncludeReserve("待定");
            summary.setStartDesignOrNot("否");
            //修改 基本信息表的流程状态
            projectMapper.updateProcessStatus(user.getProjectReserveId(),4);
            //修改 汇总表的是否纳入储备为取消  并把取消原因获取到放到对应字段

            //流程结束  清空该项目流程的问题反馈
            feedMapper.deleteByProjectReserveId(user.getProjectReserveId());
            vars.put("tg",false);
            vars.put("pass",false);
            vars.put("no",false);
            vars.put("rural",true);

//            //取消流程   将流程表中的流程信息删除
//            mapper.deleteActivityByProId(user.getProjectReserveId());

            ActRunTaskTest taskTest = mapper.getByProId(reserveProcess.getProjectReserveId());
            //删除掉act_ru_task表的联合审图 及 项目经理审图数据
            mapper.deleteByProcId(taskTest.getProcInsId(),"联合审图");
//            mapper.deleteByProcId(taskTest.getProcInsId(),"项目经理审图");
            mapper.deleteByProcId(taskTest.getProcInsId(),"技经人员审预算");
            //删除联合审图的并行任务
            String taskKey = mapper.selectTaskKey(taskTest.getProcInsId(), "联合审图");
//            String taskKey2 = mapper.selectTaskKey(taskTest.getProcInsId(), "项目经理审图");
            mapper.deleteExecution(taskTest.getProcInsId(),taskKey);
//            mapper.deleteExecution(taskTest.getProcInsId(),taskKey2);

            act.preUpdate();
            // 提交流程任务
            complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);
            //修改 汇总表的是否纳入储备为取消  并把取消原因获取到放到对应字段
            String message = mapper.getMessage();
            summary.setReasonForCancel(message);
            statisticService.update(summary);
            return;
        }

        act.preUpdate();
        // 对不同环节的业务逻辑进行操作
        String taskDefKey = act.getTaskDefKey();

        // 提交流程任务
        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);

    }

    /**
     * 联合审图判定是否通过
     */
    @Transactional(readOnly = false)
    public void actDrawingReviewTest(Act act,ReserveSummaryProcess process) {
        Map<String, Object> vars = Maps.newHashMap();
        String flag = act.getFlag();
        ReserveProcessProject user = MyActiviUtils.findCgUser(act.getProcInsId());

        //根据用户名去数据库中查找登录名
        String loginNameByName = mapper.getLoginNameByName(user.getOwnerReserveFullTime());

        if ("yes".equals(flag)) {
            //通过流程到-技经人员审预算
//            vars.put("manager", loginNameByName);
            vars.put("pass",true);
            vars.put("no",false);
            vars.put("rural",false);
            vars.put("tg",false);
//            act.setTitle("设计单位上传预算书");
            ActRunTaskTest taskTest = mapper.getByProId(user.getProjectReserveId());
            //修改 基本信息表的流程状态         查看是否通过了概预算审核
            //从ACT_HI_TASKINST历史表中查看  概预算审核信息（根据时间排序取最近的一个），根据查出来的endTime来查下一个节点是否是设计单位上传文件
            String time = mapper.selectTimeByName(taskTest.getProcInsId(), "技经人员审预算");
            if (StringUtils.isEmpty(time)){
                //说明审预算节点未结束
            }else {
                //根据结束时间来查是否有下一个节点
                String name = mapper.selectNameByTime(taskTest.getProcInsId(), time);
                if (StringUtils.isEmpty(name)){
                    //说明还在流程中
                    projectMapper.updateProcessStatus(user.getProjectReserveId(),2);
                }
            }
            //流程结束  清空该项目流程的问题反馈
            feedMapper.deleteByProjectReserveId(user.getProjectReserveId());

        } else if ("disagree".equals(flag)){
            //不通过-回到上一个流程
            loginNameByName = mapper.getLoginNameByName(user.getDesigner());
            vars.put("manager", loginNameByName);
            vars.put("pass",false);
            vars.put("tg",true);
            vars.put("no",false);
            vars.put("rural",false);
            act.setTitle("设计单位上传施工图纸");

            ActRunTaskTest taskTest = mapper.getByProId(process.getProjectReserveId());
            //删除掉act_ru_task表的联合审图 及 项目经理审图数据
            mapper.deleteByProcId(taskTest.getProcInsId(),"项目经理审图");
            mapper.deleteByProcId(taskTest.getProcInsId(),"技经人员审预算");
            //删除联合审图的并行任务
            String taskKey = mapper.selectTaskKey(taskTest.getProcInsId(), "项目经理审图");
            mapper.deleteExecution(taskTest.getProcDefId(),taskKey);

        } else if ("cancel".equals(flag)){
            //取消-项目取消，修改第六张表的状态
            //先把表的状态改为取消
            ReserveSummary reserveSummary = new ReserveSummary();
            reserveSummary.setProjectReserveId(user.getProjectReserveId());
            ReserveSummary summary = statisticService.queryByProjectReserveId(reserveSummary);
            summary.setIncludeReserve("取消");
            summary.setStartDesignOrNot("否");
            statisticService.update(summary);
            //修改 基本信息表的流程状态
            projectMapper.updateProcessStatus(user.getProjectReserveId(),3);
            vars.put("tg",false);
            vars.put("pass",false);
            vars.put("no",true);
            vars.put("rural",false);

            //流程结束  清空该项目流程的问题反馈
            feedMapper.deleteByProjectReserveId(user.getProjectReserveId());
            act.preUpdate();
            // 提交流程任务
            complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);
            //修改 汇总表的是否纳入储备为取消  并把取消原因获取到放到对应字段
            String message = mapper.getMessage();
            summary.setReasonForCancel(message);
            statisticService.update(summary);

//            //取消流程   将流程表中的流程信息删除
//            mapper.deleteActivityByProId(user.getProjectReserveId());

            ActRunTaskTest taskTest = mapper.getByProId(user.getProjectReserveId());
            //删除掉act_ru_task表的联合审图 及 项目经理审图数据
//            mapper.deleteByProcId(taskTest.getProcInsId(),"联合审图");
            mapper.deleteByProcId(taskTest.getProcInsId(),"项目经理审图");
            mapper.deleteByProcId(taskTest.getProcInsId(),"技经人员审预算");
            //删除联合审图的并行任务
//            String taskKey = mapper.selectTaskKey(taskTest.getProcInsId(), "联合审图");
            String taskKey2 = mapper.selectTaskKey(taskTest.getProcInsId(), "项目经理审图");
//            mapper.deleteExecution(taskTest.getProcInsId(),taskKey);
            mapper.deleteExecution(taskTest.getProcInsId(),taskKey2);
            return;

        } else if ("pending".equals(flag)){
            //待定 修改第六张表的状态
            ReserveSummary reserveSummary = new ReserveSummary();
            reserveSummary.setProjectReserveId(user.getProjectReserveId());
            ReserveSummary summary = statisticService.queryByProjectReserveId(reserveSummary);
            summary.setIncludeReserve("待定");
            summary.setStartDesignOrNot("否");
            statisticService.update(summary);
            //修改 基本信息表的流程状态
            projectMapper.updateProcessStatus(user.getProjectReserveId(),4);
            vars.put("tg",false);
            vars.put("pass",false);
            vars.put("no",false);
            vars.put("rural",true);

            //流程结束  清空该项目流程的问题反馈
            feedMapper.deleteByProjectReserveId(user.getProjectReserveId());
            act.preUpdate();
            // 提交流程任务
            complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);
            //修改 汇总表的是否纳入储备为取消  并把取消原因获取到放到对应字段
            String message = mapper.getMessage();
            summary.setReasonForCancel(message);
            statisticService.update(summary);

//            //取消流程   将流程表中的流程信息删除
//            mapper.deleteActivityByProId(user.getProjectReserveId());

            ActRunTaskTest taskTest = mapper.getByProId(user.getProjectReserveId());
            //删除掉act_ru_task表的联合审图 及 项目经理审图数据
//            mapper.deleteByProcId(taskTest.getProcInsId(),"联合审图");
            mapper.deleteByProcId(taskTest.getProcInsId(),"项目经理审图");
            mapper.deleteByProcId(taskTest.getProcInsId(),"技经人员审预算");
            //删除联合审图的并行任务
//            String taskKey = mapper.selectTaskKey(taskTest.getProcInsId(), "联合审图");
            String taskKey2 = mapper.selectTaskKey(taskTest.getProcInsId(), "项目经理审图");
//            mapper.deleteExecution(taskTest.getProcInsId(),taskKey);
            mapper.deleteExecution(taskTest.getProcInsId(),taskKey2);
            return;
        }

        act.preUpdate();
        // 对不同环节的业务逻辑进行操作
        String taskDefKey = act.getTaskDefKey();

        // 提交流程任务
        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);
    }

    /**
     * 技经人员判定是否关闭
     */
    @Transactional(readOnly = false)
    public void actBudgetUnit(Act act,ReserveSummaryProcess reserveProcess) {
        Map<String, Object> vars = Maps.newHashMap();
        String flag = act.getFlag();
        ReserveProcessProject user = MyActiviUtils.findCgUser(act.getProcInsId());


        //修改储备项目概预算统计表的-是否完成概算修改 和 概算修改完成时间字段
        if ("yes".equals(flag)) {
            vars.put("pass",true);

            //将预算书审前审后数据放入数据库
            BudgetBook budgetBook = new BudgetBook();
            budgetBook.setProjectReserveId("".equals(reserveProcess.getProjectReserveId()) ? null : reserveProcess.getProjectReserveId());
            budgetBook.setPretrialBudgetTaxInclude("".equals(reserveProcess.getPretrialBudgetTaxInclude()) ? null : reserveProcess.getPretrialBudgetTaxInclude());
            budgetBook.setPretrialBudgetTaxNoInclude("".equals(reserveProcess.getPretrialBudgetTaxNoInclude()) ? null : reserveProcess.getPretrialBudgetTaxNoInclude());
            budgetBook.setPretrialSupervisionFeeTaxNoInclude("".equals(reserveProcess.getPretrialSupervisionFeeTaxNoInclude()) ? null : reserveProcess.getPretrialSupervisionFeeTaxNoInclude());
            budgetBook.setPretrialDesignFeeTaxNoInclude("".equals(reserveProcess.getPretrialDesignFeeTaxNoInclude()) ? null : reserveProcess.getPretrialDesignFeeTaxNoInclude());
            budgetBook.setAfterTrialBudgetTaxInclude("".equals(reserveProcess.getAfterTrialBudgetTaxInclude()) ? null : reserveProcess.getAfterTrialBudgetTaxInclude());
            budgetBook.setAfterTrialBudgetTaxNoInclude("".equals(reserveProcess.getAfterTrialBudgetTaxNoInclude()) ? null : reserveProcess.getAfterTrialBudgetTaxNoInclude());
            budgetBook.setAfterTrialSupervisionFeeTaxNoInclude("".equals(reserveProcess.getAfterTrialSupervisionFeeTaxNoInclude()) ? null : reserveProcess.getAfterTrialSupervisionFeeTaxNoInclude());
            budgetBook.setAfterTrialDesignFeeTaxNoInclude("".equals(reserveProcess.getAfterTrialDesignFeeTaxNoInclude()) ? null : reserveProcess.getAfterTrialDesignFeeTaxNoInclude());
            //插入前先清空该项目相关的预算书数据
            budgetBookService.deleteByProjectReserveId(budgetBook.getProjectReserveId());
            //插入
            budgetBookService.save(budgetBook);

            ActRunTaskTest taskTest = mapper.getByProId(user.getProjectReserveId());
            //修改 基本信息表的流程状态         查看是否通过了概预算审核
            //从ACT_HI_TASKINST历史表中查看  概预算审核信息（根据时间排序取最近的一个），根据查出来的endTime来查下一个节点是否是设计单位上传文件
            String time = mapper.selectTimeByName(taskTest.getProcInsId(), "联合审图");
            if (StringUtils.isEmpty(time)){
                //说明审预算节点未结束
            }else {
                //根据结束时间来查是否有下一个节点
                String name = mapper.selectNameByTime(taskTest.getProcInsId(), time);
                if (StringUtils.isEmpty(name)){
                    //说明没有下一个节点
                    projectMapper.updateProcessStatus(user.getProjectReserveId(),2);
                }
            }
            //流程结束  清空该项目流程的问题反馈
            feedMapper.deleteByProjectReserveId(user.getProjectReserveId());

        } else if ("no".equals(flag)){
            //不通过-回到上一个流程
            //根据用户名去数据库中查找登录名
            String loginNameByName = mapper.getLoginNameByName(user.getDesigner());
            vars.put("manager", loginNameByName);
            vars.put("pass",false);

            //将预算问题反馈记录保存到数据库
            FeedBackBudget budget = new FeedBackBudget(reserveProcess.getProjectReserveId(),
                    reserveProcess.getPreferedCase(),reserveProcess.getTransferSituation(),
                    reserveProcess.getBudgetTemplateCheck(),reserveProcess.getQuotaApplicationCheck(),
                    reserveProcess.getWorkLoadCheck(),reserveProcess.getCheckTheFee(),
                    reserveProcess.getSupplyCheck(),reserveProcess.getMaterialCheck(),
                    reserveProcess.getLiveWorkFeeCheck(),reserveProcess.getDemolitionEngineeringProblems(),
                    reserveProcess.getOtherProblem(),reserveProcess.getDrawingAndSiteProblem(),
                    reserveProcess.getCommunicationProblem(),reserveProcess.getCivilPrefabricateProblem(),
                    reserveProcess.getLiveWorkNumProblem(),reserveProcess.getProjectManagerOtherProblem());


//            budgetService.deleteByProjectReserveId(budget.getProjectReserveId());

            ActRunTaskTest taskTest = mapper.getByProId(reserveProcess.getProjectReserveId());
            //删除掉act_ru_task表的联合审图 及 项目经理审图数据
            mapper.deleteByProcId(taskTest.getProcInsId(),"联合审图");
            //删除联合审图的并行任务
            String taskKey = mapper.selectTaskKey(taskTest.getProcInsId(), "联合审图");
            mapper.deleteExecution(taskTest.getProcInsId(),taskKey);

            FeedBackBudget infoByProId = budgetService.getInfoByProId(reserveProcess.getProjectReserveId());
            if (infoByProId == null){
                budgetService.save(budget);
            }else {
                budgetService.updateInFoByProId(budget);
            }
            act.setTitle("设计单位上传施工图纸");
        }

        act.preUpdate();
        // 对不同环节的业务逻辑进行操作
        String taskDefKey = act.getTaskDefKey();

        // 提交流程任务
        complete(act.getTaskId(), act.getProcInsId(), act.getComment(), vars);
        //设置完成时间
        Date date = new Date();
        DateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String time = format.format(date);

    }


}
