package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.PreliminaryPrepartion;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.PreliminaryPrepartionService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectProUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 储备项目前期准备工作 controller
 * @author: 王强
 * @create: 2023-03-27 16:28
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/preliminaryPrepartion")
public class PreliminaryPrepartionController extends BaseController {

    @Autowired
    private PreliminaryPrepartionService prepartionService;

    @ModelAttribute
    public PreliminaryPrepartion get(@RequestParam(required = false) String id) {
        PreliminaryPrepartion entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = prepartionService.get(id);
        }
        if (entity == null) {
            entity = new PreliminaryPrepartion();
        }
        return entity;
    }

    /**
     * 储备项目前期准备工作列表页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:preliminaryPrepartion:list")
    @RequestMapping(value = "skipList")
    public String skipList(PreliminaryPrepartion reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/reserveManage/preliminaryPrepartion/reserveManagementInformation";
    }

    /**
     * 储备项目前期准备工作数据列表
     * @param reserveManagement
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:preliminaryPrepartion:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(PreliminaryPrepartion reserveManagement, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<PreliminaryPrepartion> page = prepartionService.findPage(new Page<PreliminaryPrepartion>(request, response), reserveManagement);
        List<PreliminaryPrepartion> list = page.getList();
        List<PreliminaryPrepartion> summaryList = new ArrayList<>();
        for (PreliminaryPrepartion summary : list) {

            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = prepartionService.getByProjectReserveId(summary.getProjectReserveId());
            //根据procInsId查出历史流程名称和时间
            List<History> histories = prepartionService.getHistoryByExecuteId(procInsId);
            //当size>0时待办有历史流程，
            if (histories.size()>0){
                //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                String name = prepartionService.getByExecuteId(procInsId);
                //设置项目进度
                summary.setReserveProgress(name);
            }else {
                summary.setReserveProgress("");
            }

            summaryList.add(summary);
        }

        return getBootstrapData(page);
    }

    /**
     * 查看表单页面
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:preliminaryPrepartion:view"},logical= Logical.OR)
    @RequestMapping(value = "view")
    public String view(PreliminaryPrepartion reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/reserveManage/preliminaryPrepartion/reserveManagementView";
    }

    /**
     * 专职人员增加，编辑表单页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:preliminaryPrepartion:add","cg:reservemanagementcenter:preliminaryPrepartion:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(PreliminaryPrepartion reserveManagement, Model model) {

        //根据projectReserveId查出流程表的proc_ins_id
        String procInsId = prepartionService.getByProjectReserveId(reserveManagement.getProjectReserveId());
        //根据procInsId查出历史流程名称和时间
        List<History> histories = prepartionService.getHistoryByExecuteId(procInsId);
        //当size>0时待办有历史流程，
        if (histories.size()>0){
            //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
            String name = prepartionService.getByExecuteId(procInsId);
            //设置项目进度
            reserveManagement.setReserveProgress(name);
        }else {
            reserveManagement.setReserveProgress("");
        }
        model.addAttribute("reserveManagement", reserveManagement);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(reserveManagement.getId())){
            return "modules/cg/reservemanagementcenter/reserveManage/preliminaryPrepartion/reserveManagementForm";
        }
        return "modules/cg/reservemanagementcenter/reserveManage/preliminaryPrepartion/reserveManagementModifyByzz";
    }

    /**
     * 专职人员保存表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:preliminaryPrepartion:add"},logical=Logical.OR)
    @RequestMapping(value = "save")
    public AjaxJson save(PreliminaryPrepartion reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //新增或编辑表单保存
        prepartionService.save(reserveManagement);//保存
        j.setSuccess(true);
        j.setMsg("保存储备项目基本信息成功");
        return j;
    }

    /**
     * 专职人员修改表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:preliminaryPrepartion:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(PreliminaryPrepartion reserveManagement){
        AjaxJson j = new AjaxJson();

        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }

        //根据id去表中查是否有这个数据
        PreliminaryPrepartion cityWork = prepartionService.getByProId(reserveManagement.getProjectReserveId());
        if (null == cityWork){
            //进行保存操作
            cityWork = new PreliminaryPrepartion();
            cityWork.setProjectReserveId(reserveManagement.getProjectReserveId());
            cityWork.setCivilEngineeringWorkload(reserveManagement.getCivilEngineeringWorkload());
            cityWork.setQuantityRemarks(reserveManagement.getQuantityRemarks());
            cityWork.setReserveProjectPromotyPlan(reserveManagement.getReserveProjectPromotyPlan());
            cityWork.setUnitCompleteProgress(reserveManagement.getUnitCompleteProgress());
            cityWork.setDemandUnitReserveProjectPromotyPlan(reserveManagement.getDemandUnitReserveProjectPromotyPlan());
            cityWork.setDemandUnitCompleteProgress(reserveManagement.getDemandUnitCompleteProgress());
            cityWork.setPreliminaryPreparationRemarks(reserveManagement.getPreliminaryPreparationRemarks());
            cityWork.setDemandUnitPriority(reserveManagement.getDemandUnitPriority());
            cityWork.setImplementPlan(reserveManagement.getImplementPlan());
            cityWork.setImplementBatch(reserveManagement.getImplementBatch());
            cityWork.setConstructionUnit(reserveManagement.getConstructionUnit());
            cityWork.setPlanAndApprovalDraw(reserveManagement.getPlanAndApprovalDraw());
            cityWork.setDrawOfficeDrawn(reserveManagement.getDrawOfficeDrawn());
            cityWork.setProjectApprovalRemarks(reserveManagement.getProjectApprovalRemarks());
            prepartionService.save(cityWork);
        }else {
            cityWork.setProjectReserveId(reserveManagement.getProjectReserveId());
            cityWork.setCivilEngineeringWorkload(reserveManagement.getCivilEngineeringWorkload());
            cityWork.setQuantityRemarks(reserveManagement.getQuantityRemarks());
            cityWork.setReserveProjectPromotyPlan(reserveManagement.getReserveProjectPromotyPlan());
            cityWork.setUnitCompleteProgress(reserveManagement.getUnitCompleteProgress());
            cityWork.setDemandUnitReserveProjectPromotyPlan(reserveManagement.getDemandUnitReserveProjectPromotyPlan());
            cityWork.setDemandUnitCompleteProgress(reserveManagement.getDemandUnitCompleteProgress());
            cityWork.setPreliminaryPreparationRemarks(reserveManagement.getPreliminaryPreparationRemarks());
            cityWork.setDemandUnitPriority(reserveManagement.getDemandUnitPriority());
            cityWork.setImplementPlan(reserveManagement.getImplementPlan());
            cityWork.setImplementBatch(reserveManagement.getImplementBatch());
            cityWork.setConstructionUnit(reserveManagement.getConstructionUnit());
            cityWork.setPlanAndApprovalDraw(reserveManagement.getPlanAndApprovalDraw());
            cityWork.setDrawOfficeDrawn(reserveManagement.getDrawOfficeDrawn());
            cityWork.setProjectApprovalRemarks(reserveManagement.getProjectApprovalRemarks());
            //新增或编辑表单保存
            prepartionService.update(cityWork);
        }
        j.setSuccess(true);
        j.setMsg("修改储备项目基本信息成功");
        return j;
    }
    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:preliminaryPrepartion:export")
    @RequestMapping(value = "export")
    public void exportExcel(PreliminaryPrepartion reserveManagement, HttpServletRequest request, HttpServletResponse response) {
        List<PreliminaryPrepartion> list = prepartionService.exportFindList(reserveManagement);

        List<PreliminaryPrepartion> processList = new ArrayList<>();
        for (PreliminaryPrepartion summary : list) {

            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = prepartionService.getByProjectReserveId(summary.getProjectReserveId());
            //根据procInsId查出历史流程名称和时间
            List<History> histories = prepartionService.getHistoryByExecuteId(procInsId);
            //当size>0时待办有历史流程，
            if (histories.size()>0){
                //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                String name = prepartionService.getByExecuteId(procInsId);
                //设置项目进度
                summary.setReserveProgress(name);
            }else {
                summary.setReserveProgress("");
            }

            processList.add(summary);
        }

        //生成序列号
        int i = 1;
        for (PreliminaryPrepartion s : processList) {
            s.setId(String.valueOf(i));
            i++;
        }

        ReserveProcessProjectExportUtil util = ReserveProcessProjectExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("preliminaryPrepartion");
        util.exportProcess(response,workbook,processList);
    }

    /**
     * 导入Excel数据
     * @param file
     * @param response
     * @param request
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:reserveElectricityWork:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);
            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = prepartionService.getAllProId();

            //从基本数据表中查出所有的 项目储备编号
            List<String> proIdList2 = prepartionService.getAllProId2();

            //获取导入表格所有数据
            List<PreliminaryPrepartion> reserveManagementList = ReserveProcessProjectProUtil.getPreLiminUtil(importUtil,proIdList,proIdList2);
            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = prepartionService.getExistProjectList(reserveManagementList);
            //未存在数据
            List<PreliminaryPrepartion> withoutList = (List<PreliminaryPrepartion>) map.get("without");
            //已存在数据
            List<PreliminaryPrepartion> existList = (List<PreliminaryPrepartion>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                prepartionService.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (PreliminaryPrepartion reserveManagement : existList) {
                    prepartionService.update(reserveManagement);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条项目储备信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入项目储备信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }
}
