package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ProjectTypeVerificate;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ProjectTypeVerificateService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveElectricityWorkService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectProUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import com.jeeplus.modules.sg.picking.activiti.entity.PickList;
import com.jeeplus.modules.sg.raiseCapital.service.RaiseCapitalService;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author: 王强
 * @create: 2023-06-26 14:03
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/projectTypeVerificate")
public class ProjectTypeVerificateController extends BaseController {

    @Autowired
    private ProjectTypeVerificateService service;

    @Autowired
    private RaiseCapitalService raiseCapitalService;

    @Autowired
    private ReserveElectricityWorkService workService;

    @ModelAttribute
    public ProjectTypeVerificate get(@RequestParam(required = false) String id) {
        ProjectTypeVerificate entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = service.get(id);
        }
        if (entity == null) {
            entity = new ProjectTypeVerificate();
        }
        return entity;
    }

    /**
     * 省公司评审信息列表页面
     * @param review
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:projectTypeVerificate:list")
    @RequestMapping(value = "skipList")
    public String skipList(ProjectTypeVerificate review, Model model) {
        model.addAttribute("review", review);
        return "modules/cg/reservemanagementcenter/reserveManage/projectTypeVerificate/projectTypeVerificateInfo";
    }

    /**
     * 查看表单页面
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:projectTypeVerificate:view"},logical= Logical.OR)
    @RequestMapping(value = "view")
    public String view(ProjectTypeVerificate verificate, Model model) {
        model.addAttribute("verificate", verificate);
        return "modules/cg/reservemanagementcenter/reserveManage/projectTypeVerificate/projectTypeVerificateView";
    }

    /**
     * 编辑表单页面
     * @param verificate
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:projectTypeVerificate:add","cg:reservemanagementcenter:projectTypeVerificate:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(ProjectTypeVerificate verificate, Model model) {

        model.addAttribute("verificate", verificate);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(verificate.getId())){
            return "modules/cg/reservemanagementcenter/reserveManage/projectTypeVerificate/projectTypeVerificateForm";
        }
        return "modules/cg/reservemanagementcenter/reserveManage/projectTypeVerificate/projectTypeVerificateByzz";
    }

    /**
     * 项目储备信息数据列表
     * @param verificate
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:projectTypeVerificate:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(ProjectTypeVerificate verificate, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<ProjectTypeVerificate> page = service.findPage(new Page<ProjectTypeVerificate>(request, response), verificate);
        List<ProjectTypeVerificate> list = page.getList();
        List<ProjectTypeVerificate> workList = new ArrayList<>();

        List<String> nameList = new ArrayList<>();
        //获取所有小类的名称
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        for (ProjectTypeVerificate work : list) {
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = service.getByProjectReserveId(work.getProjectReserveId());
            String historyName = workService.getHistoryName(procInsId);
            //根据procInsId查出历史流程名称和时间
            if (StringUtils.isNotEmpty(procInsId)){
                List<History> histories = service.getHistoryByExecuteId(procInsId);
                //当size>0时待办有历史流程，
                if (histories.size()>0){
                    //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                    String name = service.getByExecuteId(procInsId);
                    //设置项目进度
                    if (StringUtils.isNotEmpty(name)){
                        work.setReserveProgress(name);
                    }else {
                        if (StringUtils.isNotBlank(historyName) && historyName.equals("技经人员审预算")){
                            work.setReserveProgress("储备完成");
                        } else {
                            work.setReserveProgress("");
                        }
                    }
                }else {
                    work.setReserveProgress("");
                }
            }else {
                work.setReserveProgress("");
            }

            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = service.getMaterialName(work.getProjectName());
            if (null != nameList & null != materialNameList){
                nameList.forEach(n->{
                    if (materialNameList.contains(n)){
                        work.setIncludeCapitalEquipment("是");
                        work.setProjectProperties("资本");
                    } else {
                        work.setIncludeCapitalEquipment("否");
                        work.setProjectProperties("成本");
                    }
                });
            }
            if (StringUtils.isBlank(work.getStateGridProjectCode())){
                work.setStateGridProjectCode("");
            }
            if (StringUtils.isBlank(work.getStateGridProjectName())){
                work.setStateGridProjectName("");
            }
            workList.add(work);
        }
        page.setList(workList);
        return getBootstrapData(page);
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:projectTypeVerificate:export")
    @RequestMapping(value = "export")
    public void exportExcel(ProjectTypeVerificate verificate, HttpServletRequest request, HttpServletResponse response) {
        List<ProjectTypeVerificate> list = service.exportFindList(verificate);

        List<String> nameList = new ArrayList<>();
        //获取所有小类的名称
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        //生成序列号
        int i = 1;
        for (ProjectTypeVerificate s : list) {
            s.setId(String.valueOf(i));
            i++;

            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = service.getByProjectReserveId(s.getProjectReserveId());
            String historyName = workService.getHistoryName(procInsId);
            //根据procInsId查出历史流程名称和时间
            if (StringUtils.isNotEmpty(procInsId)){
                List<History> histories = service.getHistoryByExecuteId(procInsId);
                //当size>0时待办有历史流程，
                if (histories.size()>0){
                    //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                    String name = service.getByExecuteId(procInsId);
                    //设置项目进度
                    if (StringUtils.isNotEmpty(name)){
                        s.setReserveProgress(name);
                    }else {
                        if (StringUtils.isNotBlank(historyName) && historyName.equals("技经人员审预算")){
                            s.setReserveProgress("储备完成");
                        } else {
                            s.setReserveProgress("");
                        }
                    }
                }else {
                    s.setReserveProgress("");
                }
            }else {
                s.setReserveProgress("");
            }

            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = service.getMaterialName(s.getProjectName());
            if (null != nameList & null != materialNameList){
                nameList.forEach(n->{
                    if (materialNameList.contains(n)){
                        s.setIncludeCapitalEquipment("是");
                        s.setProjectProperties("资本");
                    } else {
                        s.setIncludeCapitalEquipment("否");
                        s.setProjectProperties("成本");
                    }
                });
            }
        }

        ReserveProcessProjectExportUtil util = ReserveProcessProjectExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("projectTypeVerificate");
        util.exportVerificate(response,workbook,list);
    }

    /**
     * 专职人员修改表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:projectTypeVerificate:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(ProjectTypeVerificate reserveManagement) {
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //根据id去项目校核表中查是否有这个数据
        ProjectTypeVerificate cityWork = service.getByProId(reserveManagement.getProjectReserveId());
        if (null == cityWork){
            //进行保存操作
            cityWork = new ProjectTypeVerificate();
            cityWork.setProjectReserveId(reserveManagement.getProjectReserveId());
            cityWork.setProjectNature(reserveManagement.getProjectNature());
            cityWork.setNewSubstation(reserveManagement.getNewSubstation());
            cityWork.setProjectNatureArtificial(reserveManagement.getProjectNatureArtificial());
            cityWork.setProjectType(reserveManagement.getProjectType());
            cityWork.setIncludeCablesArtificial(reserveManagement.getIncludeCablesArtificial());
            service.save(cityWork);
        }else {
            //新增或编辑表单保存
            cityWork.setProjectReserveId(reserveManagement.getProjectReserveId());
            cityWork.setProjectNature(reserveManagement.getProjectNature());
            cityWork.setNewSubstation(reserveManagement.getNewSubstation());
            cityWork.setProjectNatureArtificial(reserveManagement.getProjectNatureArtificial());
            cityWork.setProjectType(reserveManagement.getProjectType());
            cityWork.setIncludeCablesArtificial(reserveManagement.getIncludeCablesArtificial());
            service.update(cityWork);
        }
        j.setSuccess(true);
        j.setMsg("修改储备项目项目校核信息成功");
        return j;
    }

    /**
     * 导入Excel数据
     * @param file
     * @param response
     * @param request
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:projectTypeVerificate:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);
            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = service.getAllProId();

            //从基本数据表中查出所有的 项目储备编号
            List<String> proIdList2 = service.getAllProId2();

            //获取导入表格所有数据
            List<ProjectTypeVerificate> reserveManagementList = ReserveProcessProjectProUtil.getVerificateUtil(importUtil,proIdList,proIdList2);
            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = service.getExistProjectList(reserveManagementList);
            //未存在数据
            List<ProjectTypeVerificate> withoutList = (List<ProjectTypeVerificate>) map.get("without");
            //已存在数据
            List<ProjectTypeVerificate> existList = (List<ProjectTypeVerificate>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                service.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (ProjectTypeVerificate reserveManagement : existList) {
                    service.update(reserveManagement);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条项目储备信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入项目储备信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }





}
