package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ReserveElectricityWork;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ProjectTypeVerificateService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveElectricityWorkService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectProUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import com.jeeplus.modules.sg.picking.activiti.entity.PickList;
import com.jeeplus.modules.sg.raiseCapital.service.RaiseCapitalService;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 储备项目带电作业信息 controller
 * @author: 王强
 * @create: 2022-07-22 08:37
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/reserveElectricityWork")
public class ReserveElectricityWorkController extends BaseController {

    @Autowired
    private ReserveElectricityWorkService workService;

    @Autowired
    private RaiseCapitalService raiseCapitalService;

    @Autowired
    private ProjectTypeVerificateService verificateService;


    @ModelAttribute
    public ReserveElectricityWork get(@RequestParam(required = false) String id) {
        ReserveElectricityWork entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = workService.get(id);
        }
        if (entity == null) {
            entity = new ReserveElectricityWork();
        }
        return entity;
    }

    /**
     * 项目储备信息列表页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:reserveElectricityWork:list")
    @RequestMapping(value = "skipList")
    public String skipList(ReserveElectricityWork reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/reserveManage/reserveElectricityWork/reserveManagementInformation";
    }



    /**
     * 项目储备信息数据列表
     * @param reserveManagement
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:reserveElectricityWork:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(ReserveElectricityWork reserveManagement, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<ReserveElectricityWork> page = workService.findPage(new Page<ReserveElectricityWork>(request, response), reserveManagement);
        List<ReserveElectricityWork> list = page.getList();
        List<ReserveElectricityWork> workList = new ArrayList<>();

        //获取所有小类的名称
        List<String> nameList = new ArrayList<>();
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        for (ReserveElectricityWork work : list) {
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = workService.getByProjectReserveId(work.getProjectReserveId());
            //根据procInsId查出历史流程名称和时间
            if (StringUtils.isNotEmpty(procInsId)){
                List<History> histories = workService.getHistoryByExecuteId(procInsId);
                String historyName = workService.getHistoryName(procInsId);
                //当size>0时待办有历史流程，
                if (histories.size()>0){
                    //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                    String name = workService.getByExecuteId(procInsId);
                    //设置项目进度
                    if (StringUtils.isNotEmpty(name)){
                        work.setReserveProgress(name);
                    }else {
                        if (StringUtils.isNotBlank(historyName) && historyName.equals("技经人员审预算")){
                            work.setReserveProgress("储备完成");
                        } else {
                            work.setReserveProgress("");
                        }
                    }
                }else {
                    work.setReserveProgress("");
                }
            }else {
                work.setReserveProgress("");
            }

            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = verificateService.getMaterialName(work.getProjectName());
            if (null != nameList & null != materialNameList){
                nameList.forEach(n->{
                    if (StringUtils.isBlank(work.getProjectNature())){
                        if (materialNameList.contains(n)){
                            work.setProjectNature("资本");
                        } else {
                            work.setProjectNature("成本");
                        }
                    }
                });
            }
            if (StringUtils.isBlank(work.getStateGridProjectCode())){
                work.setStateGridProjectCode("");
            }
            if (StringUtils.isBlank(work.getStateGridProjectName())){
                work.setStateGridProjectName("");
            }
            workList.add(work);
        }
        page.setList(workList);
        return getBootstrapData(page);
    }


    /**
     * 查看表单页面
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveElectricityWork:view"},logical= Logical.OR)
    @RequestMapping(value = "view")
    public String view(ReserveElectricityWork reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/reserveManage/reserveElectricityWork/reserveManagementView";
    }


    /**
     * 专职人员保存表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveElectricityWork:add"},logical=Logical.OR)
    @RequestMapping(value = "save")
    public AjaxJson save(ReserveElectricityWork reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //新增或编辑表单保存
        workService.save(reserveManagement);//保存
        j.setSuccess(true);
        j.setMsg("保存储备项目基本信息成功");
        return j;
    }


    /**
     * 专职人员修改表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveElectricityWork:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(ReserveElectricityWork reserveManagement){
        AjaxJson j = new AjaxJson();

        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }

        //根据id去带电作业表中查是否有这个数据
        ReserveElectricityWork cityWork = workService.getByProId(reserveManagement.getProjectReserveId());
        if (null == cityWork){
            //进行保存操作
            cityWork = new ReserveElectricityWork();
            cityWork.setProjectReserveId(reserveManagement.getProjectReserveId());
            cityWork.setHotLineWork(reserveManagement.getHotLineWork());
            cityWork.setBoundarySwitchNum(reserveManagement.getBoundarySwitchNum());
            cityWork.setHotLineWorkTypeNo(reserveManagement.getHotLineWorkTypeNo());
            cityWork.setNoStopWorkPlan(reserveManagement.getNoStopWorkPlan());
            cityWork.setPowerFailureNum(reserveManagement.getPowerFailureNum());
            cityWork.setReasonsForNotWorkInterruption(reserveManagement.getReasonsForNotWorkInterruption());
            cityWork.setPowerOutagePlan(reserveManagement.getPowerOutagePlan());
            cityWork.setPlanner(reserveManagement.getPlanner());
            cityWork.setSiteSurveyor(reserveManagement.getSiteSurveyor());
            workService.save(cityWork);
        }else {
            //新增或编辑表单保存
            cityWork.setHotLineWork(reserveManagement.getHotLineWork());
            cityWork.setBoundarySwitchNum(reserveManagement.getBoundarySwitchNum());
            cityWork.setHotLineWorkTypeNo(reserveManagement.getHotLineWorkTypeNo());
            cityWork.setNoStopWorkPlan(reserveManagement.getNoStopWorkPlan());
            cityWork.setPowerFailureNum(reserveManagement.getPowerFailureNum());
            cityWork.setReasonsForNotWorkInterruption(reserveManagement.getReasonsForNotWorkInterruption());
            cityWork.setPowerOutagePlan(reserveManagement.getPowerOutagePlan());
            cityWork.setPlanner(reserveManagement.getPlanner());
            cityWork.setSiteSurveyor(reserveManagement.getSiteSurveyor());
            workService.update(cityWork);
        }
        j.setSuccess(true);
        j.setMsg("修改储备项目基本信息成功");
        return j;
    }

    /**
     * 导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:reserveElectricityWork:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);
            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = workService.getAllProId();

            //从基本数据表中查出所有的 项目储备编号
            List<String> proIdList2 = workService.getAllProId2();

            //获取导入表格所有数据
            List<ReserveElectricityWork> reserveManagementList = ReserveProcessProjectProUtil.getChargeProjectUtil(importUtil,proIdList,proIdList2);
            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = workService.getExistProjectList(reserveManagementList);
            //未存在数据
            List<ReserveElectricityWork> withoutList = (List<ReserveElectricityWork>) map.get("without");
            //已存在数据
            List<ReserveElectricityWork> existList = (List<ReserveElectricityWork>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                workService.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (ReserveElectricityWork reserveManagement : existList) {
                    workService.update(reserveManagement);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条项目储备信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入项目储备信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }


    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:reserveElectricityWork:export")
    @RequestMapping(value = "export")
    public void exportExcel(ReserveElectricityWork reserveManagement, HttpServletRequest request, HttpServletResponse response) {
        List<ReserveElectricityWork> list = workService.exportFindList(reserveManagement);

        List<ReserveElectricityWork> workList = new ArrayList<>();

        //获取所有小类的名称
        List<String> nameList = new ArrayList<>();
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        for (ReserveElectricityWork work : list) {
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = workService.getByProjectReserveId(work.getProjectReserveId());
            //根据procInsId查出历史流程名称和时间
            List<History> histories = workService.getHistoryByExecuteId(procInsId);
            String historyName = workService.getHistoryName(procInsId);
            //当size>0时待办有历史流程，
            if (histories.size()>0){
                //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                String name = workService.getByExecuteId(procInsId);
                //设置项目进度
                if (StringUtils.isNotEmpty(name)){
                    work.setReserveProgress(name);
                }else {
                    if (StringUtils.isNotBlank(historyName) && historyName.equals("技经人员审预算")){
                        work.setReserveProgress("储备完成");
                    } else {
                        work.setReserveProgress("");
                    }
                }
            }else {
                work.setReserveProgress("");
            }

            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = verificateService.getMaterialName(work.getProjectName());
            if (null != nameList & null != materialNameList){
                nameList.forEach(n->{
                    if (StringUtils.isBlank(work.getProjectNature())){
                        if (materialNameList.contains(n)){
                            work.setProjectNature("资本");
                        } else {
                            work.setProjectNature("成本");
                        }
                    }
                });
            }

            workList.add(work);
        }

        //生成序列号
        int i = 1;
        for (ReserveElectricityWork s : workList) {
            s.setId(String.valueOf(i));
            i++;
        }

        ReserveProcessProjectExportUtil util = ReserveProcessProjectExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("electricityWork");
        util.exportElectricityWork(response,workbook,workList);
    }


    /**
     * 专职人员增加，编辑表单页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveElectricityWork:add","cg:reservemanagementcenter:reserveElectricityWork:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(ReserveElectricityWork reserveManagement, Model model) {
        //根据projectReserveId查出流程表的proc_ins_id
        String procInsId = workService.getByProjectReserveId(reserveManagement.getProjectReserveId());
        //根据procInsId查出历史流程名称和时间
        List<History> histories = workService.getHistoryByExecuteId(procInsId);
        //当size>0时待办有历史流程，
        if (histories.size()>0){
            //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
            String name = workService.getByExecuteId(procInsId);
            //设置项目进度
            reserveManagement.setReserveProgress(name);
        }else {
            reserveManagement.setReserveProgress("");
        }
        model.addAttribute("reserveManagement", reserveManagement);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(reserveManagement.getId())){
            return "modules/cg/reservemanagementcenter/reserveManage/reserveElectricityWork/reserveManagementForm";
        }
        return "modules/cg/reservemanagementcenter/reserveManage/reserveElectricityWork/reserveManagementModifyByzz";
    }

    /**
     * 导出查勘单
     * @param reserveManagement
     * @param request
     * @param response
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveElectricityWork:svrExport"},logical= Logical.OR)
    @RequestMapping(value = "svrExport")
    public void svrExport(ReserveElectricityWork reserveManagement, HttpServletRequest request, HttpServletResponse response) {
        ReserveProcessProjectExportUtil util = ReserveProcessProjectExportUtil.getOne();
        XSSFWorkbook workbook;
        //如果是带电作业，就导出  镇江公司设计阶段停电作业查勘单
        if (reserveManagement.getHotLineWork().equals("是")){
            workbook = util.getWorkbook("noPowerFailureSurveySheet");
        }else {
            //否则导出  镇江公司设计阶段不停电作业查勘单
            workbook = util.getWorkbook("powerFailureSurveySheet");
        }

        util.exportSurveySheet(response,workbook,reserveManagement);
    }
}
