package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service;

import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.Cable;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.MaterialData;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.mapper.CableMapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 电缆段长统计表 service
 * @author: 王强
 * @create: 2022-11-04 08:56
 **/
@Service
@Transactional(readOnly = true)
public class CableService extends CrudService<CableMapper, Cable> {

    @Autowired
    private CableMapper dao;

    /**
     * 根据项目储备id将redis的id查出来
     * @param reserveId
     * @return
     */
    public String getRedisIdByProjectReserveId(String reserveId){
        return dao.getRedisIdByProjectReserveId(reserveId);
    }

    @Transactional(readOnly = false)
    public void insertIntoCableRedis(String projectReserveId,String redisId){
        dao.insertIntoCableRedis(projectReserveId, redisId);
    }

    @Transactional(readOnly = false)
    public void insertDistributionIntoCableRedis(String projectReserveId,String redisId){
        dao.insertDistributionIntoCableRedis(projectReserveId, redisId);
    }

    /**
     * 根据项目储备编号删除
     * @param projectReserveId
     */
    @Transactional(readOnly = false)
    public void deleteCableRedis(String projectReserveId){
        dao.deleteCableRedis(projectReserveId);
    }

    /**
     * 根据项目储备编号删除
     * @param projectReserveId
     */
    @Transactional(readOnly = false)
    public void deleteDistributionCableRedis(String projectReserveId){
        dao.deleteDistributionCableRedis(projectReserveId);
    }


    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 根据项目名称去 甲供材表中获取数据
     * @param name
     * @return
     */
    public List<MaterialData> getByProjectName(String name){
        return dao.getByProjectName(name);
    }

    @Transactional(readOnly = false)
    public void insertList(@Param("list") List<Cable> list){
        List<Cable> statsList = dao.exportFindList(null);
        for(Cable cable : list){
            statsList.forEach(sta->{
                if (sta.getProjectReserveId().equals(cable.getProjectReserveId())){
                    dao.deleteByProId(sta.getProjectReserveId());
                }
            });
            cable.preInsert();
        }

        dao.insertList(list);
    }
    public List<Cable> exportFindList(Cable cable) {
        List<Cable> pageList = dao.exportFindList(cable);
        return pageList;
    }

    /**
     * 根据项目储备编号删除方法
     * @param proId
     */
    @Transactional(readOnly = false)
    public void deleteByProId(String proId) {
        dao.deleteByProId(proId);
    }

}
