package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.FeedBackBudget;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.ProgressStats;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.mapper.ProgressStatsMapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 储备进度统计表
 * @author: 王强
 * @create: 2022-08-18 09:16
 **/
@Service
@Transactional(readOnly = true)
public class ProgressStatsService extends CrudService<ProgressStatsMapper, ProgressStats> {

    @Autowired
    private ProgressStatsMapper dao;

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 根据 ProInsId 和时间 去历史节点表查退回意见
     * @param proInsId
     * @return
     */
    public String getCommentByProInsId(String proInsId,String time){
        return dao.getCommentByProInsId(proInsId, time);
    }

    @Transactional(readOnly = false)
    public void insertList(@Param("list") List<ProgressStats> list){
        List<ProgressStats> statsList = mapper.exportFindList(null);
        for(ProgressStats progressStats : list){
            statsList.forEach(sta->{
                if (sta.getProjectReserveId().equals(progressStats.getProjectReserveId())){
                    dao.deleteByProId(sta.getProjectReserveId());
                }
            });
            progressStats.preInsert();
        }
        dao.insertList(list);
    }

    public Page<ProgressStats> findPage(Page<ProgressStats> page, ProgressStats progressStats) {
        Page<ProgressStats> pageList = super.findPage(page, progressStats);
        return pageList;
    }

    /**
     * 删除方法
     * @param proId
     */
    @Transactional(readOnly = false)
    public void deleteByProId(String proId) {
        dao.deleteByProId(proId);
    }

    public int selectCount(String projectReserveId){
        return dao.selectCount(projectReserveId);
    }

    public List<ProgressStats> exportFindList(ProgressStats progressStats) {
        List<ProgressStats> pageList = dao.exportFindList(progressStats);
        return pageList;
    }

    public String getByProjectReserveId(String projectReserveId){
        return dao.getByProjectReserveId(projectReserveId);
    }

    public String getDistributionByProjectReserveId(String projectReserveId){
        return dao.getDistributionByProjectReserveId(projectReserveId);
    }
    /**
     * 根据proInsId 和节点名称去 历史表中 查设计单位节点信息
     * @param proInsId
     * @param name
     * @return
     */
    public List<History> getHistoryByProInsId(String proInsId, String name){
        return dao.getHistoryByProInsId(proInsId, name);
    }

    /**
     * 根据上一个节点的结束时间去查询下一个节点的信息
     * @param endTime
     * @return
     */
    public History getHistoryByStartTime(String endTime){
        return dao.getHistoryByStartTime(endTime);
    }

    /**
     * 根据项目储备id查反馈信息
     * @return
     */
    public FeedBackBudget getByProId(String proId){
        return dao.getByProId(proId);
    }
}
