package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.MaterialData;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.SpecialSupply;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.mapper.SpecialSupplyMapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 特殊物资统计
 * @author: 王强
 * @create: 2022-08-22 17:58
 **/
@Service
@Transactional(readOnly = true)
public class SpecialSupplyService extends CrudService<SpecialSupplyMapper, SpecialSupply> {

    @Autowired
    private SpecialSupplyMapper supplyMapper;

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return supplyMapper.getAllProId();
    }

    public Page<SpecialSupply> findPage(Page<SpecialSupply> page, SpecialSupply specialSupply) {
        Page<SpecialSupply> pageList = super.findPage(page, specialSupply);
        return pageList;
    }

    public List<SpecialSupply> exportFindList(SpecialSupply specialSupply) {
        List<SpecialSupply> pageList = supplyMapper.exportFindList(specialSupply);
        return pageList;
    }

    public Double getData(String code,String extendDescription,String note) {
        return supplyMapper.getData(code, extendDescription, note);
    }

    public String getByProjectReserveId(String projectReserveId){
        return supplyMapper.getByProjectReserveId(projectReserveId);
    }

    public List<History> getHistoryByExecuteId(String executeId){
        return supplyMapper.getHistoryByExecuteId(executeId);
    }

    public String getByExecuteId(String executeId){
        return supplyMapper.getByExecuteId(executeId);
    }

    @Transactional(readOnly = false)
    public void insertList(@Param("list") List<SpecialSupply> list){
        List<SpecialSupply> statsList = supplyMapper.exportFindList(null);
        for(SpecialSupply budgetStats : list){
            statsList.forEach(sta->{
                if (sta.getProjectReserveId().equals(budgetStats.getProjectReserveId())){
                    supplyMapper.deleteByProId(sta.getProjectReserveId());
                }
            });
            budgetStats.preInsert();
        }

        supplyMapper.insertList(list);
    }

    /**
     * 根据项目储备编号删除方法
     * @param proId
     */
    @Transactional(readOnly = false)
    public void deleteByProId(String proId) {
        supplyMapper.deleteByProId(proId);
    }

    /**
     * 根据项目名称去 甲供材表中获取数据
     * @param name
     * @return
     */
    public List<MaterialData> getByProjectName(String name){
        return supplyMapper.getAllMaterialInfo(name);
    }
}
