package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ProjectScreenService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ProjectTypeVerificateService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveElectricityWorkService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.MaterialData;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.SpecialParameterStats;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.SpecialParameterStatsService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelImportUtil;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import com.jeeplus.modules.sg.picking.activiti.entity.PickList;
import com.jeeplus.modules.sg.raiseCapital.service.RaiseCapitalService;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author 王强
 * @version 1.0
 * @date 2023-10-08 15:25
 */
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/specialParameterStats")
public class SpecialParameterStatsController extends BaseController {

    @Autowired
    private SpecialParameterStatsService statsService;

    @Autowired
    private ProjectScreenService service;

    @Autowired
    private ReserveElectricityWorkService workService;

    @Autowired
    private RaiseCapitalService raiseCapitalService;

    @Autowired
    private ProjectTypeVerificateService verificateService;

    @ModelAttribute
    public SpecialParameterStats get(@RequestParam(required = false) String id) {
        SpecialParameterStats entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = statsService.get(id);
        }
        if (entity == null) {
            entity = new SpecialParameterStats();
        }
        return entity;
    }

    /**
     * 储备项目设计特殊物资参数统计表页面
     * @param budgetStats
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:specialParameterStats:list")
    @RequestMapping(value = "budgetList")
    public String budgetList(SpecialParameterStats budgetStats, Model model) {
        model.addAttribute("budgetStats", budgetStats);
        return "modules/cg/statisticalTable/specialParameterStats/specialParameterStats";
    }

    /**
     * 储备项目设计特殊物资参数统计表数据列表
     * @param budgetStats
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:specialParameterStats:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(SpecialParameterStats budgetStats, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {

        Page<SpecialParameterStats> page = statsService.findPage(new Page<SpecialParameterStats>(request, response), budgetStats);

        List<SpecialParameterStats> list = page.getList();
        List<SpecialParameterStats> workList = new ArrayList<>();

        //获取所有小类的名称
        List<String> nameList = new ArrayList<>();
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        for (SpecialParameterStats work : list) {
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = service.getByProjectReserveId(work.getProjectReserveId());
            //根据procInsId查出历史流程名称和时间
            if (StringUtils.isNotEmpty(procInsId)){
                List<History> histories = service.getHistoryByExecuteId(procInsId);
                String historyName = workService.getHistoryName(procInsId);
                //当size>0时待办有历史流程，
                if (histories.size()>0){
                    //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                    String name = service.getByExecuteId(procInsId);
                    //设置项目进度
                    if (StringUtils.isNotEmpty(name)){
                        work.setReserveProgress(name);
                    }else {
                        if (StringUtils.isNotBlank(historyName) && historyName.equals("技经人员审预算")){
                            work.setReserveProgress("储备完成");
                        } else {
                            work.setReserveProgress("");
                        }
                    }
                }else {
                    work.setReserveProgress("");
                }
            }else {
                work.setReserveProgress("");
            }

            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = verificateService.getMaterialName(work.getProjectName());
            if (null != nameList & null != materialNameList){
                nameList.forEach(n->{
                    if (StringUtils.isBlank(work.getProjectNature())){
                        if (materialNameList.contains(n)){
                            work.setProjectNature("资本");
                        } else {
                            work.setProjectNature("成本");
                        }
                    }
                });
            }
            if (StringUtils.isBlank(work.getStateGridProjectCode())){
                work.setStateGridProjectCode("");
            }
            if (StringUtils.isBlank(work.getStateGridProjectName())){
                work.setStateGridProjectName("");
            }


            workList.add(work);
        }
        return getBootstrapData(page);
    }

    /**
     * 删除表单
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:specialParameterStats:del"},logical= Logical.OR)
    @RequestMapping(value = "deleteAll")
    public AjaxJson delete(String ids){
        AjaxJson j = new AjaxJson();
        String idArray[] =ids.split(",");
        for(String id : idArray){
            statsService.deleteById(id);
        }
        j.setMsg("删除储备项目设计特殊物资参数统计表信息成功");
        return j;
    }

    /**
     *  导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:specialParameterStats:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);

            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = statsService.getAllProId();
            //从甲供材表中获取所有的数据信息
            List<MaterialData> materialData = statsService.getAllMaterialData();

            // 使用Java 8+的流操作和Collectors.groupingBy来创建Map
            Map<String, List<MaterialData>> materialDataMap = materialData.stream()
                    .collect(Collectors.groupingBy(MaterialData::getProjectName));
            //获取导入表格所有数据
            List<SpecialParameterStats> plotProgressStats = ExcelImportUtil.getSpecialParameterStatsUtil(file,importUtil,proIdList,materialDataMap);
            statsService.insertList(plotProgressStats);
        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入储备项目概预算信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:specialParameterStats:export")
    @RequestMapping(value = "export")
    public void exportExcel(SpecialParameterStats budgetStats, HttpServletRequest request, HttpServletResponse response) throws ParseException {
        List<SpecialParameterStats> list = statsService.exportFindList(budgetStats);

        List<SpecialParameterStats> workList = new ArrayList<>();

        //获取所有小类的名称
        List<String> nameList = new ArrayList<>();
        List<PickList> pickListList = raiseCapitalService.newAllList();
        if (null != pickListList) {
            pickListList.forEach(k->{
                if (k.getName().equals("三、设备")){
                    k.getMdTheClassList().forEach(v->{
                        v.getMdSmallClassList().forEach(na->{
                            nameList.add(na.getName());
                        });
                    });
                }
            });
        }

        for (SpecialParameterStats work : list) {
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = service.getByProjectReserveId(work.getProjectReserveId());
            //根据procInsId查出历史流程名称和时间
            if (StringUtils.isNotEmpty(procInsId)){
                List<History> histories = service.getHistoryByExecuteId(procInsId);
                String historyName = workService.getHistoryName(procInsId);
                //当size>0时待办有历史流程，
                if (histories.size()>0){
                    //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                    String name = service.getByExecuteId(procInsId);
                    //设置项目进度
                    if (StringUtils.isNotEmpty(name)){
                        work.setReserveProgress(name);
                    }else {
                        if (StringUtils.isNotBlank(historyName) && historyName.equals("技经人员审预算")){
                            work.setReserveProgress("储备完成");
                        } else {
                            work.setReserveProgress("");
                        }
                    }
                }else {
                    work.setReserveProgress("");
                }
            }else {
                work.setReserveProgress("");
            }

            //根据项目储备id去在线开甲供材表中查询物理信息
            List<String> materialNameList = verificateService.getMaterialName(work.getProjectName());
            if (null != nameList & null != materialNameList){
                nameList.forEach(n->{
                    if (StringUtils.isBlank(work.getProjectNature())){
                        if (materialNameList.contains(n)){
                            work.setProjectNature("资本");
                        } else {
                            work.setProjectNature("成本");
                        }
                    }
                });
            }
            if (StringUtils.isBlank(work.getStateGridProjectCode())){
                work.setStateGridProjectCode("");
            }
            if (StringUtils.isBlank(work.getStateGridProjectName())){
                work.setStateGridProjectName("");
            }


            workList.add(work);
        }
        //生成序列号
        int i = 1;
        for (SpecialParameterStats s : workList) {
            s.setId(String.valueOf(i));
            i++;
        }

        ExcelExportUtil util = ExcelExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("specialParameterStats");
        util.exportSpecialParameterStats(response,workbook,workList);
    }
}
